// 初始化本地数据库
app.constant('dbConfig', {
    name: 'ieasy360',
    tables: TABLES_SCHEME
})
// sqlite 数据库访问对象
.factory('database', ['$q', 'dbConfig', function ($q, dbConfig) {
    var self = this;
    self.db = null;

    self.init = function (execQuery, cb) {

        if (window.sqlitePlugin) {
            self.db = window.sqlitePlugin.openDatabase(dbConfig.name, '1.0', 'database', -1);
        }
        else {
            if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
                self.db = openDatabase(dbConfig.name, '1.0', 'database', 1024*1024);
            } else {
                self.db = openDatabase(dbConfig.name, '1.0', 'database', -1);
            }
        }
		
		angular.forEach(dbConfig.tables, function (table) {
			var columns = [];
			angular.forEach(table.columns, function (column) {
				columns.push(column.name + ' ' + column.type);
			});
            // IF NOT EXISTS 
            var query = 'CREATE TABLE IF NOT EXISTS ' + table.name + ' (' + columns.join(',') + ') ';
            self.query(query);
        });
		if(execQuery) {
			$.maskLoader("show", "系统正在初始化...");
			var allQueryLength = 0;
			var count = 0;
			var _finish = function () {
				count++;
				if (count == allQueryLength) {
					$.maskLoader("hide");
					if (cb) {
						return cb();
					}
				}
			}
			angular.forEach(dbConfig.tables, function (table) {
				var addColumnQueries = [];
				angular.forEach(table.columns, function (column) {
					addColumnQueries.push("ALTER TABLE " + table.name + " ADD COLUMN " + column.name + " " + column.type);
				});
				allQueryLength += addColumnQueries.length;
				
				for (var idx in addColumnQueries) {
					self.query(addColumnQueries[idx]).then(function () {
						_finish();
					}, function () {
						_finish();
					});
				}
			});
		}
    };

    self.query = function (query, bindings) {
        bindings = typeof bindings !== 'undefined' ? bindings : [];
        var o = {
            query: query,
            params: bindings
        }
        return self.queryTransaction([o]);
    };

    self.queryTransaction = function (queryAndParamsArray) {
        queryAndParamsArray = typeof queryAndParamsArray !== 'undefined' ? queryAndParamsArray : [];
        var hasLogin = window.localStorage.getItem("hasLogin") || false;

        var deferred = Utils.defer();//$q.defer();
        var resultList = [];
        var affectRowsResult = [];
        var experResultList = [];
        if (Utils.isMaster()) {
            if ((CONTEXT.env != CONSTANTS.EnvConstants.WINDOWS) && (hasLogin === true)) {
                // 如果是移动环境, call 本地地址，在native端执行sql语句，避免js与native同时操作db而引发的问题
                var param = {
                    "key": BIZCONSTANT.SQL,
                    "body": queryAndParamsArray
                }
                var ret = callMasterServer(param, function (ret) {
                    //执行成功
                    if (ret.result == BIZCONSTANT.PEER_SYNC_SUCCESS)
                        deferred.resolve(ret);
                    else //失败
                        deferred.reject({ message: ret.detail.message });
                }, "http://localhost:8888");
            } else {
                self.db.transaction(function (transaction) {

                    //console.log("主机模式执行，执行的sql为：" + JSON.stringify(queryAndParamsArray));

                    for (var idx in queryAndParamsArray) {
                        var queryParam = queryAndParamsArray[idx];
                        var query = queryParam.query;
                        var bindings = typeof queryParam.params !== 'undefined' ? queryParam.params : [];
                        transaction.executeSql(query, bindings, function (transaction, result) {
                            affectRowsResult.push(result.rowsAffected);
                            for (var i = 0; i < result.rows.length; i++) {
                                resultList.push(result.rows.item(i));
                            }
                            var restparr = [];
                            if(result.rows.length>0)
                            {
                                for (var i = 0; i < result.rows.length; i++)
                                {
                                    restparr.push(result.rows.item(i));
                                }
                            }
                            experResultList.push(restparr);

                        }, function (transaction, error) {
                            if (query.indexOf('ALTER') < 0)
                            {
                                console.log(error);
                                console.error(query);
                                Utils.winLog("执行sql语句出错：", error, error.message, queryAndParamsArray, query, bindings);
                            }

                            return true;
                        });
                    }


                }, function (err) {
                    //console.log("主机事务执行失败")
                    //console.log(err);
                    deferred.reject(err);
                }, function (o) {
                    //console.log("主机事务执行成功")
                    var jsonSuccess = { result: BIZCONSTANT.PEER_SYNC_SUCCESS, desc: "success", detail: resultList, rowsAffected: affectRowsResult, expDetail: experResultList };
                    deferred.resolve(jsonSuccess);
                    //if(resultList.length == queryAndParamsArray.length){
                    //	deferred.resolve(resultList);
                    //}
                });
            }
        } else {
            var param = {
                "key": BIZCONSTANT.SQL,
                "body": queryAndParamsArray
            }
            var ret = callMasterServer(param, function (ret) {
                //执行成功
                if (ret.result == BIZCONSTANT.PEER_SYNC_SUCCESS)
                    deferred.resolve(ret);
                else //失败
                    deferred.reject({ message: ret.detail.message });
            }, null);
        }

        return deferred.promise;
    };



    self.fetchAll = function (result) {
        return result.detail;
    };

    self.fetch = function (result) {
        if (result.rows)
            return result.rows.item(0);
        else if (result.detail && result.detail.length > 0)
            return result.detail[0];
        else
            return null;
    };


    self.queryTransactionWS = function (queryAndParamsArray, callback, errorCallback) {
        queryAndParamsArray = typeof queryAndParamsArray !== 'undefined' ? queryAndParamsArray : [];
        var resultList = [];
        var affectRowsResult = [];
        self.db.transaction(function (transaction) {
            for (var idx in queryAndParamsArray) {
                var queryParam = queryAndParamsArray[idx];
                var query = queryParam.query;
                var bindings = typeof queryParam.params !== 'undefined' ? queryParam.params : [];
                transaction.executeSql(query, bindings, function (transaction, result) {
                    affectRowsResult.push(result.rowsAffected);
                    for (var i = 0; i < result.rows.length; i++) {
                        resultList.push(result.rows.item(i));
                    }
                }, function (transaction, error) {
                    console.error(query);
                    return true;
                });
            }
        }, function (err) {
            errorCallback(err);
        }, function (o) {
            var o = { affectRowsResult: affectRowsResult, resultList: resultList };
            callback(o);
        });
    }

    return self;
}])
.run(['database', '$rootScope', '$location', 'SystemConfigService', 'BanciService', 'OrderMenuService', 'PrintService', 'UploadService', 'DataCleanerService', 'HandlerNetworkOrder','$window','PingService',
    function (database, $rootScope, $location, SystemConfigService, BanciService, OrderMenuService, PrintService, UploadService, DataCleanerService, HandlerNetworkOrder, $window, PingService) {

        Utils.setInterval(PingService.pingServer, PingServerInterval.IntervalTime);

        var hasLocalConfig = true;
        loadDeviceName($rootScope);
        var deviceName = $rootScope.deviceName.split("_");
        var jqIP = deviceName[0];
        InstallConfigService.getLocalStorageInstallConfig(function (configObject) {
            if (configObject == null) {
                hasLocalConfig = false;
            }
            if (hasLocalConfig && !configObject.isMaster) {
                BIZCONSTANT.MASTER_SERVER_URL = "http://" + configObject.masterHost + ":" + WEB_SERVER.PORT;
            }
            else if (hasLocalConfig && Utils.isMaster()) {
                database.init(canInitDatabase(), function(){
                	onDatabaseInitedComplete();
                });
            }
        });

        /* 2016-03-24 JP
            新的验证方式
        */
        InstallConfigService.getLocalStorageInstallConfig(function (configObject) {

            if (Utils.isEmpty(configObject) || (!configObject.hasOwnProperty("mac") || configObject.mac == null)) {//验证是否只有isMaster字段
                /*未注册过*/
                //跳转到云账号登录的界面
                InstallConfigService.removeLocalStorageInstallConfig();
                $location.path("/index");
                return;
            } else {
                BIZCONSTANT.LOCALSTORAGE_INSTALLCONFIG = configObject;
                //有注册过 跳转到登录界面

                //todo去云端验证安装配置信息 一切以云端为主
                if (__CONFIG_SLICE__ != "dev")
                    gotoRemoteValidateInstallConfig(configObject, jqIP);
                //todo去云端验证配置信息 结束

                $rootScope.$on("$routeChangeError", function (event, current, previous, eventObj) {
                    //CONSTANTS.SystemConfigs = configObject;
                    if (eventObj.authenticated === false) {
                        $location.path("/login");
                    }
                });
            }
        })

        var userinfo = null;
        if (window.sessionStorage["userInfo"]) {
            userInfo = JSON.parse(window.sessionStorage["userInfo"]);
        }

        //获取门店基础信息
        var _loadedConfigs = false;
        if (hasLocalConfig) {
            SystemConfigService.getAllConfigs().then(function (configs) {
                CONSTANTS.SystemConfigs = configs;
                _loadedConfigs = true;
            }, function (err) {
            	_loadedConfigs = true;
                return Utils.showFailureInfo(err.message);
            });
        }


        $rootScope.$on("$routeChangeSuccess", function (userInfo) {

        });

        var eventHooks = EventHooks.get();
        $rootScope.$on("onLoad", eventHooks.onLoad);
        $rootScope.$on("beforeLogin", eventHooks.beforeLogin);
        $rootScope.$on("afterLogin", eventHooks.afterLogin);
        $rootScope.$on("beforeLogout", eventHooks.beforeLogout);
        $rootScope.$on("afterLogout", eventHooks.afterLogout);

        if (!__globalLoaded) {
            __globalLoaded = true;
			// 有本地配置并且是主机而且运行的是“非客显”页面。
            if (hasLocalConfig && Utils.isMaster() && window.location.href.indexOf("clientwindow") == -1) {
                WebServer.startup();
                SystemConfigService.getAllConfigs().then(function (configs) {
                    DataCleanerService.starup();// 清楚不需要使用的旧数据，以确保sqlite文件小
                    PrintService.bootstrapCheckStatus();
                    PrintService.initInvoiceNo(function () {
                        PrintService.startup();
                    });
                    UploadService.startup();//上传任务

                    var config = configs;
                    var temp = config["MD_ID"];
                    var mdid = temp["systemConfigValue"];
                    Kafka.startup(mdid);//启动KAFKA Consumer

                    //if (__CONFIG_SLICE__ == "dev")
                    //    HandlerNetworkOrder.update([{}]);
                }, function (err) {
                    return Utils.showFailureInfo(err.message);
                });
            }
            if (AUTO_UPDATE.AUTO){//自动更新功能只针正式版开放
            	var injectUpdateEvent = function(){
            		if(_loadedConfigs){
	            		$rootScope.$broadcast('onLoad');
	            	}
            		else{
            			window.setTimeout(injectUpdateEvent, 50);
            		}
            	};
            	injectUpdateEvent();
            }
            ieasyModule = angular.injector(['ieasy360']);
            loadDeviceName($rootScope);
            Utils.winLog('POS Start');
        }
        
    }]);

function canInitDatabase() {
	if(!AUTO_UPDATE.AUTO) { // 如果当前代码环境不允许自动更新,数据库仍然每次都需要初始化
		return true;
	}
	if(CONTEXT.env == CONSTANTS.EnvConstants.WINDOWS){ // windows环境
		return window.localStorage.getItem("isUpdatedYet") == "1";
	}
    else if(CONTEXT.env == CONSTANTS.EnvConstants.ANDROID){ // android环境
        return AndroidAdapter.isUpdated();
    }
    else if(CONTEXT.env == CONSTANTS.EnvConstants.IOS){ // IOS环境
        return IOSAdapter.isUpdated();
    }
	return true;
}

function onDatabaseInitedComplete() {
	if(CONTEXT.env == CONSTANTS.EnvConstants.WINDOWS){ // windows环境
		window.localStorage.removeItem("isUpdatedYet");
	}
    else if(CONTEXT.env == CONSTANTS.EnvConstants.ANDROID){ // android环境
        AndroidAdapter.onDatabaseInited();
    }
    else if(CONTEXT.env == CONSTANTS.EnvConstants.IOS){ // IOS
        IOSAdapter.onDatabaseInited();
    }
}

function gotoRemoteValidateInstallConfig(configObject, jqIP) {
    var getRemoteURL;

    var serverHost = SERVER_HOST.BASE_HOST;
    if (serverHost.toLowerCase().indexOf("http://") == -1) {
        serverHost = "http://" + serverHost;
    }
    var posURL = serverHost + API_CONTEXT.POS;
    if (CONTEXT.env == CONSTANTS.EnvConstants.WINDOWS) {
        getRemoteURL = posURL + INSTALL_CONFIG.GETINSTALLCONFIG_WIN.url + "?groupId=" + configObject.groupId + "&orgId=" + configObject.orgid + "&groupCode=" + configObject.groupCode + "&mac=" + configObject.mac;
    } else if (CONTEXT.env == CONSTANTS.EnvConstants.ANDROID) {
        getRemoteURL = posURL + INSTALL_CONFIG.GETINSTALLCONFIG_UDID.url + "?groupId=" + configObject.groupId + "&orgId=" + configObject.orgid + "&groupCode=" + configObject.groupCode + "&udid=" + configObject.udid;
    } else if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
        getRemoteURL = posURL + INSTALL_CONFIG.GETINSTALLCONFIG_UDID.url + "?groupId=" + configObject.groupId + "&orgId=" + configObject.orgid + "&groupCode=" + configObject.groupCode + "&udid=" + configObject.udid;
    }

    InstallConfigService.getRemoteInstallConfig(getRemoteURL, function (remoteConfigObject) {
        if (remoteConfigObject != null) {

            if (configObject.isMaster && !remoteConfigObject.isMaster)//主机切分机
            {
                InstallConfigService.saveLocal(remoteConfigObject);
                BIZCONSTANT.LOCALSTORAGE_INSTALLCONFIG = remoteConfigObject;

                return Utils.showFailureInfo("当前客户端已切换为分机");
            } else if (!configObject.isMaster && remoteConfigObject.isMaster) {//分机切主机

                InstallConfigService.removeLocalStorageInstallConfig();

                return Utils.showFailureInfo("当前客户端已切换为主机，请关闭软件重新登录");
            } else if (!configObject.isMaster && configObject.masterHost != remoteConfigObject.masterHost) {//修改了主机IP
                InstallConfigService.saveLocal(remoteConfigObject);
                BIZCONSTANT.LOCALSTORAGE_INSTALLCONFIG = remoteConfigObject;

                return Utils.showFailureInfo("当主机IP已更改为：" + remoteConfigObject.masterHost);
            } else if (configObject.isMaster && remoteConfigObject.isMaster && configObject.ip != jqIP) {//当前主机的本地IP发送了改变，需要上传给云端
                remoteConfigObject.ip = jqIP;
                configObject.ip = jqIP;

                var saveRemoteURL = SERVER_HOST.BASE_HOST + API_CONTEXT.POS + INSTALL_CONFIG.ADD_INSTALLCONFIG.url;
                InstallConfigService.saveRemote(saveRemoteURL, remoteConfigObject, function (config) {
                    InstallConfigService.saveLocal(configObject);
                });
            }
        } else {
            return Utils.showFailureInfo("云端安装信息已删除，请重新注册！");
        }
    },false);
}


/**
 * 读取硬件信息
 *
 * IP + 本地机器名称
 *
 * @param $rootScope
 */
function loadDeviceName($rootScope) {
    if (typeof require == 'function') {
        var iconv = require('iconv-lite')  
        var headers = {  
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/39.0.2171.65 Safari/537.36'
        }
        var os = require("os");
        var hostname = iconv.decode(os.hostname(), 'gb2312')
        var interfaces = os.networkInterfaces();
        var addresses = [];
        for (var k in interfaces) {
            for (var k2 in interfaces[k]) {
                var address = interfaces[k][k2];
                //console.log(address);
                if (address.family === 'IPv4' && !address.internal) {
                    addresses.push(address.address);
                }
            }
        }

        // 如果有多个地址，优先选择192.开头的
        //console.log(addresses);
        var final = addresses[0]; //默认取第一个
        angular.forEach(addresses, function (e) {
            if (e.indexOf("192") > -1) //有的VPN会有多个地址，优先去192.开头的
                final = e;
        });


        $rootScope.deviceName = final + "_" + hostname;
        $rootScope.IPPADD = final;
        $rootScope.DEVNAME = hostname;
        $rootScope.UDID = null;
        $rootScope.OS = "win";
        var os = require("getmac");
        os.getMac(function (err, macAddress) {
            if (err) {
                $.maskLoader("hide");
                return Utils.showFailureInfo("无法注册，获取不到机器MAC！");
            }
            $rootScope.MACADD = macAddress;
            console.info("mac : " + macAddress);
        });

    }
    else if (CONTEXT.env == CONSTANTS.EnvConstants.ANDROID) {
        $rootScope.deviceName = AndroidAdapter.getIp() + "_" + AndroidAdapter.getDeviceName();
        $rootScope.IPPADD = AndroidAdapter.getIp();
        $rootScope.MACADD = AndroidAdapter.getMacAddress();
        $rootScope.DEVNAME = AndroidAdapter.getDeviceName();
        $rootScope.UDID = AndroidAdapter.getUdid();
        $rootScope.OS = "android";
    }
    else if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
        $rootScope.deviceName = IOSAdapter.getIp() + "_" + IOSAdapter.getDeviceName();
        $rootScope.IPPADD = IOSAdapter.getIp();
        $rootScope.MACADD = IOSAdapter.getMacAddress();
        $rootScope.DEVNAME = IOSAdapter.getDeviceName();
        $rootScope.UDID = IOSAdapter.getUdid();
        $rootScope.OS = "ios";
    }
    else {
        $rootScope.deviceName = 'FAKE DEVICE,NOT IMPLEMENTED';
        console.log("获取不到硬件信息");
    }
}
// 数据库操作委托对象
function DatabaseFuncDelegate($q, database, tableName) {
    var self = this;

    self.getTableName = function () {
        return tableName;
    };

    self.query = function (sql, param) {
        return database.query(sql, param);
    };

    // 查询表记录
    // Usages 1: 查询表SomeTable所有的记录并返回
    // SomeTable.all().then(function(rows){
    //     处理rows的业务逻辑
    // });
    // 
    // Usages 2: 查询表SomeTable指定的记录并返回
    // SomeTable.all('col1=? and col2=?', ['col1 value', 'col2 value']).then(function(rows){
    //     处理rows的业务逻辑
    // });
    self.all = function (where, param) {
        var deferred = Utils.defer();//$q.defer();
        var sql = 'SELECT * FROM ' + self.getTableName();
        if (where) {
            database.query(sql + " WHERE " + where, param)
			.then(function (result) {
			    deferred.resolve(database.fetchAll(result));
			}, function (err) {
			    deferred.reject(err);
			});
        }
        else {
            database.query(sql).then(function (result) {
                deferred.resolve(database.fetchAll(result));
            }, function (err) {
                deferred.reject(err);
            });
        }
        return deferred.promise;
    };

    self.getById = function (id, idKey) {
        idKey = (idKey == null ? "id" : idKey);
        var deferred = Utils.defer();//$q.defer();
        var sql = 'SELECT * FROM ' + self.getTableName() + ' WHERE ' + idKey + ' = ?';
        database.query(sql, [id])
        .then(function (result) {
            deferred.resolve(database.fetch(result));
        }, function (err) {
            deferred.reject(err);
        });
        return deferred.promise;
    };

    // 在一个事务中执行多条sql命令
    // Usages:
    //
    // SomeTable.queryTransaction(
    //	[
    //		{query: 'insert into table1 (col1,col2,col3) values (?, ?, ?)',params:['val1', 'val2', 'val3']},
    //		{query: 'insert into table2 (col1,col2,col3) values (?, ?, ?)',params:['val1', 'val2', 'val3']},
    //		{query: 'insert into table3 (col1,col2,col3) values (?, ?, ?)',params:['val1', 'val2', 'val3']},
    //	]
    // ).then(function(rows){ /* 逻辑处理代码 */});
    self.queryTransaction = function (queryAndParamsArray) {
        return database.queryTransaction(queryAndParamsArray);
    };


    self._promiseError = function (deferred, message) {
        window.setTimeout(function () {
            deferred.reject({ message: message });
        }, 10);
    };

    self._buildWhere = function (data, update) {
        var arr = [];
        var param = [];
        if (typeof data == 'object') {
            for (var i in data) {
                arr.push(i + "=?");
                param.push(data[i]);
            }
        }
        if (Utils.isEmpty(update))
            return { sql: arr.join(' AND '), param: param };

        return { sql: arr.join(','), param: param };
    };


    // 插入新记录
    // Usages:
    // SomeTable.insert({col1: xx, col2: xx}).then(function(result){
    //     
    // });
    self.insert = function (data) {
        var deferred = Utils.defer();//$q.defer();
        if (typeof data != 'object') {
            self._promiseError(deferred, '要插入的数据不是合法的对象');
            return deferred.promise;
        }
        if (typeof data == 'array') {
            self.insertBatch(data).then(function (res) {
                deferred.resolve(res);
            }, function (err) {
                deferred.reject(err);
            });
            return deferred.promise;
        }
        var k = [];
        var v = [];
        var param = [];
        for (var i in data) {
            if (data[i] == null) { continue; }
            k.push(i);
            v.push('?');
            param.push(data[i]);
        }

        var sql = "INSERT INTO " + self.getTableName() + "(" + k.join(',') + ") VALUES (" + v.join(',') + ")";
        database.query(sql, param).then(function (result) {
            result.affectedItem = data;
            deferred.resolve(result);
        }, function (err) {
            deferred.reject(err);
        });

        return deferred.promise;
    };

    //整条数据获取插入的SQL语句
    self.getInsertsql = function (data) {

        var k = [];
        var v = [];
        var param = [];
        for (var i in data) {
            if (data[i] == null) { continue; }
            k.push(i);
            v.push('?');
            param.push(data[i]);
        }
        var sql = "INSERT INTO " + self.getTableName() + "(" + k.join(',') + ") VALUES (" + v.join(',') + ")";
        return {query:sql, params:param};
    };

    // 批量插入新记录
    // Usages:
    // SomeTable.insert([{col1: xx, col2: xx},{col1: xx, col2: xx}]).then(function(result){
    //  默认为insert into,第二个为可选参数，可传 REPLACE/replace   或者 IGNORE/ignore,将执行替换或者忽略
    // });
    self.insertBatch = function (dataList,sqlheader) {

        sqlheader = sqlheader ? (" OR "+sqlheader ): " ";

        var deferred = Utils.defer();//$q.defer();
        if (typeof dataList != 'object' || typeof (dataList.length) == 'undefined') {
            self._promiseError(deferred, '要插入的数据不是合法的对象,必须为数组格式');
            return deferred.promise;
        }
        if (dataList.length < 1) {
            deferred.resolve([]);
        }
        else {
            var sqls = [];
            for (var idx in dataList) {
                var data = dataList[idx];
                var k = [];
                var v = [];
                for (var i in data) {
                    if (data[i] == null) { continue; }
                    k.push(i);
                    v.push("'" + data[i] + "'");
                }
                sqls.push({ query: "INSERT " + sqlheader + " INTO " + self.getTableName() + "(" + k.join(',') + ") VALUES (" + v.join(',') + ")", params: [] });
            }
            database.queryTransaction(sqls).then(function (result) {
                deferred.resolve(result);
            }, function (err) {
                err.sql = sqls;
                deferred.reject(err);
            });
        }
        return deferred.promise;
    };

    // 批量插入新记录或替换已有记录
    // Usages:
    // SomeTable.insert([{col1: xx, col2: xx},{col1: xx, col2: xx}]).then(function(result){
    //     
    // });
    self.insertOrReplaceBatch = function (dataList) {
        return self.insertBatch(dataList, 'replace');
    };


    // 更新记录
    // Usages: 更新id为1的记录
    // SomeTable.update({col1: xx, col2: xx}, 'id=?', [1]).then(function(result){
    //     
    // });
    self.update = function (data, where, param) {
        var deferred = Utils.defer();//$q.defer();
        if (!param) {
            param = [];
        }
        if (typeof data != 'object') {
            self._promiseError('要更新的数据不是合法的对象');
            return deferred.promise;
        }
        var set_info = self._buildWhere(data, true);
        for (var i = set_info.param.length - 1; i >= 0; i--) {
            param.unshift(set_info.param[i]);
        }
        var sql = "UPDATE " + self.getTableName() + " SET " + set_info.sql;
        if (where) {
            sql += " WHERE " + where;
        }

        database.query(sql, param).then(function (result) {
            deferred.resolve(result);
        }, function (err) {
            deferred.reject(err);
        });
        return deferred.promise;
    };

    // 更新记录
    // Usages: 更新id为1的记录
    // SomeTable.updateObject({col1: xx, col2: xx}, 'id').then(function(result){
    //     
    // });
    self.updateObject = function (data, idKey) {
        var deferred = Utils.defer();//$q.defer();
        var param = [];
        if (typeof data != 'object') {
            self._promiseError('要更新的数据不是合法的对象');
            return deferred.promise;
        }
        var set_info = self._buildUpdateWhere(data, idKey);
        for (var i = set_info.param.length - 1; i >= 0; i--) {
            param.unshift(set_info.param[i]);
        }
        var sql = "UPDATE " + self.getTableName() + " SET " + set_info.sql + " WHERE " + idKey + "='" + data[idKey] + "'";
        database.query(sql, param).then(function (result) {
            deferred.resolve(result);
        }, function (err) {
            deferred.reject(err);
        });
        return deferred.promise;
    };

    self._buildUpdateWhere = function (data, idKey) {
        var arr = [];
        var param = [];
        if (typeof data == 'object') {
            for (var i in data) {
                if (i != idKey && data[i] != null) {
                    arr.push(i + "=?");
                    param.push(data[i]);
                }
            }
        }
        return { sql: arr.join(' , '), param: param };
    };

    // 删除记录
    // Usages: 删除id为1的记录
    // SomeTable.remove('id=?', [1]).then(function(result){
    //     
    // });
    self.remove = function (where, param) {
        var deferred = Utils.defer();//$q.defer();
        if (!param) {
            param = [];
        }
        var sql = "DELETE FROM " + self.getTableName() + " WHERE " + where;
        database.query(sql, param).then(function (result) {
            deferred.resolve(result);
        }, function (err) {
            deferred.reject(err);
        });
        return deferred.promise;
    };

    // 生成guid
    self.guid = function () {
        function S4() {
            return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1);
        };

        return (S4() + S4() + S4() + S4() + S4() + S4() + S4() + S4());
    };
};