function PrinterCommand(){};

PrinterCommand.controlCodes = {
    NUL: String.fromCharCode(0),
    EOT: String.fromCharCode(4),
    ENQ: String.fromCharCode(5),
    HT: String.fromCharCode(9),
    LF: String.fromCharCode(10),
    FF: String.fromCharCode(12),
    CR: String.fromCharCode(13),
    DLE: String.fromCharCode(16),
    DC4: String.fromCharCode(20),
    CAN: String.fromCharCode(24),
    ESC: String.fromCharCode(27),
    FS: String.fromCharCode(28),
    GS: String.fromCharCode(29)
};

// 初始化打印机
PrinterCommand.CMD_SetPos = function(){
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(64);
};

// 设置默认行间距
PrinterCommand.CMD_NormalLineSpacing = function(){
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(50);
};

// 设置默认行间距
PrinterCommand.CMD_SetLineSpacing = function(lineSpacing){
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(51) + String.fromCharCode(lineSpacing);
};

/// <summary>
/// 换行（回车）
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_Enter = function()
{
    return String.fromCharCode(10);
};

/// <summary>
/// 对齐模式
/// </summary>
/// <param name="align">0:左对齐 1:中对齐 2:右对齐</param>
/// <returns></returns>
PrinterCommand.CMD_TextAlign = function(align)
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(97) + String.fromCharCode(align);
}

/// <summary>
/// 选择/取消加粗模式
/// </summary>
/// <param name="align">0:取消加粗模式 1:选择加粗模式</param>
/// <returns></returns>
PrinterCommand.CMD_TextBold = function(bold)
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(69) + (""+bold);
}

/// <summary>
/// 鸣叫(适用于GP-80xxx系列)
/// </summary>
/// <param name="count">鸣叫次数</param>
/// <param name="leep">鸣叫间隔(leep*50毫秒)</param>
/// <returns></returns>
PrinterCommand.CMD_Beep = function(count, leep)
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(66) + String.fromCharCode(count) + String.fromCharCode(leep);
}

///<summary>
///Epson TM 220 Select Color
///</summary>
///<param name="color">48:Black 49:Red</param>
///<returns></returns>
PrinterCommand.CMD_Color = function(color)
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(114) + String.fromCharCode(color);
}

PrinterCommand.CMD_POS_DISPLAY = function(n){
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(115) + (""+n);   
};

PrinterCommand.CMD_POS_DISPLAY_Number = function(strNum){
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(81) + String.fromCharCode(65) + strNum + String.fromCharCode(13);   
};

PrinterCommand.CMD_NORMAL_ENTER = function(){
    return PrinterCommand.controlCodes.CR;
};

/// <summary>
/// 字体的大小
/// </summary>
/// <param name="nfontsize">0:正常大小 1:两倍高 2:两倍宽 3:两倍大小 4:三倍高 5:三倍宽 6:三倍大小 7:四倍高 8:四倍宽 9:四倍大小 10:五倍高 11:五倍宽 12:五倍大小</param>
/// <returns></returns>
PrinterCommand.CMD_FontSize = function(nfontsize)
{
    var _cmdstr = "";

    //设置字体大小
    switch (nfontsize)
    {
        case -1:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(0);//29 33
            break;

        case 0:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(0);//29 33
            break;

        case 1:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(1);
            break;

        case 2:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(16);
            break;

        case 3:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(17);
            break;

        case 4:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(2);
            break;

        case 5:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(32);
            break;

        case 6:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(34);
            break;

        case 7:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(3);
            break;

        case 8:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(48);
            break;

        case 9:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(51);
            break;

        case 10:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(4);
            break;

        case 11:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(64);
            break;

        case 12:
            _cmdstr = PrinterCommand.controlCodes.GS + String.fromCharCode(33) + String.fromCharCode(68);
            break;

    }
    return _cmdstr;
}

/// <summary>
/// BTP-M280(针打) 倍宽倍高
/// </summary>
/// <param name="size">0:取消倍宽倍高模式  1:倍高模式 2:倍宽模式 3:两倍大小</param>
/// <param name="style">0:无下划线 128：有下划线</param>
/// <returns></returns>
PrinterCommand.CMD_FontSize_BTP_M280 = function(size, style)
{
    var _cmdstr = "";
    //只有0和1两种模式
    var fontsize = size;

    switch (fontsize)
    {
        case 1:
            _cmdstr = PrinterCommand.controlCodes.FS + String.fromCharCode(33) + String.fromCharCode(8+style);
            break;
        case 2:
            _cmdstr = PrinterCommand.controlCodes.FS + String.fromCharCode(33) + String.fromCharCode(4+style);
            break;
        case 3:
            //_cmdstr = PrinterCommand.controlCodes.FS + ((Char)87).ToString() + ((Char)1).ToString();
            _cmdstr = PrinterCommand.controlCodes.FS + String.fromCharCode(33) + String.fromCharCode(12+style);
            break;
        default:
            //_cmdstr = PrinterCommand.controlCodes.FS + ((Char)87).ToString() + ((Char)0).ToString();
            _cmdstr = PrinterCommand.controlCodes.FS + String.fromCharCode(33) + String.fromCharCode(style);
            break;
    }

    return _cmdstr;
}

/// <summary>
/// BTP-M280(针打) 倍宽倍高
/// </summary>
/// <param name="size">0:取消倍宽倍高模式  1:倍高模式 2:倍宽模式 3:两倍大小</param>
/// <param name="style">0:无下划线 128：有下划线</param>
/// <returns></returns>
PrinterCommand.CMD_FontSize_BTP_M2801 = function(size, style)
{
    var _cmdstr = "";
    //只有0和1两种模式
    var fontsize = size;

    switch (fontsize)
    {
        case 1:
            _cmdstr = PrinterCommand.controlCodes.ESC + String.fromCharCode(33) + String.fromCharCode(17+style);
            break;
        case 2:
            _cmdstr = PrinterCommand.controlCodes.ESC + String.fromCharCode(33) + String.fromCharCode(33+style);
            break;
        case 3:
            _cmdstr = PrinterCommand.controlCodes.ESC + String.fromCharCode(33) + String.fromCharCode(49+style);
            break;
        default:
            _cmdstr = PrinterCommand.controlCodes.ESC + String.fromCharCode(33) + String.fromCharCode(1+style);
            break;
    }

    return _cmdstr;
}

/// <summary>
/// 走纸
/// </summary>
/// <param name="line">走纸的行数</param>
/// <returns></returns>
PrinterCommand.CMD_PageGO = function(line)
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(100) + String.fromCharCode(line);
}

/// <summary>
/// 切割
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_CutPage = function()
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(109);
}

/// <summary>
/// 选择切纸模式并切纸
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_HalfCutPage = function()
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(86) + String.fromCharCode(1);
}

/// <summary>
/// 返回状态(返回8位的二进制)
/// </summary>
/// <param name="num">1:打印机状态 2:脱机状态 3:错误状态 4:传送纸状态</param>
/// 返回打印机状态如下：
/// 第一位：固定为0
/// 第二位：固定为1
/// 第三位：0:一个或两个钱箱打开  1:两个钱箱都关闭
/// 第四位：0:联机  1:脱机
/// 第五位：固定为1
/// 第六位：未定义
/// 第七位：未定义
/// 第八位：固定为0
/// 
/// 返回脱机状态如下：
/// 第一位：固定为0
/// 第二位：固定为1
/// 第三位：0:上盖关  1:上盖开
/// 第四位：0:未按走纸键  1:按下走纸键
/// 第五位：固定为1
/// 第六位：0:打印机不缺纸  1: 打印机缺纸
/// 第七位：0:没有出错情况  1:有错误情况
/// 第八位：固定为0
/// 
/// 返回错误状态如下：
/// 第一位：固定为0
/// 第二位：固定为1
/// 第三位：未定义
/// 第四位：0:切刀无错误  1:切刀有错误
/// 第五位：固定为1
/// 第六位：0:无不可恢复错误  1: 有不可恢复错误
/// 第七位：0:打印头温度和电压正常  1:打印头温度或电压超出范围
/// 第八位：固定为0
/// 
/// 返回传送纸状态如下：
/// 第一位：固定为0
/// 第二位：固定为1
/// 第三位：0:有纸  1:纸将尽
/// 第四位：0:有纸  1:纸将尽
/// 第五位：固定为1
/// 第六位：0:有纸  1:纸尽
/// 第七位：0:有纸  1:纸尽
/// 第八位：固定为0
/// <returns></returns>
PrinterCommand.CMD_ReturnStatus = function(num)
{
    return PrinterCommand.controlCodes.DLE + PrinterCommand.controlCodes.EOT + String.fromCharCode(num);
}

/// <summary>
/// 条码高宽
/// </summary>
/// <param name="num"></param>
/// <returns></returns>
PrinterCommand.CMD_TiaoMaHeight = function(num)
{
    //return (PrinterCommand.controlCodes.ESC + "h" + ((Char)num).ToString();
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(104) + String.fromCharCode(num);
}

/// <summary>
/// 条码宽度
/// </summary>
/// <param name="num"></param>
/// <returns></returns>
PrinterCommand.CMD_TiaoMaWidth = function(num)
{
    //return (PrinterCommand.controlCodes.ESC + "w" + ((Char)num).ToString();   
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(119) + String.fromCharCode(num);
}

/// <summary>
/// 条码数字打印的位置
/// </summary>
/// <param name="num">1:上方  2:下方  0:不打印数字</param>
/// <returns></returns>
PrinterCommand.CMD_TiaoMaWeiZi = function(num)
{
    return PrinterCommand.controlCodes.ESC + "H" + String.fromCharCode(num);
}

/// <summary>
/// 开始打印(条码类型为CODE39)
/// </summary>
/// <param name="numstr"></param>
/// <returns></returns>
PrinterCommand.CMD_TiaoMaPrint = function(mumstr)
{
    //return (PrinterCommand.controlCodes.ESC + "k" + ((Char)4).ToString() + numstr + ((Char)0).ToString();
    //string txm = (PrinterCommand.controlCodes.ESC + ((Char)107).ToString() + ((Char)4).ToString();

    //char[] numslist = numstr.ToCharArray();
    //if (numslist != null && numslist.Length > 0)
    //{
    //    int charint = 0;
    //    foreach (char nums in numslist)
    //    {
    //        if (int.TryParse(nums.ToString(), out charint))
    //        {
    //            txm += ((Char)(charint + 48)).ToString();
    //        }
    //    }
    //}

    return PrinterCommand.controlCodes.ESC + String.fromCharCode(107) + String.fromCharCode(4) + numstr + String.fromCharCode(0);
    //return txm + ((Char)0).ToString();
}

/// <summary>
/// 打开钱箱
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_QianXiang = function()
{
    return PrinterCommand.controlCodes.ESC + String.fromCharCode(112) + String.fromCharCode(0) + String.fromCharCode(60) + String.fromCharCode(255);
}


/// <summary>
/// 清除缓存
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_QingChuHuanChong = function()
{
    return PrinterCommand.controlCodes.CAN;
}

/// <summary>
/// 初始化
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_MonitorAlgin = function()
{
    var controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x40); //"ESC @";
    return controlstr;
}

/// <summary>
/// 清屏
/// </summary>
/// <returns></returns>
PrinterCommand.CMD_MonitorCLR = function()
{
    return String.fromCharCode(0x0c);
}

/// <summary>
/// 
/// </summary>
/// <param name="light">0:全灭 1:单价  2:总计  3:收款  4:找零</param>
/// <returns></returns>
PrinterCommand.CMD_MonitorLight = function(light)
{
    var controlstr = "";
    switch (light)
    {
        case 0:
            controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x1b) + String.fromCharCode(0x73) + String.fromCharCode(0x30);
            break;

        case 1:
            controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x1b) + String.fromCharCode(0x73) + String.fromCharCode(0x31);
            break;

        case 2:
            controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x1b) + String.fromCharCode(0x73) + String.fromCharCode(0x32);
            break;

        case 3:
            controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x1b) + String.fromCharCode(0x73) + String.fromCharCode(0x33);
            break;

        case 4:
            controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x1b) + String.fromCharCode(0x73) + String.fromCharCode(0x34);
            break;
    }

    return controlstr;
}

/// <summary>
/// 显示数字
/// </summary>
/// <param name="num"></param>
/// <returns></returns>
PrinterCommand.CMD_MonitorNum = function(num)
{
    var controlstr = String.fromCharCode(0x1b) + String.fromCharCode(0x51) + String.fromCharCode(0x41) + (""+num) + String.fromCharCode(0x0d);
    //controlstr = "ESC Q A " + num.ToString();
    return controlstr;
}

/// <summary>
/// 打印logo
/// </summary>
/// <param name="n">图片号</param>
/// <param name="m">0：正常 1：倍宽 2：倍高 3：倍高倍宽</param>
/// <returns></returns>
PrinterCommand.CMD_PrintLogo = function(n, m)
{
    return PrinterCommand.controlCodes.FS + String.fromCharCode(112) + String.fromCharCode(n) + String.fromCharCode(m);
}

function PrinterProxy(printer) {
    this.printer = printer;
    this.bufferStr = "";
    this.iconv = null;
    if(typeof(require) != 'undefined'){
        this.iconv = require("iconv-lite");
    }

    this.init = function(){
        this.printCommand(PrinterCommand.CMD_SetPos());
    };

    this.text = function(txt) {
        this.bufferStr += txt;
        /*
        var buffer = this.iconv.encode(txt, 'gbk');
        this.printer.print(buffer);
        */
    };

    this.printCommand = function(txt) {
        this.bufferStr += txt;
        /*
        var buffer = this.iconv.encode(txt, 'ascii');
        this.printer.print(buffer);
        */
    };
	
	this.getCommandText = function(){
		return this.bufferStr;
	};

    this.flush = function(){
        var buffer = Utils.encodeBuffer(this.bufferStr, 'gbk');
        this.printer.print(buffer);
        this.printer.flush();
    };
}

var centerText = function(txt, lineWidth) {
    if (txt.length < lineWidth - 2) {
        var pad = "";
        var nbSpaces = (lineWidth - txt.length) / 2;
        for (var i = 0; i < nbSpaces; i++) {
            pad += " ";
        }
        return pad + txt;
    } else {
        return txt;
    }
};

PrinterProxy.prototype.printNormal = function(txt) {
    this.text(txt);
};

PrinterProxy.prototype.printEmptyLine = function(txt) {
    this.text("\n\r");
};

PrinterProxy.prototype.printLine = function(txt) {
    this.text(txt + "\n\r");
};

PrinterProxy.prototype.printCentered = function(txt) {
    this.text(centerText(txt, 40) + "\n\r");
};

PrinterProxy.prototype.printCenteredLen = function(txt, len) {
    this.text(centerText(txt, len) + "\n\r");
};

/// <summary>
/// 鸣叫(适用于GP-80xxx系列)
/// </summary>
/// <param name="count">鸣叫次数</param>
/// <param name="leep">鸣叫间隔(leep*50毫秒)</param>
PrinterProxy.prototype.NetPrinter_Beep = function(count, leep)
{
    var command = PrinterCommand.CMD_Beep(count, leep);
    this.printCommand(command);
}

/// <summary>
/// Epson TM 220 Select Color
/// </summary> 
/// <param name="color">48:Black 49:Red</param>
PrinterProxy.prototype.NetPrinter_Color = function(color)
{
    this.printCommand(PrinterCommand.CMD_Color(color));
}

/// <summary>
/// 网络打印机 打印的文本
/// </summary>
/// <param name="pszString"></param>
/// <param name="nFontAlign">0:居左 1:居中 2:居右</param>
/// <param name="nfontsize">字体大小0:正常大小 1:两倍高 2:两倍宽 3:两倍大小 4:三倍高 5:三倍宽 6:三倍大小 7:四倍高 8:四倍宽 9:四倍大小 10:五倍高 11:五倍宽 12:五倍大小</param>
/// <param name="nFontStyle">字体样式 0：正常 1：粗体 2：下划线 3：粗体+下划线 </param>
/// <param name="color">字体颜色 0：黑 1：红 </param>
/// <param name="ifzhenda">0:非针打  1:针打</param> 
PrinterProxy.prototype.NetPrinter_TextOut = function(pszString, nFontAlign, nFontSize, nFontStyle, color, ifzhenda)
{
    nFontAlign = nFontAlign == null ? 0 : nFontAlign;
    nFontSize = nFontSize == null ? 0 : nFontSize;
    ifzhenda = ifzhenda == null ? 0 : ifzhenda;
    //var ifzhenda = parseInt(CONSTANTS.SystemConfigs["PrinterIsZhenda"].SystemConfigValue);
    nFontStyle = nFontStyle == null ? 0 : nFontStyle;
    color = color == null ? 0 : color;

    if (color > 0)
    {
        this.NetPrinter_Color(49);
    }
    this.printCommand(PrinterCommand.CMD_TextAlign(nFontAlign));

    var command = "";
    if (ifzhenda == 1)
    {
        if (nFontStyle > 1)
            command = PrinterCommand.CMD_FontSize_BTP_M280(nFontSize, 128);
        else
            command = PrinterCommand.CMD_FontSize_BTP_M280(nFontSize, 0);

        this.printCommand(command);

        if (nFontStyle > 1)
            command = PrinterCommand.CMD_FontSize_BTP_M2801(nFontSize, 128);
        else
            command = PrinterCommand.CMD_FontSize_BTP_M2801(nFontSize, 0);

        this.printCommand(command);
    }
    else
    {
        command = PrinterCommand.CMD_FontSize(nFontSize);
        this.printCommand(command);
    }

    command = pszString;// +CMD_Enter();
    this.text(command);
}

/// <summary>
/// 网络打印机 打印的文本
/// </summary>
/// <param name="pszString"></param>
/// <param name="nFontAlign">0:居左 1:居中 2:居右</param>
/// <param name="nfontsize">字体大小0:正常大小 1:两倍高 2:两倍宽 3:两倍大小 4:三倍高 5:三倍宽 6:三倍大小 7:四倍高 8:四倍宽 9:四倍大小 10:五倍高 11:五倍宽 12:五倍大小</param>
/// <param name="ifzhenda">0:非针打  1:针打</param> 
PrinterProxy.prototype.NetPrinter_TextOut_Normal = function(pszString, nFontAlign, nFontSize, ifzhenda)
{
    nFontAlign = nFontAlign == null ? 0 : nFontAlign;
    nFontSize = nFontSize == null ? 0 : nFontSize;
    ifzhenda = ifzhenda == null ? 0 : ifzhenda;
    //ifzhenda = parseInt(CONSTANTS.SystemConfigs["PrinterIsZhenda"].SystemConfigValue);
    this.NetPrinter_TextOut(pszString, nFontAlign, nFontSize, 0, 0, ifzhenda);
}

/// <summary>
/// 网络打印机 打印的文本
/// </summary>
/// <param name="pszString"></param>
/// <param name="nFontAlign">0:居左 1:居中 2:居右</param>
/// <param name="nfontsize">字体大小0:正常大小 1:两倍高 2:两倍宽 3:两倍大小 4:三倍高 5:三倍宽 6:三倍大小 7:四倍高 8:四倍宽 9:四倍大小 10:五倍高 11:五倍宽 12:五倍大小</param>
/// <param name="ifzhenda">0:非针打  1:针打</param> 
PrinterProxy.prototype.NetPrinter_TextOut_ColorRed= function(pszString,nFontAlign,nFontSize,color,ifzhenda)
{
    nFontAlign = nFontAlign == null ? 0 : nFontAlign;
    nFontSize = nFontSize == null ? 0 : nFontSize;
    ifzhenda = ifzhenda == null ? 0 : ifzhenda;
    //ifzhenda = parseInt(CONSTANTS.SystemConfigs["PrinterIsZhenda"].SystemConfigValue);
    this.NetPrinter_TextOut(pszString, nFontAlign, nFontSize, 0, 1, ifzhenda);
}

/// <summary>
/// 恢复默认行间距
/// </summary>
PrinterProxy.prototype.NetPrinter_NormalLineSpacing = function()
{
    this.text(PrinterCommand.CMD_NormalLineSpacing());
}

/// <summary>
/// 设置行间距 默认30
/// </summary>
PrinterProxy.prototype.NetPrinter_SetLineSpacing = function(spacing)
{
    this.text(PrinterCommand.CMD_SetLineSpacing(spacing));
}

/// <summary>
/// 网络打印机 回车
/// </summary>
PrinterProxy.prototype.NetPrinter_Enter = function()
{
    this.text(PrinterCommand.CMD_Enter());
}

/// <summary>
/// 网络打印机 切割
/// </summary>
/// <param name="pagenum">切割时，走纸行数</param>
PrinterProxy.prototype.NetPrinter_CutPage = function(pagenum)
{
    this.printCommand(PrinterCommand.CMD_PageGO(pagenum) + PrinterCommand.CMD_Enter());
    this.printCommand(PrinterCommand.CMD_CutPage() + PrinterCommand.CMD_Enter());
}

/// <summary>
/// 网络打印机 切割
/// </summary>
/// <param name="pagenum">切割时，走纸行数</param>
PrinterProxy.prototype.NetPrinter_HalfCutPage = function(pagenum)
{
    this.printCommand(PrinterCommand.CMD_PageGO(pagenum) + PrinterCommand.CMD_Enter());
    this.printCommand(PrinterCommand.CMD_HalfCutPage() + PrinterCommand.CMD_Enter());
}

/// <summary>
/// 网络打印机换行
/// </summary>
/// <param name="lines"></param>
PrinterProxy.prototype.NetPrinter_FeedLines = function(lines)
{
    this.printCommand(PrinterCommand.CMD_FontSize(0));
    var command = "";
    for (var i = 0; i < lines; i++)
    {
        command = "" + PrinterCommand.CMD_Enter();
        this.text(command);
    }
}

/// <summary>
/// 打开钱箱
/// </summary>
PrinterProxy.prototype.NetPrinter_QianXiang = function()
{
    var command = "" + PrinterCommand.CMD_QianXiang();
    this.text(command);
}

PrinterProxy.prototype.NetPrinter_InitPrinter = function()
{
    var command = "" + PrinterCommand.CMD_SetPos();
    this.text(command);
}

/// <summary>
/// 打印条码
/// </summary>
/// <param name="numstr"></param>
/// <param name="height"></param>
/// <param name="width"></param>
/// <param name="numweizi">1:上方  2:下方  0:不打印数字</param>
/// <param name="fontalign">0:居左 1:居中 2:居右</param>
/// <param name="fontsize">字体大小0:正常大小 1:两倍高 2:两倍宽 3:两倍大小 4:三倍高 5:三倍宽 6:三倍大小 7:四倍高 8:四倍宽 9:四倍大小 10:五倍高 11:五倍宽 12:五倍大小</param>
PrinterProxy.prototype.NetPrinter_TiaoMa = function(numstr,height,width,numweizi,fontalign,fontsize)
{
    this.text(PrinterCommand.CMD_TiaoMaHeight(height));

    this.text(PrinterCommand.CMD_TiaoMaWidth(width));

    this.text(PrinterCommand.CMD_TiaoMaWeiZi(numweizi));

    this.printCommand(PrinterCommand.CMD_TextAlign(fontalign));

    this.printCommand(PrinterCommand.CMD_FontSize(fontsize));
    
    this.text(PrinterCommand.CMD_TiaoMaPrint(numstr));
}

/// <summary>
/// 打印logo
/// </summary>
/// <param name="n">图片号</param>
/// <param name="m">0：正常 1：倍宽 2：倍高 3：倍高倍宽</param>
PrinterProxy.prototype.NetPrinter_Logo = function(n, m)
{
    this.text(PrinterCommand.CMD_PrintLogo(n,m));
}

/// 打印虚线并且换行
/// <param name="paperWidth">80还是58</param>
PrinterProxy.prototype.NetPrinter_DashLine = function(paperWidth){
    paperWidth = paperWidth == null ? 58 : paperWidth;
    //if(CONSTANTS.SystemConfigs["PrinterSize"] == null ||
    //    CONSTANTS.SystemConfigs["PrinterSize"].SystemConfigValue == "58"){
    //    paperWidth = 58;
    //}
    //else{
    //    paperWidth = 80;
    //}
    var totalNumber  = paperWidth / 1.904761904761905;
    if(paperWidth == 80){
        totalNumber = 42;
    }
    else {
        totalNumber = Math.round(totalNumber);
    }
    var dashLine = "";
    for(var i=0; i<totalNumber;i++){
        dashLine += "-";
    }
    this.NetPrinter_TextOut_Normal(dashLine);
    this.NetPrinter_Enter();
};

PrinterProxy.prototype.PosDisplay_SetStatus = function(n){
    this.printCommand(PrinterCommand.CMD_POS_DISPLAY(n));
}

// numstr:  eg: "127.123"  
PrinterProxy.prototype.POS_DISPLAY_NUMBER = function(numstr){
    this.printCommand(PrinterCommand.CMD_POS_DISPLAY_Number(numstr));
};

PrinterProxy.prototype.POS_DISPLAY_ENTER = function(){
    this.printCommand(PrinterCommand.CMD_NORMAL_ENTER());
};