var WebServer = {
    server: null
};

WebServer.startup = function () {
    if (CONTEXT.env == CONSTANTS.EnvConstants.WINDOWS) {
        var http = require("http");

        WebServer.server = new http.Server();

        WebServer.server.on('request', function (request, response) {
            var headers = request.headers;
            var method = request.method;
            var url = request.url;
            var body = [];
            if (method == "POST") {
                request.on('error', function (err) {
                    console.error(err);
                }).on('data', function (chunk) {
                    body.push(chunk);
                }).on('end', function () {
                    body = Buffer.concat(body).toString();
                    wsrouter(body, response);
                });
            } else {
                response.writeHead(200, {
                    "Content-Type": "text/plain",
                    "Access-Control-Allow-Origin": "*",
                    "Access-Control-Allow-Methods": "GET, POST, OPTIONS",
                    "Access-Control-Allow-Headers": "X-Requested-With, Content-Type"
                });
                response.write("ONLY POST SUPPORTED.");
                response.end();
            }
        });

        WebServer.server.listen(WEB_SERVER.PORT);

        WebServer.server.on('error', function (e) {
            if (e.code == 'EADDRINUSE') {
                window.setTimeout(function () {
                    WebServer.server.close();
                    WebServer.server.listen(WEB_SERVER.PORT);
                }, 1000);
            }
        });

        process.on('exit', function () {
            WebServer.shutdown();
        });
    }
    else if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
        IOSAdapter.webServerStartup();
    }
    else {
        WebServer.server = window.webserver;
        WebServer.server.startup();
    }
    SocketServer.startup();
};

WebServer.shutdown = function () {
    if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
        IOSAdapter.webServerShutdown();
    }
    else {
        WebServer.server.close();
        SocketServer.shutdown();
    }
};

WebServer.restart = function () {
    WebServer.shutdown();
    WebServer.startup();
};

var SocketServer = {server: null};

SocketServer.startup = function () {
    if (CONTEXT.env == CONSTANTS.EnvConstants.ANDROID) {
        window.socketserver.startup();
    } else if (CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
        IOSAdapter.socketServerStartup();
    } else {
        var net = require('net');

        var crypto = require('crypto');
        var WS = '258EAFA5-E914-47DA-95CA-C5AB0DC85B11';

        //var io=require('socket.io');
        SocketServer.server = net.createServer();
        var clientList = [];

        SocketServer.server.on('connection', function (client) {
            client.name = client.remoteAddress + ':' + client.remotePort;
            console.log("clien.name : " + client.name);
            var key;
            clientList.push(client);

            client.on('data', function (e) {

                if (!key) {
                    //握手
                    try{
                        key = e.toString().match(/Sec-WebSocket-Key: (.+)/)[1];
                        key = crypto.createHash('sha1').update(key + WS).digest('base64');
                        client.write('HTTP/1.1 101 Switching Protocols\r\n');
                        client.write('Upgrade: websocket\r\n');
                        client.write('Connection: Upgrade\r\n');
                        client.write('Sec-WebSocket-Accept: ' + key + '\r\n');
                        client.write('\r\n');
                    }catch (e){};
                } else {
                    var frame = decodeDataFrame(e);
                    if (frame.Opcode)
                        if (frame.Opcode == 8) {
                            return client.end(); //断开连接
                        }
                    console.log("frame : ");
                    console.log(frame);
                    SocketServer.broadcast(frame.PayloadData, client);
                };

            });

            client.on('end', function () {
                console.log('end-----finish');
                clientList.splice(clientList.indexOf(client), 1);
            });

            function decodeDataFrame(e) {
                var i = 0, j, s, frame = {
                    //解析前两个字节的基本数据
                    FIN: e[i] >> 7, Opcode: e[i++] & 15, Mask: e[i] >> 7,
                    PayloadLength: e[i++] & 0x7F
                };
                //处理特殊长度126和127
                if (frame.PayloadLength == 126)
                    frame.length = (e[i++] << 8) + e[i++];
                if (frame.PayloadLength == 127)
                    i += 4, //长度一般用四字节的整型，前四个字节通常为长整形留空的
                    frame.length = (e[i++] << 24) + (e[i++] << 16) + (e[i++] << 8) + e[i++];
                //判断是否使用掩码
                if (frame.Mask) {
                    //获取掩码实体
                    frame.MaskingKey = [e[i++], e[i++], e[i++], e[i++]];
                    //对数据和掩码做异或运算
                    for (j = 0, s = []; j < frame.PayloadLength; j++)   //因为是文本帧，直接使用frame.length，其他情况下需要根据frame.PayloadLength 处理
                        s.push(e[i + j] ^ frame.MaskingKey[j % 4]);
                } else s = e.slice(i, frame.PayloadLength); //否则直接使用数据
                //数组转换成缓冲区来使用
                s = new Buffer(s);
                //如果有必要则把缓冲区转换成字符串来使用
                if (frame.Opcode == 1) s = s.toString();
                //设置上数据部分
                frame.PayloadData = s;
                //返回数据帧
                return frame;
            }

            SocketServer.encodeDataFrame = function (message) {
                message = String(message);
                var length = Buffer.byteLength(message);

                //  数据的起始位置，如果数据长度16位也无法描述，则用64位，即8字节，如果16位能描述则用2字节，否则用第二个字节描述
                var index = 2 + (length > 65535 ? 8 : (length > 125 ? 2 : 0));

                //  定义buffer，长度为描述字节长度 + message长度
                var buffer = new Buffer(index + length);

                //  第一个字节，fin位为1，opcode为1
                buffer[0] = 129;

                //    因为是由服务端发至客户端，所以无需masked掩码
                if (length > 65535) {
                    buffer[1] = 127;

                    //      长度超过65535的则由8个字节表示，因为4个字节能表达的长度为4294967295，已经完全够用，因此直接将前面4个字节置0
                    buffer.writeUInt32BE(0, 2);
                    buffer.writeUInt32BE(length, 6);
                } else if (length > 125) {
                    buffer[1] = 126;

                    //      长度超过125的话就由2个字节表示
                    buffer.writeUInt16BE(length, 2);
                } else {
                    buffer[1] = length;
                }

                //    写入正文
                buffer.write(message, index);
                return buffer;
            }

        });

        process.on('exit', function () {
            SocketServer.shutdown();
        });

        //广播，给所有连接的客户端发送消息
        /*function broadcast(message, client) {

        }*/
        //广播，给所有连接的客户端发送消息
        SocketServer.broadcast = function (message) {
            message = SocketServer.encodeDataFrame(message);
            // console.log("broadcast message : " + message);
            var cleanup = []
            for (var i = 0; i < clientList.length; i += 1) {
                if(clientList[i].name.indexOf("127.0.0.1") >= 0) continue;
                if (clientList[i].writable) { // 先检查 sockets 是否可写

                    //for(var c=0;c<message.length;c++)
                    clientList[i].write(message);

                } else {
                    cleanup.push(clientList[i]) // 如果不可写，收集起来销毁。销毁之前要 Socket.destroy() 用 API 的方法销毁。
                    clientList[i].destroy()
                }
            }

            for (i = 0; i < cleanup.length; i += 1) {
                clientList.splice(clientList.indexOf(cleanup[i]), 1)
            }
        }
        SocketServer.server.listen(WEB_SERVER.SOCEKTPORT);
    }
}
SocketServer.shutdown = function () {
    SocketServer.server.close();
    //SocketServer.shutdown();
}