app.factory('CanbieService', ['$q', 'database', function ($q, database) {
    var CanbieService = {};

    var canbieDao = new DatabaseFuncDelegate($q, database, 'pos_canbie');

    /*JP 2016-03-10 获取当前餐别
    * date 默认当前时间
    *获取餐别的同时还获取了餐别的时间范围   分别存储在 formatStarttime 和 formatEndtime  
    */
    CanbieService.getCurrentCanBie = function (cb, date) {
        canbieDao.query("select * from pos_canbie where isDeleted <> '1' ")
        .then(function (result) {
            if (result.detail.length < 1)
                return cb({ message: "找不到餐别数据，请联系我司相关的工作人员" });

            if (result.detail.length == 1)
                return cb(null, result.detail[0])

            var canbie = Utils.getCanbieByTime(result.detail, date);
            return cb(null, canbie); // {message:"非餐厅营业时间，匹配不到餐别：" + date.format("yyyy-MM-dd hh:mm:ss")}
        }, function (error) {
            return cb(error);
        });
    };

    /*JP 2016-03-10
    获取所有餐别信息*/
    CanbieService.getAllCanbie = function (cb) {
        canbieDao.all(" isDeleted <> '1' ")
     .then(function (result) {
         var canbies = [];
         if (result.length < 1) {
             return cb({ message: "未设置最后餐别数据，请联系我司相关的工作人员" });
         }

         for (var idx in result) {
             var canbie = result[idx];

             canbies.push(dbModelToViewModel(canbie));
         }
         return cb(null, canbies);
     }, function (err) {
         return cb(err);
     })
    }

    function dbModelToViewModel(dbModal) {
        var canbie = new CanbieInfo();
        canbie.guid = dbModal.guid;
        canbie.code = dbModal.code;
        canbie.name = dbModal.name;
        canbie.starttime = dbModal.starttime;
        canbie.eattime = dbModal.eattime;
        canbie.endtime = dbModal.endtime;
        canbie.formatStarttime = dbModal.formatStarttime;
        canbie.formatEattime = dbModal.formatEattme;
        canbie.formatEndtime = dbModal.formatEndtime;
        //canbie.operatorId = null;
        //canbie.operatorCode = null;
        //canbie.operatorName = null;
        //canbie.operatorTime = new Date();
        return canbie;
    }


    CanbieService.isLastCanbieByCurTime = function (cb, date) {

        canbieDao.all(" isDeleted <> '1' ")
       .then(function (result) {
           if (result.length < 1) {
               return cb({ message: "未设置最后餐别数据，请联系我司相关的工作人员" });
           }

           date = date == null ? new Date() : (typeof date == "object") ? date : new Date(date);
           var curTime = Utils.formatDate(date, "yyyy-MM-dd hh:mm:ss");

           for (var idx in result) {
               var canbie = result[idx];

               var endTime = canbie.endtime;
               if (canbie.starttime > canbie.endtime)
                   endTime = parseInt(canbie.endtime) + 86400;

               if (canbie.starttime <= canbieTime && canbieTime <= endTime) {
                   if (endTime > 86400) {
                       canbie.starttime = date.AddTime(0, 0, -1).format("yyyy-MM-dd") + " " + canbie.formatStarttime;
                   } else {
                       canbie.starttime = date.format("yyyy-MM-dd") + " " + canbie.formatStarttime;
                   }
                   canbie.starttime = date.format("yyyy-MM-dd") + " " + canbie.formatEndtime;

                   return cb(null, canbie);
               }
           }
           return cb(null, null); // {message:"非餐厅营业时间，匹配不到餐别：" + date.format("yyyy-MM-dd hh:mm:ss")}
       }, function (error) {
           return cb(error);
       });
    }



    return CanbieService;
}]);