app.factory('OrderMenuService', ['$q', 'database', 'CanbieService','SystemConfigService', function ($q,database,CanbieService,SystemConfigService) {
    var OrderMenuService = {};

    var dishService = new DatabaseFuncDelegate($q, database, 'base_dish');
    var tasteService = new DatabaseFuncDelegate($q, database, 'base_kouwei');
    var cwkmService = new DatabaseFuncDelegate($q, database, 'base_caiwukemu');

    /**
    [
        {
            dish_typeid: null,
            DishType_Name: "",
            DishType_Code: ""
            dishList: [
                {
                    md_dishid: null,
                    md_dishprice: null,
                    dishid: null,
                    Dish_Code: "",
                    Dish_Name: "",
                    Dish_QuickCode: "",
                    images: [
                        {
                            dish_picid: null,
                            dish_picurl: ""
                        }
                    ],
                    units: [
                        {
                            unitid: null,
                            unitname: ""
                        }
                    ]
                }
            ],
            unitList: [
                {
                    unitid: null,
                    unitname: ""
                }
            ]
        }
    ]
    */
    OrderMenuService.getSalesDishWithTypeUnit = function(){
        var sql = "select d.id as dishid, "+
                    "d.Dish_Code, d.Dish_Name, d.Dish_QuickCode, d.Dish_SalePrice, dt.id as dish_typeid, dt.DishType_Code,dt.DishType_Name,dt.DishType_IfFenTan, "+
                    "dp.id as dish_picid, dp.Pic_DataString as dish_picurl, cw.id as cwlxid, cw.CWLX_Name as cwlxname "+
                    "from  base_dish d "+
                    "inner join base_dish_type dt on d.Dish_Status = 1 and dt.id = d.DishType_ID and dt.DishType_Status = 1 "+
                    "inner join base_caiwuleixing cw on cw.id = d.Dish_CWLX_ID "+
                    "left join base_dish_pic dp on dp.Dish_ID = d.id "+
                    "order by dt.AddTime asc,d.Dish_Name asc";
        return Utils.deferredCallback($q, dishService.query(sql), function(result){
            var output = [];
            for (var i = 0; i < result.rows.length; i++) {
                var rowItem = result.rows.item(i);
                var dishTypeObj = Utils.arrayFind(output, rowItem.dish_typeid, "dish_typeid");
                if(dishTypeObj == null){
                    dishTypeObj = {
                        dish_typeid: rowItem.dish_typeid,
                        DishType_Name: rowItem.DishType_Name,
                        DishType_Code: rowItem.DishType_Code,
                        DishType_IfFenTan: rowItem.DishType_IfFenTan,
                        dishList: [],
                        unitList: [
                            {unitid: "1", unitname: "例", scale: 1},
                            {unitid: "2", unitname: "中", scale: parseFloat((CONSTANTS.SystemConfigs["MiddleScale"] == null ? "1.5":CONSTANTS.SystemConfigs["MiddleScale"].SystemConfigValue))},
                            {unitid: "3", unitname: "大", scale: parseFloat((CONSTANTS.SystemConfigs["BigScale"] == null ? "2":CONSTANTS.SystemConfigs["BigScale"].SystemConfigValue))}
                        ]
                    };
                    output.push(dishTypeObj);
                }
                var dishObj = Utils.arrayFind(dishTypeObj.dishList, rowItem.dishid, "dishid");
                if(dishObj == null){
                    dishObj = {
                        md_dishid: rowItem.dishid,
                        md_dishprice: rowItem.Dish_SalePrice,
                        dishid: rowItem.dishid,
                        Dish_Code: rowItem.Dish_Code,
                        Dish_Name: rowItem.Dish_Name,
                        Dish_QuickCode: rowItem.Dish_QuickCode,
                        Dish_SalePrice: rowItem.Dish_SalePrice,
                        dish_typeid: rowItem.dish_typeid,
                        dish_typename: rowItem.DishType_Name,
                        cwlxid: rowItem.cwlxid,
                        cwlxname: rowItem.cwlxname,
                        images: [],
                        units: []
                    };
                    dishTypeObj.dishList.push(dishObj);
                }
                if(rowItem.dish_picid != null){
                    var dishImageObj = Utils.arrayFind(dishObj.images, rowItem.dish_picid, "dish_picid");
                    if(dishImageObj == null){
                        dishImageObj = {
                            dish_picid: rowItem.dish_picid,
                            dish_picurl: rowItem.dish_picurl
                        };
                        dishObj.images.push(dishImageObj);
                    }
                }
                /*
                if(rowItem.unitid != null){
                    var dishUnitObj = Utils.arrayFind(dishObj.units, rowItem.unitid, "unitid");
                    if(dishUnitObj == null){
                        dishUnitObj = {
                            unitid: rowItem.unitid,
                            unitname: rowItem.unitname
                        };
                        dishObj.units.push(dishUnitObj);
                    }

                    var dishTypeUnitObj = Utils.arrayFind(dishTypeObj.unitList, rowItem.unitid, "unitid");
                    if(dishTypeUnitObj == null){
                        dishTypeUnitObj = {
                            unitid: rowItem.unitid,
                            unitname: rowItem.unitname
                        };
                        dishTypeObj.unitList.push(dishTypeUnitObj);
                    }
                }*/
            }
            return output;
        });
    };

    var orderInfoDao = new DatabaseFuncDelegate($q, database, 'hisorderinfo');

    OrderMenuService.saveOrder = function(orderInfo, cb){
        OrderMenuService.removeHistoryOrder(orderInfo, function(err,results){
            if(err == null || err.status == "NO_ORDER_INFO"){
                CanbieService.getCurrentCanBie(function(err, canbie){
                    if(err){
                        return cb(err);
                    }
                    var mdid = CONSTANTS.SystemConfigs["MD_ID"].SystemConfigValue;
                    var now = (new Date()).format("yyyy-MM-dd hh:mm:ss");
                    var queries = [];
                    var orderID = orderInfo.id == null ? orderInfoDao.guid() : orderInfo.id;
                    var orderZT_ID = orderInfoDao.guid();

                    queries.push({query: "insert into hisorderinfo ( "+
                        "id,MD_ID,Order_Code,TMLC_ID,OrderStatus,OrderYuanShiMoney, "+
                        "OrderShiJiMoney,OrderZheKouMoney,OrderYouMianMoney,IF_UPOK,AddTime,EndTime, "+
                        "Operator_ID,Operator_Name,CanBie_ID,TaiKaHao,Memo_1,HY_ID,HY_Code) "+
                        "values (?, ?, ?,?, ?, ?,?, ?, ?,?,?, ?, ?,?, ?, ?,?,?,?)", params: [orderID,mdid,orderInfo.orderNo,'快餐',0,orderInfo.amount,
                        orderInfo.totalAmout,orderInfo.discount,orderInfo.youmian,0,orderInfo.addTime.format("yyyy-MM-dd hh:mm:ss"),orderInfo.endTime.format("yyyy-MM-dd hh:mm:ss"),
                        orderInfo.operator.id, orderInfo.operator.Operator_Name,(orderInfo.canbie == null ? canbie.id : orderInfo.canbie.id),""+orderInfo.taikaNo,(orderInfo.memo == null ? "" : orderInfo.memo),(orderInfo.hy.HY_ID==null?"":orderInfo.hy.HY_ID),(orderInfo.hy.HY_Code==null?"":orderInfo.hy.HY_Code)]});
                    queries.push({query: "insert into hisordertype ( "+
                        "id,Order_ID,Order_Code,OrderType_Type,KHName,KHTel, "+
                        "OrderAddress,Delivery,EatTime,OrderStatus,MD_ID) "+
                        "values (?, ?, ?,?, ?, ?,?, ?, ?,?,?)", params: [orderInfoDao.guid(),orderID,orderInfo.orderNo,2,(orderInfo.typeFlag=="外送"?orderInfo.customerName:""),(orderInfo.typeFlag=="外送"?orderInfo.customerTel:""),
                        (orderInfo.typeFlag=="外送"?orderInfo.customerAddress:""),(orderInfo.typeFlag=="外送"?orderInfo.songcanyuan:""),now,(orderInfo.typeFlag=="外送"?0:""),mdid]});
                    queries.push({query: "insert into hisorderztrelation ( "+
                        "id,MD_ID,Order_ID,Order_Code,ZT_ID,ZT_Name,ZhuoTaiDishOrder,TMLC_ID,Operator_ID,Operator_Name) "+
                        "values (?, ?, ?,?, ?, ?,?, ?, ?,?)", params: [orderZT_ID,mdid,orderID,orderInfo.orderNo,CONSTANTS.ZT_ID,CONSTANTS.ZT_NAME,orderInfo.taikaNo,CONSTANTS.TMLC,orderInfo.operator.id, orderInfo.operator.Operator_Name]});
                    for(var idx in orderInfo.orderItems){
                        var item = orderInfo.orderItems[idx];
                        var orderZTDish_ID = orderInfoDao.guid();

                        queries.push({query: "insert into hisorderztdishrelation ( "+
                        "id,MD_ID,OrderZT_ID,Dish_ID,Dish_Code,DishType_ID,DishType_Name,DishName, DishPrice,TMLCPrice,DishYouMianMoney,"+
                        "DishUnit_ID,DishUnit,DishNum,DishDesc,DishStatus,Operator_ID,Operator_Name,DishShowOrder,CWLX_ID,CWLX_Name) "+
                        "values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)", params: [orderZTDish_ID,mdid,orderZT_ID,
                        item.dish.dishid,item.dish.Dish_Code+"",item.dish.dish_typeid,item.dish.dish_typename,item.dish.Dish_Name,/*item.getTotalAmout()*/item.actualPrice,item.actualPrice,item.youmian,(item.unit == null ? "" : item.unit.unitid),(item.unit == null ? "" : item.unit.unitname),
                        item.count,item.getTasteString(),0,orderInfo.operator.id,orderInfo.operator.Operator_Name,""+(parseInt(idx)+1),item.dish.cwlxid,item.dish.cwlxname]});
                        for(var idx2 in item.tasteList){
                            var kw = item.tasteList[idx2];
                            queries.push({query: "insert into hisorderdishkouwei ( "+
                            "id,MD_ID,DishRelation_ID,KW_ID,KW_Name,Operator_ID,Operator_Name) "+
                            "values (?,?,?,?,?,?,?)", params: [orderInfoDao.guid(), mdid,orderZTDish_ID,
                            kw.id,kw.KW_Name,orderInfo.operator.id, orderInfo.operator.Operator_Name]});
                        }
                    }
                    orderInfoDao.queryTransaction(queries).then(function(resultList){
                        cb(null, {results:resultList, orderID:orderID, orderZhuotaiID: orderZT_ID});
                    }, function(err){
                        cb(err);
                    });
                });
            }
            else {
                cb(err);
            }
        });
    };

    OrderMenuService.getUnPaidOrder = function(userinfo, cb){
        var sql = "select o.id as orderid,o.Order_Code,o.OrderYuanShiMoney,o.OrderShiJiMoney,o.OrderZheKouMoney,o.OrderYouMianMoney,o.AddTime,o.EndTime,o.CanBie_ID,o.TaiKaHao, "+
                    "ot.id as ordertypeid,ot.OrderType_Type,ot.KHName,ot.KHTel,ot.OrderAddress,ot.Delivery,ot.EatTime,ot.OrderStatus as waimaiStatus, "+
                    "ozt.id as orderzhuotaiid,ozt.ZT_ID,ozt.ZT_Name,oztr.id as dishrelationid,oztr.Dish_ID,oztr.Dish_Code,oztr.DishType_ID,oztr.DishType_Name, "+
                    "oztr.DishName,oztr.DishPrice,oztr.DishUnit_ID,oztr.DishUnit,oztr.DishNum,oztr.CWLX_ID as cwlxid,oztr.CWLX_Name as cwlxname,odk.id as kwrelationid,odk.KW_ID,odk.KW_Name "+
                    "from hisorderinfo o "+
                    "inner join hisordertype ot on o.id = ot.Order_ID "+
                    "inner join hisorderztrelation ozt on ozt.Order_ID = o.id "+
                    "inner join hisorderztdishrelation oztr on oztr.OrderZT_ID = ozt.id "+
                    "left join hisorderdishkouwei odk on odk.DishRelation_ID = oztr.id "+
                    "where o.OrderStatus = 0 and o.Operator_ID='"+userinfo.id+"' "+
                    "order by o.AddTime desc,oztr.DishShowOrder asc";
        orderInfoDao.query(sql).then(function(resultList){
            var scaleMap = {};
            scaleMap["1"] = 1;
            scaleMap["2"] = parseFloat((CONSTANTS.SystemConfigs["MiddleScale"] == null ? "1.5":CONSTANTS.SystemConfigs["MiddleScale"].SystemConfigValue));
            scaleMap["3"] = parseFloat((CONSTANTS.SystemConfigs["BigScale"] == null ? "2":CONSTANTS.SystemConfigs["BigScale"].SystemConfigValue));           
            var output = [];
            for (var i = 0; i < resultList.rows.length; i++) {
                var row = resultList.rows.item(i);
                var orderInfo = Utils.arrayFind(output, row.Order_Code, "orderNo");
                if(orderInfo == null){
                    orderInfo = new OrderInfo();
                    orderInfo.id = row.orderid;
                    orderInfo.orderNo = row.Order_Code;
                    orderInfo.taikaNo = row.TaiKaHao;
                    orderInfo.addTime = row.AddTime;
                    orderInfo.endTime = row.EndTime;
                    orderInfo.printTime = null;
                    orderInfo.typeFlag = row.OrderType_Type == 2 ? "外带":"外送"; // 外带， 外送， 自取， 内用
                    orderInfo.customerName = row.KHName; // 外卖可用 
                    orderInfo.customerTel = row.KHTel; // 外卖可用
                    orderInfo.customerAddress = row.OrderAddress; // 外卖可用
                    orderInfo.songcanyuan = row.Delivery;
                    orderInfo.operator = userinfo;
                    orderInfo.orderItems = [];
                    orderInfo.itemCount = 0; // 项数
                    orderInfo.amount = 0; // 小计
                    orderInfo.discount = row.OrderZheKouMoney; // 折扣
                    orderInfo.youmian = row.OrderYouMianMoney;
                    orderInfo.totalCount = 0; // 数量
                    orderInfo.paidAmount = 0; // 已付
                    orderInfo.totalAmout = 0; // 总价
                    orderInfo.unpaidAmount = 0; // 未收
                    orderInfo.isHistoryOrder = true;
                    output.push(orderInfo);
                }
                var orderItem = Utils.arrayFind(orderInfo.orderItems, row.Dish_ID, "dishid");
                if(orderItem == null){
                    orderItem = new OrderItem();
                    orderItem.dishid = row.Dish_ID;
                    orderItem.setDish({
                        md_dishid: row.Dish_ID,
                        md_dishprice: row.DishPrice,
                        dishid: row.Dish_ID,
                        Dish_Code: row.Dish_Code,
                        Dish_Name: row.DishName,
                        Dish_SalePrice: row.DishPrice,
                        cwlxid: row.cwlxid,
                        cwlxname: row.cwlxname,
                        dish_typeid: row.DishType_ID,
                        dish_typename:row.DishType_Name
                    });
                    orderItem.count = row.DishNum;
                    if(row.DishUnit_ID != null && row.DishUnit_ID.length > 0){
                        orderItem.setUnit({
                            unitid: row.DishUnit_ID,
                            unitname: row.DishUnit,
                            scale: scaleMap[row.DishUnit_ID]
                        });
                        orderItem.setNewPrice();
                    }
                    orderItem.tasteList = [];
                    orderItem.discount = 0;
                    orderInfo.orderItems.push(orderItem);
                }
                if(row.KW_ID != null && row.KW_ID.length > 0){
                    var taste = Utils.arrayFind(orderItem.tasteList, row.KW_ID, "id");
                    if(taste == null){
                        taste = {
                            id: row.KW_ID,
                            KW_Name: row.KW_Name
                        }
                        orderItem.tasteList.push(taste);
                    }
                }
            }
            for(var idx in output){
                output[idx]._update();
            }
            cb(null,output);
        }, function(err){cb(err)});
    };

    OrderMenuService.getOrderInfoWithSummary = function(id, cb){
        var sql = "select o.id as orderid,o.Order_Code,o.OrderYuanShiMoney,o.OrderShiJiMoney,o.OrderZheKouMoney,o.OrderYouMianMoney,o.AddTime,o.EndTime,o.CanBie_ID,o.TaiKaHao, "+
                    "ot.id as ordertypeid,o.HY_ID,o.HY_Code,ot.OrderType_Type,ot.KHName,ot.KHTel,ot.OrderAddress,ot.Delivery,ot.EatTime,ot.OrderStatus as waimaiStatus, "+
                    "ozt.id as orderzhuotaiid,ozt.ZT_ID,ozt.ZT_Name,oztr.id as dishrelationid,oztr.Dish_ID,oztr.Dish_Code,oztr.DishType_ID,oztr.DishType_Name, "+
                    "oztr.DishName,oztr.DishPrice,oztr.DishYouMianMoney,oztr.DishUnit_ID,oztr.DishUnit,oztr.DishNum,oztr.CWLX_ID as cwlxid,oztr.CWLX_Name as cwlxname,odk.id as kwrelationid,odk.KW_ID,odk.KW_Name, "+
                    "ojs.CWKM_ID,ojs.CWKM_Name,ojs.ShouDaoMoney,ojs.ZhaoLingMoney,ojs.ShiShouMoney,ojs.JieSuanType, "+
                    "bo.id as operatorid, bo.Operator_Name,bo.Operator_Code,bo.Operator_Desc,o.OrderStatus as ostatus,o.IF_UPOK "+
                    "from hisorderinfo o "+
                    "inner join hisordertype ot on o.id = ot.Order_ID "+
                    "inner join hisorderztrelation ozt on ozt.Order_ID = o.id "+
                    "inner join hisorderztdishrelation oztr on oztr.OrderZT_ID = ozt.id "+
                    "inner join base_operator bo on bo.id = o.Operator_ID "+
                    "left join hisorderdishkouwei odk on odk.DishRelation_ID = oztr.id "+
                    "left join hisorderjiesuan ojs on ojs.Order_ID = o.id "+
                    "where o.id = '"+id+"' "+
                    "order by o.AddTime desc,oztr.DishShowOrder asc, ojs.JSOrder";
        orderInfoDao.query(sql).then(function(resultList){
            var output = [];
            var scaleMap = {};
            scaleMap["1"] = 1;
            scaleMap["2"] = parseFloat((CONSTANTS.SystemConfigs["MiddleScale"] == null ? "1.5":CONSTANTS.SystemConfigs["MiddleScale"].SystemConfigValue));
            scaleMap["3"] = parseFloat((CONSTANTS.SystemConfigs["BigScale"] == null ? "2":CONSTANTS.SystemConfigs["BigScale"].SystemConfigValue));           
            for (var i = 0; i < resultList.rows.length; i++) {
                var row = resultList.rows.item(i);
                var orderInfo = Utils.arrayFind(output, row.Order_Code, "orderNo");
                if(orderInfo == null){
                    orderInfo = new OrderInfo();
                    orderInfo.id = row.orderid;
                    orderInfo.orderNo = row.Order_Code;
                    orderInfo.taikaNo = row.TaiKaHao;
                    orderInfo.addTime = row.AddTime;
                    orderInfo.endTime = row.EndTime;
                    orderInfo.printTime = null;
                    orderInfo.typeFlag = row.OrderType_Type == 2 ? "外带":"外送"; // 外带， 外送， 自取， 内用
                    orderInfo.customerName = row.KHName; // 外卖可用 
                    orderInfo.customerTel = row.KHTel; // 外卖可用
                    orderInfo.customerAddress = row.OrderAddress; // 外卖可用
                    orderInfo.songcanyuan = row.Delivery;
                    orderInfo.operator = {
                        id:row.operatorid,
                        Operator_Name: row.Operator_Name,
                        Operator_Code: row.Operator_Code,
                        Operator_Desc: row.Operator_Desc
                    };
                    orderInfo.orderItems = [];
                    orderInfo.itemCount = 0; // 项数
                    orderInfo.amount = row.OrderYuanShiMoney; // 小计
                    orderInfo.discount = row.OrderZheKouMoney; // 折扣
                    orderInfo.youmian = row.OrderYouMianMoney;
                    orderInfo.totalCount = 0; // 数量
                    orderInfo.paidAmount = row.OrderShiJiMoney; // 已付
                    orderInfo.totalAmout = row.OrderShiJiMoney; // 总价
                    orderInfo.unpaidAmount = 0; // 未收
                    orderInfo.isHistoryOrder = true;
                    orderInfo.hy = {
                        HY_ID: row.HY_ID,
                        HY_Code: row.HY_Code
                    };
                    orderInfo.paidApporach = [];
                    orderInfo.orderStatus = row.ostatus;
                    orderInfo.IF_UPOK = row.IF_UPOK;
                    output.push(orderInfo);
                }
                var orderItem = Utils.arrayFind(orderInfo.orderItems, row.Dish_ID, "dishid");
                if(orderItem == null){
                    orderItem = new OrderItem();
                    orderItem.dishid = row.Dish_ID;
                    orderItem.youmian = row.DishYouMianMoney;
                    orderItem.setDish({
                        md_dishid: row.Dish_ID,
                        md_dishprice: row.DishPrice,
                        dishid: row.Dish_ID,
                        Dish_Code: row.Dish_Code,
                        Dish_Name: row.DishName,
                        Dish_SalePrice: row.DishPrice,
                        cwlxid: row.cwlxid,
                        cwlxname: row.cwlxname,
                        dish_typeid: row.DishType_ID,
                        dish_typename:row.DishType_Name
                    });
                    orderItem.count = row.DishNum;
                    if(row.DishUnit_ID != null && row.DishUnit_ID.length > 0){
                        orderItem.setUnit({
                            unitid: row.DishUnit_ID,
                            unitname: row.DishUnit,
                            scale: scaleMap[row.DishUnit_ID]
                        });
                        orderItem.setNewPrice();
                    }
                    orderItem.tasteList = [];
                    orderItem.discount = 0;
                    orderInfo.orderItems.push(orderItem);
                }
                if(row.KW_ID != null && row.KW_ID.length > 0){
                    var taste = Utils.arrayFind(orderItem.tasteList, row.KW_ID, "id");
                    if(taste == null){
                        taste = {
                            id: row.KW_ID,
                            KW_Name: row.KW_Name
                        }
                        orderItem.tasteList.push(taste);
                    }
                }
                if(row.CWKM_ID != null){
                    var cwkm = Utils.arrayFind(orderInfo.paidApporach, row.CWKM_ID, "CWKM_ID");
                    if(cwkm == null){
                        cwkm = {
                            CWKM_ID: row.CWKM_ID,
                            CWKM_Name: row.CWKM_Name,
                            ShouDaoMoney: row.ShouDaoMoney,
                            ZhaoLingMoney: row.ZhaoLingMoney,
                            ShiShouMoney: row.ShiShouMoney,
                            type: row.JieSuanType
                        }
                        orderInfo.paidApporach.push(cwkm);
                    }
                }
            }
            for(var idx in output){
                output[idx]._update();
            }
            cb(null,output);
        }, function(err){cb(err)});
    };

    OrderMenuService.removeHistoryOrder = function(orderinfo, cb){
        var sql = "select ozt.id as orderzhuotaiid, oztr.id as dishrelationid from hisorderztrelation ozt "+
                    "inner join hisorderztdishrelation oztr on oztr.OrderZT_ID = ozt.id "+
                    "where ozt.Order_Code ='"+orderinfo.orderNo+"'";
        orderInfoDao.query(sql).then(function(results){
            if(results.rows.length > 0){
                var ids = []
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    var zhuotai = Utils.arrayFind(ids, row.orderzhuotaiid, "ztID");
                    if(zhuotai == null){
                        zhuotai = {ztID: row.orderzhuotaiid, dishRelationIDs: []};
                        ids.push(zhuotai);
                    }
                    var dishrelation = Utils.arrayFind(zhuotai.dishRelationIDs, row.dishrelationid, "dishRelID");
                    if(dishrelation == null){
                        dishrelation = {dishRelID: row.dishrelationid};
                        zhuotai.dishRelationIDs.push(dishrelation);
                    }
                }
                var queries = [];
                queries.push({query: "delete from hisorderinfo where Order_Code=?", params: [orderinfo.orderNo]});
                queries.push({query: "delete from hisordertype where Order_Code=?", params: [orderinfo.orderNo]});
                queries.push({query: "delete from hisorderztrelation where Order_Code=?", params: [orderinfo.orderNo]});
                for(var idx in ids){
                    var idInfo = ids[idx];
                    queries.push({query: "delete from hisorderztdishrelation where OrderZT_ID=?", params: [idInfo.ztID]});
                    var dishidStr = "";
                    for(var idx2 in idInfo.dishRelationIDs){
                        dishidStr += "'"+idInfo.dishRelationIDs[idx2].dishRelID+"',";
                    }
                    if(dishidStr.length > 0){
                        dishidStr = dishidStr.substring(0, dishidStr.length - 1);
                    }
                    queries.push({query: "delete from hisorderdishkouwei where DishRelation_ID in (?)", params: [dishidStr]});
                }
                orderInfoDao.queryTransaction(queries).then(function(resultList){
                    cb(null, resultList);
                }, function(err){
                    cb(err);
                });
            }
            else{
                cb({message: "没有找到订单编号为"+orderinfo.orderNo+"的记录！", status:'NO_ORDER_INFO'});
            }
        }, function(err){
            cb(err);
        });
    };

    /*
        moneyStruct[cwkm.id] = {
            name: cwkm.CWKM_Name,
            shoudaomoney: $scope.moneyStruct.m2,
            zhaolingmoney: 0,
            shishoumoney: $scope.moneyStruct.m2
        };
    */
    OrderMenuService.billOrder = function(orderBillInfo, cb) {
        orderBillInfo.orderInfo.endTime = new Date();
        OrderMenuService.saveOrder(orderBillInfo.orderInfo, function(err, result){
            if(err){
                return cb(err);
            }
            var orderid = result.orderID;
            var orderZhuotaiID = result.orderZhuotaiID;

            var sql = "select cwlx.id as cwlxid, cwlx.CWLX_Name as cwlxname, cwlx.CWLX_Type as cwlxtype,oztr.DishType_ID,oztr.DishType_Name,oztr.DishNum,oztr.DishPrice,oztr.DishYouMianMoney "+
                    "from hisorderztdishrelation oztr "+
                    "inner join base_caiwuleixing cwlx on cwlx.id = oztr.CWLX_ID and oztr.OrderZT_ID = '"+orderZhuotaiID+"' ";
            orderInfoDao.query(sql).then(function(results){
                var cwlxInfo = {};
                var dishtypeInfo = {};
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    var cwlxAgg = cwlxInfo[row.cwlxid];
                    if(cwlxAgg == null){
                        cwlxAgg = {
                            name: row.cwlxname,
                            type: row.cwlxtype,
                            money: 0
                        };
                    }
                    var money = parseFloat(row.DishPrice) * parseFloat(row.DishNum) + row.DishYouMianMoney;
                    cwlxAgg.money += money;
                    cwlxInfo[row.cwlxid] = cwlxAgg;

                    var dishtypeAgg = dishtypeInfo[row.DishType_ID];
                    if(dishtypeAgg == null){
                        dishtypeAgg = {
                            name: row.DishType_Name,
                            money: 0
                        };
                    }
                    dishtypeAgg.money += money;
                    dishtypeInfo[row.DishType_ID] = dishtypeAgg;
                }

                var now = (new Date()).format("yyyy-MM-dd hh:mm:ss");
                var mdid = CONSTANTS.SystemConfigs["MD_ID"].SystemConfigValue;
                var banciNo = CONSTANTS.Banci.BanCiHao;
                var queries = [];
                queries.push({query: "insert into hisoperatorjiesuanorderinfo "+
                    "(id,BanCiHao,Order_ID,Order_Code,Operator_ID,Operator_Name,IfFanJieSuan,AddTime,MD_ID) values (?,?,?,?,?,?,?,?,?)", 
                    params: [orderInfoDao.guid(),banciNo,orderid,orderBillInfo.orderInfo.orderNo,
                    orderBillInfo.orderInfo.operator.id, orderBillInfo.orderInfo.operator.Operator_Name,0,now,mdid]});
                queries.push({query: "update hisorderinfo set OrderStatus=? where id=?",params: [1, orderid]});
                for(var cwlxid in cwlxInfo){
                    var cwlxAgg = cwlxInfo[cwlxid];
                    queries.push({query: "insert into hisordercaiwuleixingtongji "+
                        "(id,BanCiHao,Order_ID,Order_Code,CWLX_ID,CWLX_Type,CWLX_Name,LiLunMoney,ShiJiMoney,MD_ID) values (?,?,?,?,?,?,?,?,?,?)", 
                        params: [orderInfoDao.guid(),banciNo,orderid,orderBillInfo.orderInfo.orderNo,
                        cwlxid, cwlxAgg.type,cwlxAgg.name,cwlxAgg.money,cwlxAgg.money,mdid]});
                }
                for(var dishtypeid in dishtypeInfo){
                    var dishtypeAgg = dishtypeInfo[dishtypeid];
                    queries.push({query: "insert into hisorderdishtypetongji "+
                        "(id,BanCiHao,Order_ID,Order_Code,DishType_ID,DishType_Name,LiLunMoney,ShiJiMoney,MD_ID) values (?,?,?,?,?,?,?,?,?)", 
                        params: [orderInfoDao.guid(),banciNo,orderid,orderBillInfo.orderInfo.orderNo,
                        dishtypeid, dishtypeAgg.name,dishtypeAgg.money,dishtypeAgg.money,mdid]});
                }
                var jsorder = 1;
                for(var cwkmid in orderBillInfo.moneyStruct){
                    var cwkminfo = orderBillInfo.moneyStruct[cwkmid];
                    if(cwkminfo.shoudaomoney == 0){ // 过滤未发生任何交易行为的统计
                        continue;
                    }
                    queries.push({query: "insert into hisorderjiesuan "+
                        "(id,MD_ID,Order_ID,Order_Code,Operator_ID,Operator_Name,CWKM_ID,CWKM_Name,ShouDaoMoney,ZhaoLingMoney,ShiShouMoney,JieSuanType,IfYuFu,JSOrder) values (?,?,?,?,?,?,?,?,?,?,?,?,?,?)", 
                        params: [orderInfoDao.guid(),mdid,orderid,orderBillInfo.orderInfo.orderNo,orderBillInfo.orderInfo.operator.id, orderBillInfo.orderInfo.operator.Operator_Name,
                        cwkmid,cwkminfo.name,cwkminfo.shoudaomoney,cwkminfo.zhaolingmoney,cwkminfo.shishoumoney,cwkminfo.type,0,jsorder]});
                    jsorder++;
                }
                queries.push({query: "update hisorderztdishrelation set DishStatus=? where OrderZT_ID=?",params: [1,orderZhuotaiID]});    
                queries.push({query: "update hisordertype set OrderStatus=? where Order_ID=?",params: [9, orderid]});
                
                orderInfoDao.queryTransaction(queries).then(function(resultList){
                    cb(null, resultList);
                }, function(err){
                    cb(err);
                });
            }, function(err){
                cb(err);
            });
        });
    };

    OrderMenuService.getJiebanDanHistory = function(userid, banciNo, cb){
        var sql = "select oj.Order_Code, oj.CWKM_Name, oj.CWKM_ID, oj.ShiShouMoney, "+
                    "ocwlx.CWLX_ID, ocwlx.CWLX_Name, ocwlx.CWLX_Type, ocwlx.ShiJiMoney, "+
                    "ody.DishType_ID, ody.DishType_Name, ody.ShiJiMoney as dishtypeMoney, o.OrderStatus,o.OrderShiJiMoney,cb.CB_Name, "+
                    "ozd.Dish_ID,ozd.DishName,ozd.DishNum,ozd.DishUnit,ozd.TMLCPrice,ozd.DishYouMianMoney "+
                    "from hisoperatorjiesuanorderinfo jso "+
                    "inner join hisorderjiesuan oj on jso.Order_ID = oj.Order_ID "+
                    "inner join hisorderinfo o on o.id = jso.Order_ID "+
                    "inner join hisorderztrelation oz on oz.Order_ID = o.id "+
                    "inner join hisorderztdishrelation ozd on ozd.OrderZT_ID = oz.id "+
                    "inner join base_canbie cb on cb.id = o.CanBie_ID "+
                    "inner join hisordercaiwuleixingtongji ocwlx on ocwlx.Order_ID = oj.Order_ID "+
                    "inner join hisorderdishtypetongji ody on ody.Order_ID = oj.Order_ID "+
                    "where jso.BanCiHao='"+banciNo+"' and jso.Operator_ID='"+userid+"' order by o.AddTime, ozd.DishName, oj.JSOrder ";
        orderInfoDao.query(sql).then(
        function(results){
            var jiebaninfo = new JiebandanInfo();
            var addedDish = [];
            var addedCwlx = [];
            var addedDishtype = [];
            var addedCwkm = [];
            for (var i = 0; i < results.rows.length; i++) {
                var row = results.rows.item(i);
                var jsOrder = Utils.arrayFind(jiebaninfo.jiesuanOrders, row.Order_Code, "Order_Code");
                if(jsOrder == null){
                    jsOrder = {
                        Order_Code: row.Order_Code,
                        OrderStatus: row.OrderStatus,
                        OrderShiJiMoney: row.OrderShiJiMoney,
                        CB_Name: row.CB_Name,
                        cwkmList : []
                    };
                    jiebaninfo.jiesuanOrders.push(jsOrder);
                }
                if(row.OrderStatus != 1){
                    continue;
                }
                var cwkm = Utils.arrayFind(jsOrder.cwkmList, row.CWKM_ID, "CWKM_ID");
                if(cwkm == null){
                    cwkm = {
                        CWKM_ID: row.CWKM_ID,
                        CWKM_Name: row.CWKM_Name,
                        money: row.ShiShouMoney
                    };
                    jsOrder.cwkmList.push(cwkm);
                }
                var cwlx = Utils.arrayFind(jiebaninfo.caiwuleixingInfos, row.CWLX_ID, "CWLX_ID");
                if(cwlx == null){
                    cwlx = {
                        CWLX_ID: row.CWLX_ID,
                        CWLX_Name: row.CWLX_Name,
                        CWLX_Type: row.CWLX_Type,
                        money: 0
                    };
                    jiebaninfo.caiwuleixingInfos.push(cwlx);
                }
                if(!Utils.contains(addedCwlx, row.CWLX_ID + "-"+ row.Order_Code)){
                    if(row.OrderStatus == 1){
                        cwlx.money += row.ShiJiMoney;
                        addedCwlx.push(row.CWLX_ID + "-"+ row.Order_Code);
                    }
                }
                var dishtype = Utils.arrayFind(jiebaninfo.dishtypeInfos, row.DishType_ID, "DishType_ID");
                if(dishtype == null){
                    dishtype = {
                        DishType_ID: row.DishType_ID,
                        DishType_Name: row.DishType_Name,
                        money: 0
                    };
                    jiebaninfo.dishtypeInfos.push(dishtype);
                }
                if(!Utils.contains(addedDishtype, row.DishType_ID + "-"+ row.Order_Code)){
                    if(row.OrderStatus == 1){
                        dishtype.money += row.dishtypeMoney;
                        addedDishtype.push(row.DishType_ID + "-"+ row.Order_Code);
                    }
                }
                var dish = Utils.arrayFind(jiebaninfo.dishInfos, row.Dish_ID +"_"+ row.DishUnit, "Dish_ID");
                if(dish == null){
                    dish = {
                        Dish_ID: row.Dish_ID +"_" + row.DishUnit,
                        DishName: row.DishName+"("+row.DishUnit+")",
                        DishNum: 0,
                        money:0
                    };
                    jiebaninfo.dishInfos.push(dish);
                }
                if(!Utils.contains(addedDish, row.Dish_ID +"_"+ row.DishUnit + "-"+ row.Order_Code)){
                    if(row.OrderStatus == 1){
                        dish.money += row.DishNum * row.TMLCPrice + row.DishYouMianMoney;
                        dish.DishNum += row.DishNum;
                        addedDish.push(row.Dish_ID +"_"+ row.DishUnit + "-"+ row.Order_Code);
                    }
                }
                var paidMethodObj = Utils.arrayFind(jiebaninfo.paidMethodInfos, row.CWKM_ID, "CWKM_ID");
                if(paidMethodObj == null){
                    paidMethodObj = {
                        CWKM_ID: row.CWKM_ID,
                        CWKM_Name: row.CWKM_Name,
                        money: 0
                    };
                    jiebaninfo.paidMethodInfos.push(paidMethodObj);
                }
                
                if(!Utils.contains(addedCwkm, row.CWKM_ID + "-"+ row.Order_Code)){
                    if(row.OrderStatus == 1){
                        paidMethodObj.money += row.ShiShouMoney;
                        jiebaninfo.totalAmount += row.ShiShouMoney;
                        addedCwkm.push(row.CWKM_ID + "-"+ row.Order_Code);
                    }
                }
            }

            cb(null, jiebaninfo);
        },
        function(err){
            cb(err);
        });
    };

    OrderMenuService.allDish = function(cb){
        var sql = "select d.id as dishid, "+
                    "d.Dish_Code, d.Dish_Name, d.Dish_QuickCode, d.Dish_SalePrice, dt.id as dish_typeid, dt.DishType_Code,dt.DishType_Name, "+
                    "cw.id as cwlxid, cw.CWLX_Name as cwlxname "+
                    "from  base_dish d "+
                    "inner join base_dish_type dt on d.Dish_Status = 1 and dt.id = d.DishType_ID and dt.DishType_Status = 1 "+
                    "inner join base_caiwuleixing cw on cw.id = d.Dish_CWLX_ID "+
                    "order by dt.DishType_PrintOrder, d.Dish_Disp_Order";
        orderInfoDao.query(sql).then(function(results){
            return cb(null, results);
        }, function(err){cb(err)});
    };

    /**
        {
            orderIDs: [],
            data: [
                {
                    tableName: "",
                    rows: [
                        {col1:xx,col2:xx...}
                    ],
                }
            ]
        }
    */
    OrderMenuService.getUnSyncOrderList = function(limit, cb){
        var _buildModelData = function(tableName, row){
            var tableMeta = null;
            for(var idx in TABLES_SCHEME){
                if(TABLES_SCHEME[idx].name.toLowerCase() == tableName.toLowerCase()){
                    tableMeta = TABLES_SCHEME[idx];
                    break;
                }
            }
            var output = {};
            if(tableMeta != null){
                for(var idx in tableMeta.columns){
                    var colDef = tableMeta.columns[idx];
                    if(row[colDef.name] != null){
                        output[colDef.name] = row[colDef.name];
                    }
                }
            }
            return output;
        };

        var output = {};
        var expectedExecCount = 10;
        var actualExecCount = 0;
        var sql = "select distinct * from hisorderinfo where IF_UPOK = 0 and OrderStatus = 1 order by AddTime asc limit "+limit;
        orderInfoDao.query(sql).then(function(results){
            actualExecCount++;
            output.orderIDs = [];
            output.data = [];
            var orderdata = {
                tableName: "hisorderinfo",
                rows: []
            };
            for (var i = 0; i < results.detail.length; i++) {
                var row = results.detail[i];
                output.orderIDs.push(row.id);
                orderdata.rows.push(_buildModelData("hisorderinfo", row));
            }
            output.data.push(orderdata);
            var orderIDQuery = Utils.toIDQueryString(output.orderIDs);
            orderInfoDao.query("select distinct * from hisorderjiesuan where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisorderjiesuan",
                    rows: []
                };
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    data.rows.push(_buildModelData("hisorderjiesuan", row));
                }
                output.data.push(data);
            }, function(err){cb(err)});
            orderInfoDao.query("select distinct * from hisordertype where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisordertype",
                    rows: []
                };
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    data.rows.push(_buildModelData("hisordertype", row));
                }
                output.data.push(data);
            }, function(err){cb(err)});
            orderInfoDao.query("select distinct * from hisorderztrelation where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisorderztrelation",
                    rows: []
                };
                var ztid = [];
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    ztid.push(row.id);
                    data.rows.push(_buildModelData("hisorderztrelation", row));
                }
                output.data.push(data);

                var ztidQuery = Utils.toIDQueryString(ztid);
                orderInfoDao.query("select distinct * from hisorderztdishrelation where OrderZT_ID in ("+ztidQuery+")").then(function(results){
                    actualExecCount++;
                    var data = {
                        tableName: "hisorderztdishrelation",
                        rows: []
                    };
                    var ztdishid = [];
                    for (var i = 0; i < results.rows.length; i++) {
                        var row = results.rows.item(i);
                        if(!Utils.contains(ztdishid, row.id)){
                            ztdishid.push(row.id);
                        }
                        data.rows.push(_buildModelData("hisorderztdishrelation", row));
                    }
                    output.data.push(data);

                    var ztdishidQuery = Utils.toIDQueryString(ztdishid);

                    orderInfoDao.query("select distinct * from hisorderdishkouwei where DishRelation_ID in ("+ztdishidQuery+")").then(function(results){
                        actualExecCount++;
                        var data = {
                            tableName: "hisorderdishkouwei",
                            rows: []
                        };
                        for (var i = 0; i < results.rows.length; i++) {
                            var row = results.rows.item(i);
                            data.rows.push(_buildModelData("hisorderdishkouwei", row));
                        }
                        output.data.push(data);
                    }, function(err){cb(err)});

                }, function(err){cb(err)});
            }, function(err){cb(err)});
            orderInfoDao.query("select distinct * from hisordercaiwuleixingtongji where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisordercaiwuleixingtongji",
                    rows: []
                };
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    data.rows.push(_buildModelData("hisordercaiwuleixingtongji", row));
                }
                output.data.push(data);
            }, function(err){cb(err)});
            orderInfoDao.query("select distinct * from hisorderdishtypetongji where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisorderdishtypetongji",
                    rows: []
                };
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    data.rows.push(_buildModelData("hisorderdishtypetongji", row));
                }
                output.data.push(data);
            }, function(err){cb(err)});
            orderInfoDao.query("select distinct * from hisoperatorjiesuanorderinfo where Order_ID in ("+orderIDQuery+")").then(function(results){
                actualExecCount++;
                var data = {
                    tableName: "hisoperatorjiesuanorderinfo",
                    rows: []
                };
                var bancihao = [];
                for (var i = 0; i < results.rows.length; i++) {
                    var row = results.rows.item(i);
                    if(!Utils.contains(bancihao, row.BanCiHao)){
                        bancihao.push(row.BanCiHao);
                    }
                    data.rows.push(_buildModelData("hisoperatorjiesuanorderinfo", row));
                }
                output.data.push(data);

                orderInfoDao.query("select distinct * from hisoperatorbanci where BanCiHao in ("+Utils.toIDQueryString(bancihao)+")").then(function(results){
                    actualExecCount++;
                    var data = {
                        tableName: "hisoperatorbanci",
                        rows: []
                    };
                    for (var i = 0; i < results.rows.length; i++) {
                        var row = results.rows.item(i);
                        data.rows.push(_buildModelData("hisoperatorbanci", row));
                    }
                    output.data.push(data);
                }, function(err){cb(err)});
            }, function(err){cb(err)});
            
            var performSuccessCall = function(){
                if(actualExecCount == expectedExecCount){
                    cb(null, output);
                }
                else{
                    window.setTimeout(performSuccessCall, 100);
                }
            };
            performSuccessCall();
        }, function(err){cb(err)});
    };

    OrderMenuService.getJiebanBanciInfo = function(cb){
        var _buildModelData = function(tableName, row){
            var tableMeta = null;
            for(var idx in TABLES_SCHEME){
                if(TABLES_SCHEME[idx].name.toLowerCase() == tableName.toLowerCase()){
                    tableMeta = TABLES_SCHEME[idx];
                    break;
                }
            }
            var output = {};
            if(tableMeta != null){
                for(var idx in tableMeta.columns){
                    var colDef = tableMeta.columns[idx];
                    if(row[colDef.name] != null){
                        output[colDef.name] = row[colDef.name];
                    }
                }
            }
            return output;
        };

        var output = {};
        output.data = [];
        output.banciIDs = [];
        orderInfoDao.query("select distinct * from hisoperatorbanci where IfJiaoZhang = 1 and Synced != 1").then(function(results){
            var data = {
                tableName: "hisoperatorbanci",
                rows: []
            };
            for (var i = 0; i < results.rows.length; i++) {
                var row = results.rows.item(i);
                output.banciIDs.push(row.id);
                data.rows.push(_buildModelData("hisoperatorbanci", row));
            }
            output.data.push(data);
            cb(null, output);
        }, function(err){cb(err)});
    };

    OrderMenuService.updateSyncOrdersSuccess = function(orderIdArray, cb){
        var sql = "update hisorderinfo set IF_UPOK='1' where id in ("+Utils.toIDQueryString(orderIdArray)+")";
        orderInfoDao.query(sql).then(function(results){
            SystemConfigService.batchSaveConfig({
                "LastSyncTime":(new Date()).format("yyyy-MM-dd hh:mm:ss")
            }, function(err, resultList){
                if(err){
                    return cb(err);
                }
                return cb(null, results);
            });   
        }, function(err){cb(err)});
    };
    
    OrderMenuService.updateBanciSuccess = function(banciIdArray, cb){
        var sql = "update hisoperatorbanci set Synced=1 where id in ("+Utils.toIDQueryString(banciIdArray)+")";
        orderInfoDao.query(sql).then(function(results){
            SystemConfigService.batchSaveConfig({
                "LastSyncBanciTime":(new Date()).format("yyyy-MM-dd hh:mm:ss")
            }, function(err, resultList){
                if(err){
                    return cb(err);
                }
                return cb(null, results);
            });
        }, function(err){cb(err)});
    };

    OrderMenuService.isWeixinOrderFetched = function(memo, cb){
        var sql = "select id from hisorderinfo where Memo_1 ='"+memo+"'";
        orderInfoDao.query(sql).then(function(results){
            return cb(null, results.rows.length > 0 ? results.rows.item(0) : null);
        }, function(err){cb(err)});
    };

    OrderMenuService.getPaidOrderByOrderNo = function(orderNo, cb){
        var sql = "select * from hisorderinfo where Order_Code ='"+orderNo+"' and OrderStatus=1";
        orderInfoDao.query(sql).then(function(results){
            return cb(null, results.rows.length > 0 ? results.rows.item(0) : null);
        }, function(err){cb(err)});
    };

    OrderMenuService.getPaidOrderByDateRange = function(start, end, cb){
        var sql = "select * from hisorderinfo where 1=1 and OrderStatus=1";
        if(!Utils.isEmpty(start) && Utils.isEmpty(end)){
            sql += " and AddTime >= '"+start+"'"
        }
        else if(Utils.isEmpty(start) && !Utils.isEmpty(end)){
            sql += " and AddTime <= '"+end+"'"
        }
        else {
            sql += " and AddTime >= '"+start+"' and AddTime <= '"+end+"'"
        }
        sql += " order by AddTime"
        orderInfoDao.query(sql).then(function(results){
            var output = [];
            for (var i = 0; i < results.rows.length; i++) {
                output.push(results.rows.item(i));
            }
            return cb(null, output);
        }, function(err){cb(err)});
    };

    OrderMenuService.abondonOrder = function(orderid,reason, cb){
        var sql = "update hisorderinfo set OrderStatus=100, Memo_2='"+reason+"' where id = '"+orderid+"' ";
        orderInfoDao.query(sql).then(function(results){
            return cb(null, results);
        }, function(err){cb(err)});
    };

    //保存优惠券券号
    OrderMenuService.updateOrderCouponNo = function (couponNo, orderGuid) {
        if(!couponNo || !orderGuid) return;
        var sql = "update pos_order set couponNo='" + couponNo + "' where guid = '" + orderGuid + "'";
        orderInfoDao.query(sql).then(function (ret) {
            console.log("OrderMenuService.updateOrderCouponNo.ret : " + JSON.stringify(ret));
        })
    }

    //保存优惠券券号
    OrderMenuService.updateOrderCouponNo = function (couponNo, orderGuid) {
        if(!couponNo || !orderGuid) return;
        var sql = "update pos_order set couponNo='" + couponNo + "' where guid = '" + orderGuid + "'";
        orderInfoDao.query(sql).then(function (ret) {
            console.log("OrderMenuService.updateOrderCouponNo.ret : " + JSON.stringify(ret));
        })
    }

    OrderMenuService.Dish = dishService;
    OrderMenuService.Taste = tasteService;
    OrderMenuService.Caiwukemu = cwkmService;

    return OrderMenuService;
}]);