app.factory('PrintService', ['$q', 'database', '$http', "$window",'UniqueIDService', 'UploadService', function ($q,database,$http,$window,UniqueIDService, DataSyncService) {
    var PrintService = {};
	
	var jobDao = new DatabaseFuncDelegate($q, database, 'printer_job');
	var jobLogDao = new DatabaseFuncDelegate($q, database, 'printer_job_log');
	var printerDao = new DatabaseFuncDelegate($q, database, 'printer');
	var statusLogDao = new DatabaseFuncDelegate($q, database, 'printer_status_log');
	
	var running = false;
	var interval = 5000; // 打印服务间隔时间
	var repeatTimesOnError = 3; // 打印失败重打次数
	var backupPrintersWorkingTime = 300000; // 5分钟
	var printers = {};
	var issuePrinters = {};
	
	PrintService.startup = function(){
	    running = true;
	    PrintService.reInitPrintJob();
		$window.setTimeout(PrintService._run, interval);
	};
	
	PrintService.logIssuePrinter = function(printerId){
		if(issuePrinters[printerId] == null){
			issuePrinters[printerId] = (new Date()).getTime();
		}
	};
	
	PrintService.canBackupPrintDirectly = function(printerId){
		if(issuePrinters[printerId] != null){
			var curTime = (new Date()).getTime();
			if((curTime - issuePrinters[printerId]) > backupPrintersWorkingTime) {
				issuePrinters[printerId] = null;
			}
			return true;
		}
		return false;
	};
	
	PrintService._findPrinter = function(printerId, callback){
		if(printerId == null) {
			return null;
		}
		if(printers[printerId] != null){
			callback(printers[printerId]);
		}
		else{
			var sql = "select p.guid as pid, p.name as pname,p.code as pcode,p.size as psize,p.is_zhenda as pzhenda, pc.guid as pcid, pc.name as pcname, pc.value as pcvalue, bp.guid as bpid, bp.name as bpname,bp.code as bpcode,bp.size as bpsize, bp.is_zhenda as bpzhenda, bpc.guid as bpcid, bpc.name as bpcname, bpc.value as bpcvalue from printer p inner join printer_config pc on pc.printer_id = p.guid " +
						"left join printer bp on bp.guid = p.backup_id "+
						"left join printer_config bpc on bpc.printer_id = bp.guid where p.guid='"+printerId+"' "; // 根据printer id查找printer以及备用printer
			printerDao.query(sql)
			.then(function(result){
				var printer = null;
				for (var i = 0; i < result.detail.length; i++) {
					var row = result.detail[i];
					if(printer == null){
						printer = new MPrinter();
						printer.id = row.pid;
						printer.name = row.pname;
						printer.code = row.pcode;
						printer.size = row.psize;
						printer.isZhenda = row.pzhenda;
					}
					if(printer.configs[row.pcname] == null) {
						printer.configs[row.pcname] = row.pcvalue;
					}
					if(row.bpid != null) {
						if(printer.backupPrinter == null) {
							printer.backupPrinter = new MPrinter();
							printer.backupPrinter.id = row.bpid;
							printer.backupPrinter.name = row.bpname;
							printer.backupPrinter.code = row.bpcode;
							printer.backupPrinter.size = row.bpsize;
							printer.backupPrinter.isZhenda = row.bpzhenda;
						}
						if(printer.backupPrinter.configs[row.bpcname] == null) {
							printer.backupPrinter.configs[row.bpcname] = row.bpcvalue;
						}
					}
				}
				if(printer != null){
					printers[printer.id] = printer;
				}
				callback(printer);
			});
		}
	};
	
	PrintService._executeJob = function(job,cb){
	    jobDao.query("update printer_job set processing = 1 where guid = '" + job.id + "' and processing = 0 and status <> 1").then(function (results) {
	        if (results.rowsAffected[0] > 0) {
			    job.processing = 1;
				PrintService._findPrinter(job.mPrinterId, function (printer) {
					if(printer != null) {
						printer.doPrint(PrintService, job, function(){
							job.processing = 0;
							jobDao.query("update printer_job set processing = 0 where guid = '"+job.id+"' and processing = 1");
							if(cb){
								cb();
							}
						});
					}
				});
			}
		});
	};
	
	PrintService._run = function(){
		if(!running) {
			return;
		}
		var sql = "select guid as printerId from printer"; // 根据printer id查找printer以及备用printer
		printerDao.query(sql)
		.then(function (result) {
			for (var i = 0; i < result.detail.length; i++) {
				var row = result.detail[i];
				PrintService._runPerPrinter(row.printerId);
			}
		});
	};
	
	PrintService._runPerPrinter = function(printerId){
		if(!running) {
			return;
		}
	    jobDao.all('status <> ? and error_count <= ? and processing=? and printer_id=? order by createTime limit 10', [1, repeatTimesOnError, 0, printerId])
	    //jobDao.all('status <> ?  and processing=? and printer_id=? order by createTime limit 10', [1,  0, printerId])
		.then(function(rows){
			var totalLength = rows.length;
			if(totalLength == 0){
				$window.setTimeout(function(){
					PrintService._runPerPrinter(printerId);
				}, interval);
				return;
			}
			var funcs = [];
			var execute_job = function(job,idx){
				return function(callback){
					PrintService._executeJob(job,function(){callback(null, job.id)});
				}
			};
			for(idx in rows) {
				var job = PrintService._convertToJob(rows[idx]);
				funcs.push(execute_job(job, idx));
			}
			async.parallel(funcs,
			function(err, results){
				if(results.length == totalLength) {
					$window.setTimeout(function(){
						PrintService._runPerPrinter(printerId);
					}, interval);
				}
			});
		});
	};
	
	PrintService.addJob = function(printerJob){
		var type = "print_job";
		if(printerJob.invoiceCode == "R001" || printerJob.invoiceCode == "R002"){
			type += "_"+printerJob.mPrinterId + "_" + printerJob.invoiceCode;
		}
		UniqueIDService.nextSeq(new Date(), type, function(err, seq){
			if(err){
				
			}
			printerJob.createTime = new Date();
			printerJob.status = 0;
			printerJob.errorCount = 0;
			printerJob.jobNo = ""+seq;
			printerJob.printCount = 0;
			PrintService._saveJob(printerJob);
		});
	};
	
	PrintService.initInvoiceNo = function(callback){
		var now = new Date();
		var sql = "select guid as printerId from printer"; // 根据printer id查找printer以及备用printer
		printerDao.query(sql)
		.then(function (result) {
			for (var i = 0; i < result.detail.length; i++) {
				var row = result.detail[i];
				UniqueIDService.init(now, "print_job"+"_"+row.printerId + "_R001", function(err, seq){});
				UniqueIDService.init(now, "print_job"+"_"+row.printerId + "_R002", function(err, seq){});
				if(callback){
					callback();
				}
			}
		});
	};
	
	PrintService._saveJob = function(job, callback){
		if(job.id == null){
			job.id = jobDao.guid();
			jobDao.insert({guid:job.id,name:job.name,printer_id:job.mPrinterId,final_printer_id:job.final_printer_id,status:job.status,processing: job.processing,error_count:job.errorCount,content:job.content.encodeHex(),createTime: job.createTime.format("yyyy-MM-dd hh:mm:ss.S"),invoice_code:job.invoiceCode,ref:job.ref,order_id:job.orderId,job_no:job.jobNo,print_count:job.printCount,operator:job.operator}).then(function(result){
				if(callback){
					callback(job, result);
				}
			});
		}
		else{
			jobDao.updateObject({guid:job.id,final_printer_id:job.final_printer_id,status:job.status,error_count:job.errorCount,print_count:job.printCount,printTime:job.printTime.format("yyyy-MM-dd hh:mm:ss.S")}, "guid").then(function(result){
				if(callback){
					callback(job, result);
				}
			});
		}
	};
	
	PrintService._addJobLog = function(job, message){
		jobLogDao.insert({guid:jobLogDao.guid(), job_id: job.id, status:job.status, createTime: (new Date()).format("yyyy-MM-dd hh:mm:ss.S"), message:message});
	};
	
	PrintService._convertToJob = function(row){
		var job = new PrinterJob();
		job.id = row.guid;
		job.name = row.name;
		job.mPrinterId = row.printer_id;
		job.status = row.status;
		job.errorCount = row.error_count;
		job.content = row.content.decodeHex();
		job.createTime = new Date(row.createTime);
		job.invoiceCode = row.invoice_code;
		job.ref = row.ref;
		job.orderId = row.order_id;
		job.jobNo = row.job_no;
		job.printTime = new Date(row.printTime);;
		job.printCount = row.print_count;
		job.operator = row.operator;
		
		return job;
	};
	
	PrintService.removeJob = function(jobId){
		jobDao.remove('id=?', [jobId]);
	};
	
	PrintService.stop = function(){
		running = false;
	};
	
	PrintService.bootstrapCheckStatus = function(){
		PrintService.checkPrinterStatus();
		window.setTimeout(PrintService.bootstrapCheckStatus, 300000);
	};
	
	PrintService.checkPrinterStatus = function(){
		var sql = "select guid as printerId from printer"; // 根据printer id查找printer以及备用printer
		printerDao.query(sql)
		.then(function (result) {
			for (var i = 0; i < result.detail.length; i++) {
				var row = result.detail[i];
				PrintService._findPrinter(row.printerId, function (printer) {
				    //debugger;
				    if (printer)
					    printer.checkStatus(PrintService, function(){});
				});
			}
		});
	};
	
	PrintService._addPrinterStatusLog = function(printer, message){
		statusLogDao.insert({guid:statusLogDao.guid(), printer_id: printer.id, status:printer.status, createTime: (new Date()).format("yyyy-MM-dd hh:mm:ss.S"), message:message});
	};
	
	PrintService._updatePrinter = function(printer, callback){
		printerDao.updateObject({guid:printer.id,status:printer.status}, "guid").then(function(result){
			if(callback){
				callback(printer, result);
			}
		});
		DataSyncService.syncPrinter(printer);
	};
	
	PrintService.allPrintCaipin = function (callback)
	{
	    var sql = "SELECT a.caipinCode,a.caipinId,a.printSchemeId,a.caipinTypeId,b.printid  FROM pos_print_caipin a left join pos_print_scheme b  on a.printSchemeId=b.guid"; 
	    
	    printerDao.query(sql)
        .then(function (result) {
            var printcaipinlist = [];
            
            for (var i = 0; i < result.detail.length; i++) {
                var row = result.detail[i];
                var printcaipin = new printCaipin();
                printcaipin.caipinId = row.caipinId;
                printcaipin.caipinCode = row.caipinCode;
                printcaipin.printSchemeId = row.printSchemeId;
                printcaipin.caipinTypeId = row.caipinTypeId;
                printcaipin.printid = row.printid;

                printcaipinlist.push(printcaipin);
            }
            callback(printcaipinlist);
        });
	}

	PrintService.allPrintReceipt = function (callback) {
	    var sql = "select a.guid guid,a.printId printId,a.name name,c.name printName,ifnull(a.number,1) number,b.content ,c.size size,d.name configname,d.value configvalue from pos_print_receipt a left join pos_print_receipt_template b on a.guid=b.printReceiptId LEFT JOIN printer c on a.printId=c.guid LEFT JOIN printer_config d ON c.guid = d.printer_id";

	    printerDao.query(sql)
        .then(function (result) {
            var printreceiptlist = [];

            for (var i = 0; i < result.detail.length; i++) {
                var row = result.detail[i];
                var printreceiptindex = Utils.arrayFindIndex(printreceiptlist, row.guid, 'id');
                var printreceipt = printreceiptlist[printreceiptindex];
                if (printreceipt==null)
                {
                    printreceipt = new printReceipt(row.name);
                    printreceipt.id = row.guid;
                    printreceipt.printName = row.printName;
                    printreceipt.printId = row.printId;
                    printreceipt.code = row.name;
                    printreceipt.number = row.number;
                    printreceipt.template = row.content;
                    printreceipt.size = Utils.m(row.size);
                    if (!row.size)
                        printreceipt.size = 80;
                    printreceiptlist.push(printreceipt);
                }
                if (row.configname)
                    printreceipt[row.configname] = row.configvalue;   
            }
            callback(printreceiptlist);
        });
	}

	PrintService.allPrintTemplate = function (callback) {
	    var sql = "select * from pos_sys_print_receipt_template";

	    printerDao.query(sql)
        .then(function (result) {
            var printreceiptlist = [];

            for (var i = 0; i < result.detail.length; i++) {
                var row = result.detail[i];
                var template = new pos_sys_print_receipt_template();
                template.id = row.guid;
                template.code = row.code;
                template.newContent = row.newContent;
                template.sourceContent = row.sourceContent;
                template.sourceContent58 = row.sourceContent58;
                template.size = 80;
                if (row.guiGe)
                    template.size = Utils.m(row.guiGe);

                printreceiptlist.push(template);
            }
            callback(printreceiptlist);
        });
	}

    //打印服务启动时调用此方法，把打印异常的Job恢复正常
	PrintService.reInitPrintJob = function ()
	{
	    var sql = "update printer_job set processing=0,error_count=0 where status=0 AND processing<>0";
	    jobDao.query(sql);
	}

    return PrintService;
}]);