app.factory('UniqueIDService', ['$q', 'database', function ($q,database) {
    var UniqueIDService = {};

    var uniqueIdDb = new DatabaseFuncDelegate($q, database, 'tmp_uniqueid');

    /// 获取当前的seq, 根据date, type来查找
    /// 如：获取当日订单的序号： UniqueIDService.getSeq(new Date(), 'order')
    UniqueIDService.getSeq = function(date, type, cb){
        var datestr = date.format("yyyy-MM-dd");
        uniqueIdDb.all("usedate=? and usetype=? order by seq desc", [datestr, type]).then(function(rows){
            if(rows.length < 1){
                uniqueIdDb.insert({id: uniqueIdDb.guid(), usedate: datestr, usetype:type, seq: 1}).then(function(results){
                    cb(null, 1);
                }, function(err){
                    cb(err);
                });
            }
            else{
                return cb(null, rows[0].seq);
            }
        });
    };
	
	UniqueIDService.init = function(date, type, cb){
        var datestr = date.format("yyyy-MM-dd");
        uniqueIdDb.all("usedate=? and usetype=? order by seq desc", [datestr, type]).then(function(rows){
            if(rows.length < 1){
                uniqueIdDb.insert({id: uniqueIdDb.guid(), usedate: datestr, usetype:type, seq: 0}).then(function(results){
                    cb(null, 0);
                }, function(err){
                    cb(err);
                });
            }
            else{
                return cb(null, rows[0].seq);
            }
        });
    };

    /// 获取最新的seq, 如果已存在，则在原先的seq上递增一个
    UniqueIDService.nextSeq = function(date, type, cb){
        var datestr = date.format("yyyy-MM-dd");
        //uniqueIdDb.all("usedate = date('now') and usetype=? order by seq desc", [type]).then(function (rows) {
        uniqueIdDb.query("select '' id, date('now','localtime') usedate,'' usetype,'' seq UNION ALL SELECT  * from  tmp_uniqueid where usedate = date('now','localtime') and usetype='" + type + "'   order by seq desc").then(function (result) {
            var rows = result.detail;
            var nowdate = rows[0].usedate.replaceAll('-', '');
            if (rows.length < 2) {
                uniqueIdDb.query("insert into tmp_uniqueid (id,usedate,usetype,seq) values ('" + uniqueIdDb.guid() + "',date('now','localtime'),'" + type + "',1) ").then(function (results) {
                //uniqueIdDb.insert({id: uniqueIdDb.guid(), usedate: datestr, usetype:type, seq: 1}).then(function(results){
                    cb(null, 1, nowdate);
                }, function(err){
                    cb(err);
                });
            }
            else{
                var newseq = rows[1].seq + 1;
                uniqueIdDb.query("update tmp_uniqueid set seq="+newseq+" where id='"+rows[1].id+"' and seq="+rows[1].seq).then(function(results){
					if(results.rowsAffected[0] > 0){
					    return cb(null, newseq, nowdate);
					}
					else{
						return UniqueIDService.nextSeq(date, type, cb);
					}
                }, function(err){
                    cb(err);
                });
            }
        });
    };

    /// 获取最新的几个seq
    UniqueIDService.nextSeqs = function(date, type, num, cb){
        var datestr = date.format("yyyy-MM-dd");


        uniqueIdDb.query("select '' id, date('now','localtime') usedate,'' usetype,'' seq UNION ALL SELECT  * from  tmp_uniqueid where usedate = date('now','localtime') and usetype='" + type + "'   order by seq desc").then(function (result) {
            var rows = result.detail;
            var nowdate = rows[0].usedate.replaceAll('-', '');
            if (rows.length < 2) {
                uniqueIdDb.query("insert into tmp_uniqueid (id,usedate,usetype,seq) values ('" + uniqueIdDb.guid() + "',date('now','localtime'),'" + type + "',1) ").then(function (results) {
                    //uniqueIdDb.insert({id: uniqueIdDb.guid(), usedate: datestr, usetype:type, seq: 1}).then(function(results){
                    cb(null, getSeqs(1, num), nowdate);
                }, function (err) {
                    cb(err);
                });
            }
            else {
                var newseq = rows[1].seq + num;
                uniqueIdDb.query("update tmp_uniqueid set seq=" + newseq + " where id='" + rows[1].id + "' and seq=" + rows[1].seq).then(function (results) {
                    if (results.rowsAffected[0] > 0) {
                        //return cb(null, newseq, nowdate);
                        return cb(null, getSeqs(rows[1].seq + 1, num), nowdate);
                    }
                    else {
                        return UniqueIDService.nextSeqs(date, type, num, cb);
                    }
                }, function (err) {
                    cb(err);
                });
            }
        });

    };

    function getSeqs(startIndex, num){
        var seq = [];
        for(var i =0;i<num;i++){
            seq.push(startIndex + i);
        }
        return seq;
    }

    /// 获取最大的Seq，防止时间错乱导致的数据错乱
    UniqueIDService.MaxSeq = function (table,colume,typename,cb) {
        var sql = "select datetime('now','localtime') m UNION all select Max(" + colume +" ) m from " + table;
        uniqueIdDb.query(sql).then(function (result) {
            var rows = result.detail;
            var nowtime = rows[0].m;
            var Seq = '0';
            if (rows.length > 1)
                Seq = rows[1].m;
            if (!Seq)
                Seq = '0';
            Seq = Seq.replaceAll(typename, '');
            cb(null, Seq, nowtime);
        }, function (err) {
            cb(err, null, nowtime);
        });
    };

    return UniqueIDService;
}]);