/// 打印模板语义解析
/// #{...} 数据项
/// <...> 行居中
/// [...] 2倍宽
/// (...) 2倍高
/// $...$ 2倍大小
/// #3[...] 3倍宽
/// #3(...) 3倍高
/// #3$...$ 3倍大小
/// #4[...] 4倍宽
/// #4(...) 4倍高
/// #4$...$ 4倍大小
/// #5[...] 5倍宽
/// #5(...) 5倍高
/// #5$...$ 5倍大小
function PrinterTemplate() {
    var isDebug = true;
    this.getTemplate = function () { };
    this.invoice = null;
    this.size = 80;
    var recursionLevel = 5;//递归最大层级数
    this.parse = function (object, invoice) {
        this.invoice = invoice;
        this.size = invoice.size;
        this.setPrinterArg(invoice.size);
        var printeTemplateText = isDebug ? this.getTemplate() : invoice.template;
        var printContent = this._parseObject(this.filterChars(object), invoice, printeTemplateText);
        printContent = printContent.replaceAll('#{门店名称}', BIZCONSTANT.POSUSER.HotelName)
                                    .replaceAll('#{门店电话}', BIZCONSTANT.POSUSER.HotelTel)
                                    .replaceAll('#{门店地址}', BIZCONSTANT.POSUSER.HotelAddress);

        if (invoice && printContent.indexOf('#{打印机名称}') > -1)
        {
            var printname = invoice.printName ? invoice.printName : '';
            printContent = printContent.replaceAll('#{打印机名称}', printname);
        }
        console.info(printContent);
        // add by Samuel: 用来适配机器D800 －－－特殊机器有些特殊字符干扰打印
        if ((CONTEXT.env == CONSTANTS.EnvConstants.ANDROID && window.yunshan.isD800Device()) || CONTEXT.env == CONSTANTS.EnvConstants.IOS) {
            return this._filterCharsForD800(printContent);
        }
        return invoice.islable == 'true' ? this._parseSymbol2(printContent, invoice) : this._parseSymbol(printContent);
    };

    //使用递归的方式，将数据源对象中的string类型的属性，全部替换掉特殊字符
    //很多对象之间有互相引用，必须设置递归的最大层级数
    this.filterChars = function (object, level) {
        if (!level)
            level = 1;
        //console.group(level);
        if (level >= recursionLevel)
            return object;
        for (var i in object) {
            try {
                var objtype = typeof object[i];
                if (objtype === 'object' && object[i]) {
                    //console.log(i, objtype, object[i], level);
                    if (Utils.isArray(object[i]) && object[i].length == 0 || level > recursionLevel)
                        continue;

                    object[i] = this.filterChars(object[i], level + 1);
                }
                else if (typeof object[i] === 'string' && isNaN(object[i]))
                    object[i] = object[i].replaceAll("\\[", "【")
                        .replaceAll("\\]", "】")
                        .replaceAll('\\(', '（')
                        .replaceAll('\\)', '）')
                        .replaceAll('\\<', '《')
                        .replaceAll('\\>', '》')
                        .replaceAll('\\+', '＋')
                        .replaceAll('\\*', 'x')
                        .replaceAll('\\.', '。')
                        .replaceAll('\\^', '-')
                        .replaceAll('\\\\', '')
                        .replaceAll('·', ':')
                        .replaceAll("\\$", "￥");
            } catch (e) { }
        }
        //console.groupEnd();
        return object;
    }

    // add by Samuel: 用来过滤特殊字印，避免干扰D800内置打印机的打印，此工作应该由通联sdk做到识别指令
    this._filterCharsForD800 = function (origintext) {
        origintext = origintext.replaceAll("\\[", "").replaceAll("\\]", "").replaceAll('\\(', '').replaceAll('\\)', '');
        origintext = origintext.replaceAll('\\<', '').replaceAll('\\>', '');
        origintext = origintext.replaceAll("#{}", "").replaceAll("<>", "").replaceAll("[]", "").replaceAll("()", "").replaceAll("$$", "").replaceAll("#3[]", "")
            .replaceAll("#3()", "").replaceAll("#3$$", "").replaceAll("#4[]", "").replaceAll("#4()", "").replaceAll("#4$$", "").replaceAll("#5[]", "").replaceAll("#5()", "").replaceAll("#5$$", "");

        return origintext;
    }

    this._parseObject = function (object, invoice) { };

    //Esc命令
    this._parseSymbol = function (printtext) {
        //字体倍宽
        var arr = printtext.match(/#[3-5]\[.+?\]/ig)
        if (arr) {
            for (var si in arr) {
                var item = arr[si];
                var rate = item.substring(1, 2);
                var itemvalue = item.substring(2).replaceAll('\\[', '').replaceAll('\\]', '');
                item = "#" + rate + "[" + itemvalue + "]";
                if (rate == "3") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(5) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "4") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(8) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "5") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(11) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
            }
        }

        //字体倍高
        var arr = printtext.match(/#[3-5]\(.+?\)/ig)
        if (arr) {
            for (var si in arr) {
                var item = arr[si];
                var rate = item.substring(1, 2);
                var itemvalue = item.substring(2).replaceAll('\\(', '').replaceAll('\\)', '');
                item = "#" + rate + "(" + itemvalue + ")";
                if (rate == "3") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(4) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "4") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(7) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "5") {
                    printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(10) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
            }
        }

        //字体倍大小
        var arr = printtext.match(/#[3-5]\$.+?\$/ig)
        if (arr) {
            for (var si in arr) {
                var item = arr[si];
                var rate = item.substring(1, 2);
                var itemvalue = item.substring(2).replaceAll('\\$', '');
                item = "#" + rate + "$" + itemvalue + "$";
                if (rate == "3") {
                    printtext = printtext.replaceAll2(item, PrinterCommand.CMD_FontSize(6) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "4") {
                    printtext = printtext.replaceAll2(item, PrinterCommand.CMD_FontSize(9) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
                else if (rate == "5") {
                    printtext = printtext.replaceAll2(item, PrinterCommand.CMD_FontSize(12) + itemvalue + PrinterCommand.CMD_FontSize(0));
                }
            }
        }

        //字体宽度
        var arr = printtext.match(/\[.+?\]/ig)
        if (arr) {
            for (var si in arr) {
                var item = arr[si];
                var count = item.Count('[');
                var itemvalue = item.replaceAll('\\[', '').replaceAll('\\]', '');
                item = item.replaceAll('\\]', '').replaceAll('\\[', '\\[');
                for (var ri = 0; ri < count; ri++)
                    item += '\\]';
                printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(2) + itemvalue + PrinterCommand.CMD_FontSize(0));
            }
        }

        //字体高度
        var barr = printtext.match(/\(.+?\)/ig)
        if (barr) {
            for (var si in barr) {
                var item = barr[si];
                var count = item.Count('(');
                var itemvalue = item.replaceAll('\\(', '').replaceAll('\\)', '');
                item = item.replaceAll('\\)', '').replaceAll('\\(', '\\(');
                for (var ri = 0; ri < count; ri++)
                    item += '\\)';
                printtext = printtext.replaceAll(item, PrinterCommand.CMD_FontSize(1) + itemvalue + PrinterCommand.CMD_FontSize(0));
            }
        }

        //字体大小
        var barr = printtext.match(/\$.+?\$/ig)
        if (barr) {
            for (var si in barr) {
                var item = barr[si];
                var itemvalue = item.replaceAll('\\$', '')
                item = "$" + itemvalue + "$";
                printtext = printtext.replaceAll2(item, PrinterCommand.CMD_FontSize(3) + itemvalue + PrinterCommand.CMD_FontSize(0));
            }
        }

       

        //行居中
        var lines = printtext.split("\n");
        printtext = "";
        for (var idx in lines) {
            var line = lines[idx];
            var barr = line.match(/\<.+?\>/ig)
            if (barr) {

                for (var i in barr)
                {
                    var tpitem = barr[i];
                    var clonetp = tpitem;
                    if (clonetp.indexOf('<R') >= 0)
                    {
                        clonetp = PrinterCommand.CMD_TextAlign(2) + clonetp.replaceAll('\\<R', '').replaceAll('R\\>', '');
                    }
                    else if (clonetp.indexOf('<L') >= 0) {
                        clonetp = PrinterCommand.CMD_TextAlign(0) + clonetp.replaceAll('\\<L', '').replaceAll('L\\>', '');
                    }
                    else
                        clonetp = PrinterCommand.CMD_TextAlign(1) + clonetp.replaceAll('\\<', '').replaceAll('\\>', '');
                    line = line.replaceAll(tpitem, clonetp);
                }

                //line = line.replaceAll('\\<', '').replaceAll('\\>', '');
                //line = PrinterCommand.CMD_TextAlign(1) + line;
            }
            else {
                line = PrinterCommand.CMD_TextAlign(0) + line;
            }
            printtext += line + "\n";
        }

        /// #{...} 数据项
        /// <...> 行居中
        /// [...] 2倍宽
        /// (...) 2倍高
        /// $...$ 2倍大小
        /// #3[...] 3倍宽
        /// #3(...) 3倍高
        /// #3$...$ 3倍大小
        /// #4[...] 4倍宽
        /// #4(...) 4倍高
        /// #4$...$ 4倍大小
        /// #5[...] 5倍宽
        /// #5(...) 5倍高
        /// #5$...$ 5倍大小

        printtext = printtext.replaceAll("#{}", "").replaceAll("<>", "").replaceAll("[]", "").replaceAll("()", "").replaceAll("$$", "").replaceAll("#3[]", "")
            .replaceAll("#3()", "").replaceAll("#3$$", "").replaceAll("#4[]", "").replaceAll("#4()", "").replaceAll("#4$$", "").replaceAll("#5[]", "").replaceAll("#5()", "").replaceAll("#5$$", "");

        return printtext;
    };

    //TSC标签指令
    this._parseSymbol2 = function (printtext, invoice) {

        printtext = printtext.replaceAll('#{打印时间}', (new Date()).format("hh:mm")).replaceAll('#{日期}', (new Date()).format("MM/dd"));
        

        var lable_w = 50;
        var lable_h = 30;

        if (invoice.lablewidth)
            lable_w = invoice.lablewidth;
        if (invoice.lableheight)
            lable_h = invoice.lableheight;

        var line_length = parseInt(lable_w / 3);//16;
        var rtprintstr = PrinterCommand.TSCCommand.Setup(lable_w, lable_h, 12, 8, 0, 5, 0) + PrinterCommand.TSCCommand.ClearBuffer();
        //PrinterCommand.TSCCommand.TextBgein(10, 50);
        //PrinterCommand.TSCCommand.Text(printtext) +
        //PrinterCommand.TSCCommand.Print();

        //printtext += "SIZE 30 mm, 20 mm\n" +
        //        "SPEED 12\n" +
        //        "GAP 5 mm, 0 mm\n" +
        //        "DENSITY 8\n" +
        //        "DIRECTION 1,1\n" +
        //        "SET TEAR ON\n" +
        //        "SHIFT 10\n" +
        //        "CLS\n" +
        //        "TEXT 10,10,\"TSS24.BF2\",0,1,1,\"万通中心店 午餐\"\n" +
        //        "TEXT 50,50,\"TSS24.BF2\",0,1,1,\"万通中心店 午餐\"\n" +
        //        "TEXT 10,25,\"TSS24.BF2\",0,1,1,\"万通中心店 午餐\"\n" +
        //        "PRINT 1, 1 \n";
        var rtarr = [];
        var printstrarr = printtext.split('\n');
        var x_start = 10;
        var y_start = 5;
        var basehight = 12;
        for (var li in printstrarr)
        {
            var str = printstrarr[li];
            var font_w_size = 1;
            var font_h_size = 1;
            var font_sise = 1;
            //倍宽
            var arr = str.match(/#[3-5]\[.+?\]/ig)
            if (arr) {
                for (var si in arr) {
                    var item = arr[si];
                    var rate = parseInt(item.substring(1, 2));
                    if (rate > font_w_size)
                        font_w_size = rate;
                    var itemvalue = item.substring(2).replaceAll('\\[', '').replaceAll('\\]', '');
                    item = "#" + rate + "[" + itemvalue + "]";
                    str = str.replaceAll(item, itemvalue);
                }
            }

            //字体倍高
            var arr = str.match(/#[3-5]\(.+?\)/ig)
            if (arr) {
                for (var si in arr) {
                    var item = arr[si];
                    var rate = parseInt(item.substring(1, 2));
                    if (rate > font_h_size)
                        font_h_size = rate;
                    var itemvalue = item.substring(2).replaceAll('\\(', '').replaceAll('\\)', '');
                    item = "#" + rate + "(" + itemvalue + ")";
                    str = str.replaceAll(item, itemvalue);
                }
            }

            //字体倍大小
            var arr = str.match(/#[3-5]\$.+?\$/ig)
            if (arr) {
                for (var si in arr) {
                    var item = arr[si];
                    var rate = parseInt(item.substring(1, 2));
                    if (rate > font_sise)
                        font_sise = rate;
                    var itemvalue = item.substring(2).replaceAll('\\$', '');
                    item = "#" + rate + "$" + itemvalue + "$";
                    str = str.replaceAll(item, itemvalue);
                }
            }


            //字体宽度
            var arr = str.match(/\[.+?\]/ig)
            if (arr && arr.length > 0) {
                if (font_w_size == 1)
                    font_w_size = 2;
                for (var si in arr) {
                    var item = arr[si];
                    var count = item.Count('[');
                    var itemvalue = item.replaceAll('\\[', '').replaceAll('\\]', '');
                    item = item.replaceAll('\\]', '').replaceAll('\\[', '\\[');
                    for (var ri = 0; ri < count; ri++)
                        item += '\\]';
                    str = str.replaceAll(item, itemvalue);
                }
            }

            //字体高度
            var barr = str.match(/\(.+?\)/ig)
            if (barr && barr.length > 0) {
                if (font_h_size == 1)
                    font_h_size = 2;
                for (var si in barr) {
                    var item = barr[si];
                    var count = item.Count('(');
                    var itemvalue = item.replaceAll('\\(', '').replaceAll('\\)', '');
                    item = item.replaceAll('\\)', '').replaceAll('\\(', '\\(');
                    for (var ri = 0; ri < count; ri++)
                        item += '\\)';
                    str = str.replaceAll(item, itemvalue);
                }
            }

            //字体大小
            var barr = str.match(/\$.+?\$/ig)
            if (barr && barr.length > 0) {
                if (font_sise == 1)
                    font_sise = 2;
                for (var si in barr) {
                    var item = barr[si];
                    var itemvalue = item.replaceAll('\\$', '')
                    item = "$" + itemvalue + "$";
                    str = str.replaceAll(item, itemvalue);
                }
            }


            str = str.replaceAll("#{}", "").replaceAll("<>", "")
                .replaceAll("[]", "").replaceAll("()", "")
                .replaceAll("$$", "").replaceAll("#3[]", "")
                .replaceAll("#3()", "").replaceAll("#3$$", "")
                .replaceAll("#4[]", "").replaceAll("#4()", "")
                .replaceAll("#4$$", "").replaceAll("#5[]", "")
                .replaceAll("#5()", "").replaceAll("#5$$", "")
                .replaceAll("\\<R", "").replaceAll("R\\>", "")
                .replaceAll("\\<L", "").replaceAll("L\\>", "")
                .replaceAll("\\<", "").replaceAll("\\>", "");

            str = str.replaceAll("             ", "");
            if (font_sise > font_h_size || font_sise > font_w_size) {
                font_h_size = font_sise;
                font_w_size = font_sise;
            } else
                font_sise = 0;
            var linenum = parseInt((Utils.getPrinterLength(str)/2)/ line_length);
            if ((str.length % line_length) > 0)
                linenum++;
            for (var line_idx = 1; line_idx <= linenum; line_idx++)
            {
                var text = str.substring((line_idx - 1) * line_length, (line_idx == linenum ? (str.length) : (line_idx * line_length)));
                rtarr.push(PrinterCommand.TSCCommand.TextBgein(x_start, y_start, font_w_size, font_h_size) + PrinterCommand.TSCCommand.Text(text));
                y_start = y_start + (basehight * font_h_size);
                rtarr.push(PrinterCommand.TSCCommand.TextBgein(x_start, y_start, font_w_size, font_h_size) + PrinterCommand.TSCCommand.Text(''));
                y_start = y_start + (basehight * font_h_size);
            }
            if(linenum==0)
            {
                
                rtarr.push(PrinterCommand.TSCCommand.TextBgein(x_start, y_start, font_w_size, font_h_size) + PrinterCommand.TSCCommand.Text(str));
                y_start = y_start + (basehight * font_h_size);
                rtarr.push(PrinterCommand.TSCCommand.TextBgein(x_start, y_start, font_w_size, font_h_size) + PrinterCommand.TSCCommand.Text(''));
                y_start = y_start + (basehight * font_h_size);
            }
        }

        console.log(printtext);
        //return printtext;
        //字体倍宽
        

        /// #{...} 数据项
        /// <...> 行居中
        /// [...] 2倍宽
        /// (...) 2倍高
        /// $...$ 2倍大小
        /// #3[...] 3倍宽
        /// #3(...) 3倍高
        /// #3$...$ 3倍大小
        /// #4[...] 4倍宽
        /// #4(...) 4倍高
        /// #4$...$ 4倍大小
        /// #5[...] 5倍宽
        /// #5(...) 5倍高
        /// #5$...$ 5倍大小

       
        return rtprintstr + rtarr.join('');
    };


    this.setPrinterArg = function (size) {
        this.size = size;
    };

    // 共 xx 道 oo 份
    // retuen { dishCount : xx,dishNum : oo }
    this.getDishsMasterInfo = function (dishs) {
        var dishidarr = [];
        var dishcount = 0;
        for(var i in dishs)
        {
            var dish = dishs[i];
            var dishnum = dish.num - dish.tuiNum;
            dishcount += dishnum;
            if (dishidarr.indexOf(dish.caipinId) < 0)
                dishidarr.push(dish.caipinId);
        }
        return { dishCount: dishidarr.length, dishNum: dishcount };
    }

    // 统计财务类别合计
    this.getDishsTypeMasterInfo = function (dishs)
    {
        var linelen = 40;
        if (this.size != 80)
            linelen = 32;
        var cwlbhj = [];
        for (var i in dishs) {
            var tcp = Utils.clone(dishs[i]);
            if (tcp.num <= 0)
                continue;

            var num = tcp.num - tcp.tuiNum - tcp.zengNum;
            if (num <= 0)
                continue;
            var cw = null;
            for (var j in cwlbhj) {
                if (cwlbhj[j].kid == tcp.caiwuTypeId)
                    cw = cwlbhj[j];
            }
            if (cw == null && tcp.caiwuTypeId)
                cwlbhj.push({ kid: tcp.caiwuTypeId, kname: tcp.caiwuTypeName, kmoney: tcp.m4Print() });
            else if (cw)
                cw.kmoney += tcp.m4Print();
        }

        var cwlbhjstr = '';
        for (var h in cwlbhj) {
            var itemstr = cwlbhj[h].kname + ":" + this.m2string(cwlbhj[h].kmoney);
            if ((Utils.getPrinterLength(itemstr) + Utils.getPrinterLength(cwlbhjstr)) > linelen)
                cwlbhjstr += '\n';
            cwlbhjstr += itemstr + ' ';
        }
        return cwlbhjstr;
    }

    //{source,text,align,length}
    // 格式化行数据，如果某一项的长度超出给定的限制长度，那么，这项之后的项目则换行对齐打印
    // 动态参数，第一个是模板，之后所有参数都是数据源项目，结构见上方
    // example: #{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}
    this.formatTemplateLine=function()
    {
        var args = arguments;
        if (args.length == 1 && Utils.isArray(args[0]))
            args = args[0];
        var sourceArgs = Utils.clone(args);
        var template=args[0];
        var getBrforeLength=function (endindex,args) {
            var len= 0;
            for(var gi=1;gi<=endindex;gi++)
            {
                len = len +args[gi].length;
            }
            return len;
        }

        for(var i = 1; i<args.length;i++)
        {
            var model = args[i];
            if (!model.length)
                continue;
            if (!model.align || model.align.length == 0)
            {
                model.align = i == 1 ? "L" : "R";
            }
            var reallenght=Utils.getPrinterLength(model.text);
            if (reallenght <= model.length){
                if (model.align == 'R')
                    model.text = Utils.printBlank(model.length - reallenght) + model.text;
                else if (model.align == 'L')
                    model.text = model.text + Utils.printBlank(model.length - reallenght);
                else
                {
                    var llen = parseInt((model.length - reallenght) / 2);
                    var rlen = parseInt((model.length - reallenght) / 2);
                    if (((model.length - reallenght) % 2) != 0)
                        llen++;
                    model.text = Utils.printBlank(llen) + model.text + Utils.printBlank(rlen);
                }   
            }
            else
            {
                //if(i<(args.length-1))
                //{
                    if (model.align=='L')
                        model.text = model.text + '\n' + Utils.printBlank(getBrforeLength(i, sourceArgs));
                    else
                        model.text = '\n' + Utils.printBlank(getBrforeLength(i-1, sourceArgs) - (reallenght - model.length)) + model.text;
                //}
            }
        }
        for(var m=1;m<args.length;m++)
        {
            template = template.replaceAll(args[m].source, args[m].text);
        }
        return template;
    }

    //格式化数字，默认的强制两位小数
    // 子类中处理数字必须使用此方法
    // 特殊需求的覆写此方法即可
    this.m2string = function (m) {
        return Utils.m2string(m);
    }

    //菜品排序
    this.sortDishs = function (dishs) {
       
        var sourcearr = [];
        for (var v in dishs) {
            var dish = dishs[v];
            dish.caiwuTypeName = dish.caiwuTypeName ? dish.caiwuTypeName : '';
            sourcearr.push(dish);
        }
        var rtdishs = [];
        if (!CAT_PAR.REMOTE.PRINTDISHSORT || CAT_PAR.REMOTE.PRINTDISHSORT == '0')// 按点菜时间排
            rtdishs = sourcearr.sort(function (v1, v2) { return Utils.m(v1.luoDanTime) - Utils.m(v2.luoDanTime) });
        if (CAT_PAR.REMOTE.PRINTDISHSORT == '1')// 按菜品类别排序
            rtdishs = sourcearr.sort(function (v1, v2) { return Utils.m(v1.caipinTypeCode) - Utils.m(v2.caipinTypeCode) });
        if (CAT_PAR.REMOTE.PRINTDISHSORT == '2')// 按财务类别排序
            rtdishs = sourcearr.sort(function (a, b) {
                if (a.caiwuTypeName.length == 0 && b.caiwuTypeName.length != 0)
                    return 1;
                if (a.caiwuTypeName.length != 0 && b.caiwuTypeName.length == 0)
                    return -1;
                return a.caiwuTypeName.localeCompare(b.caiwuTypeName);
            });
        return rtdishs;
    }

    this.dateFormat = function (dateorstr, formatstr) {
        if (!formatstr)
            formatstr = "hh:mm";
        var sdate = new Date(dateorstr);
        var now = new Date();
        if (sdate == 'Invalid Date')
            return '';
        // 判断日期是否相等 
        var IsDateEquals = function (date1, date2) {
            return date1.getDate() == date2.getDate() && date1.getMonth() == date2.getMonth() && date1.getFullYear() == date2.getFullYear();
        };

        var AddDays = function (date, value) {
            return new Date(date.setDate(date.getDate() + value));
        };
        if (IsDateEquals(sdate, now))
            return '今天 ' + sdate.format(formatstr);

        if(IsDateEquals(AddDays(now,1), sdate))
            return '明天 ' + sdate.format(formatstr);

        if (IsDateEquals(AddDays(now, 2), sdate))
            return '后天 ' + sdate.format(formatstr);

        return sdate.format('yy-MM-dd '+formatstr);
    }
}

PrinterTemplate.fillJobInfo = function (printtext, job) {
    return printtext.replaceAll('#{打印时间}', job.printTime.format("yyyy-MM-dd hh:mm"))
        .replaceAll('#{单据号}', job.jobNo);
}

function OrderPrint() {
    this.company = '袁州食府';
    this.companyphone = '0795-3563999';
    this.companyaddress = '宜春市环城西路363号';
    this.DCoperator = '管理员';
    this.syoperator = '收银员01';
    this.CBname = '午餐';
    this.rs = 5;
    this.zhuotai = 8318;
    this.ordercode = '2016030100001';
    this.xdtime = '2016-03-01 12:50:55';
    this.jstime = '2016-03-01 16:12:50';
    this.pay_items = [{ payname: '现金', paymoney: 20.00 }, { payname: '银行卡', paymoney: 100.00 }];
    this.shijimoney = 120.00;
    this.ordermoney = 120.00;
    this.remark = '';
    this.ret = {
        total: 0, //消费合计
        ofZheKouName: '', //折扣率的名字
        ofZheKouMoney: 0, //折扣掉的金额
        youMian: 0,//定额
        free: 0, //赠送
        payment: [],
        danPinSum: 0,
        moLingSum: 0
    };
    this.dishs = [{ name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 }, { name: '清炒空心菜', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }, { name: '剑南春', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }];
}

function JieZhangDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var linelen = 40;
    var spacelen = 0;
    var dishnamelen = 20;
    var dishnumlen = 6;
    var dishpricelen = 7;
    var dishmoneylen = 9;
    var paymentlen = 8;
    var hyjlen = 0;
    // #region 内置模板

    var _template =
				'<[#{门店名称}]>\n' +
				'<[#{结账单}]>\n' +
				'----------------------------------------\n' +
				'<(#{桌台号})>\n' +
                '服务员: #{点菜员}  人数：#{就餐人数}\n' +
                '下单时间：#{下单时间}  餐别:#{餐别}\n' +
                '开单号：#{订单号}\n' +
                '结算时间: #{结算时间}\n' +
                '备注: #{备注}\n' +
                '----------------------------------------\n' +
                '品名            数量      单价       金额\n' +
                '----------------------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '----------------------------------------\n' +
                '退菜\n' +
                '----------------------------------------\n' +
                '#{退菜}\n' +
                '----------------------------------------\n' +
                '赠菜\n' +
                '----------------------------------------\n' +
                '#{赠菜}\n' +
                '----------------------------------------\n' +
                '#{财务类别合计}\n' +
                '----------------------------------------\n' +
				'(消费合计:)                  (#{订单金额})\n' +
                '----------------------------------------\n' +
                '#yzm_item\n' +
                '#{优惠方式}                #{优惠金额}\n' +
                '#yzm_item\n' +
				'----------------------------------------\n' +
				'#pay_item\n' +
				'#{付款方式}                #{付款金额}\n' +
				'#pay_item\n' +
				'----------------------------------------\n' +
                '(合     计:)                    (#{实收金额})\n' +
                '(找     零:)                    (#{找零金额})\n' +
				'\n' +
				'收银员： #{收银员}\n' +
				'\n' +
				'欢迎光临#{门店名称}\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    var _template58 =
				'<[#{门店名称}]>\n' +
				'<[#{结账单}]>\n' +
				'-----------------------------\n' +
				'<(#{桌台号})>\n' +
                '服务员: #{点菜员}  人数：#{就餐人数}\n' +
                '下单时间：#{下单时间}  \n餐别:#{餐别}\n' +
                '开单号：#{订单号}\n' +
                '结算时间: #{结算时间}\n' +
                '备注: #{备注}\n' +
                '-----------------------------\n' +
                '品名         数量   单价   金额\n' +
                '-----------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '-----------------------------\n' +
                '退菜\n' +
                '-----------------------------\n' +
                '#{退菜}\n' +
                '-----------------------------\n' +
                '赠菜\n' +
                '-----------------------------\n' +
                '#{赠菜}\n' +
                '-----------------------------\n' +
                 '#{财务类别合计}\n' +
                '-----------------------------\n' +
				'(消费合计:)              (#{订单金额})\n' +
                '-----------------------------\n' +
                '#yzm_item\n' +
                '#{优惠方式}                #{优惠金额}\n' +
                '#yzm_item\n' +
				'-----------------------------\n' +
				'#pay_item\n' +
				'#{付款方式}                #{付款金额}\n' +
				'#pay_item\n' +
				'-----------------------------\n' +
                '(合     计:)              (#{实收金额})\n' +
                '(找     零:)              (#{找零金额})\n' +
				'\n' +
				'收银员： #{收银员}\n' +
				'\n' +
				'欢迎光临#{门店名称}\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    // #endregion

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 16;
            dishnumlen = 8;
            dishpricelen = 8;
            dishmoneylen = 10;
            paymentlen = 27;
        }
        else {
            linelen = 32;
            dishnamelen = 12;
            dishpricelen = 6;
            dishnumlen = 5;
            dishmoneylen = 6;
            paymentlen = 18;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var order = object;
        var dishTypeinfo = '';

        var templateHasHYJ = printtext.indexOf('#{会员价}') >= 0;
        var orderHasHYJ = !!object.hyJiaYouHui;

        if (templateHasHYJ && orderHasHYJ) {
            this.m2string = function (m) { return Utils.m(m) + ''; }
            //linelen = 32;
            dishnamelen = dishnamelen - 2;
            dishpricelen = dishpricelen - 1;
            dishnumlen = dishnumlen - 1;
            dishmoneylen = dishmoneylen - 2;
            hyjlen = 6;
        }


        order.remark = (order.remark && order.remark != 'null') ? order.remark : ' ';
        if (order.waimaiObj){
            var waimaiObj = order.waimaiObj.orderDeliveryInfo;
            //order.remark = waimaiObj.remark;
            printtext = Utils.removePrintLineByK(printtext, "#{找零金额}");
            var spprinttextarr = printtext.split('\n');
            var spindex = -1;
            for (var s in spprinttextarr) {
                var stext = spprinttextarr[s];
                if (stext.indexOf('#{结账单}') >= 0) {
                    spindex = s;
                    break;
                }     
            }
            if (spindex >= 0) {
                var waimaistr = 
                                '水单编号：#{水单编号}\n'+
                                '客户姓名：#{客户姓名}\n' +
                                '客户电话：#{客户电话}\n' +
                                '客户地址：#{客户地址}\n' +
                                '(送达时间：#{送出时间})\n' +
                                '发    票：#{发票}\n' +
                                '客户备注：#{客户备注}\n' +
                                '<-----------(【#{付款方式}】)----------->\n';

                if (!order.waimaiObj.orderType || order.waimaiObj.orderType != 'WaimaiBook')
                    waimaistr = Utils.removePrintLineByK(waimaistr, '#{送出时间}');
                else
                    waimaistr = waimaistr.replaceAll('#{送出时间}', this.dateFormat(waimaiObj.bookDeliverTime));
                waimaistr = waimaistr.replaceAll('#{送出人员}', waimaiObj.deliverymanName)
                .replaceAll('#{水单编号}', waimaiObj.orderNo)
                .replaceAll('#{客户姓名}', waimaiObj.receiverName)
                .replaceAll('#{客户电话}', waimaiObj.receiverPhone)
                .replaceAll('#{发票}', order.waimaiObj.invoiceType ? order.waimaiObj.invoiceTitle : "无")
                .replaceAll('#{客户地址}', waimaiObj.address.replaceAll('\\(', '（').replaceAll('\\)', '）'))
                .replaceAll('#{付款方式}', (order.waimaiObj.orderTradeInfoList.length > 0 && order.waimaiObj.orderTradeInfoList[0].payType == 1) ? "货到付款" : "在线支付")
                .replaceAll('#{付款类型}', (order.waimaiObj.orderTradeInfoList.length > 0 && order.waimaiObj.orderTradeInfoList[0].payType == 1) ? "货到付款" : "在线支付")
                .replaceAll('#{客户备注}', order.remark);

                var cutline = '';
                for (var li = 0; li < linelen; li++)
                {
                    cutline += '-';
                }

                spprinttextarr[spindex] = spprinttextarr[spindex] + '\n'+cutline+'\n'+waimaistr;
            }
            printtext = spprinttextarr.join('\n');
        }

        // 是对账单的话 不显示订单金额
        if (order.printName === '对账单' && printtext.indexOf('#{订单金额}') >= 0) 
            printtext = Utils.removePrintLineByK(printtext, '#{订单金额}');

        var dishMasterInfo = { dishCount: 0, dishNum: 0 };
        if (printtext.indexOf('#{数量统计}') >= 0)
            dishMasterInfo = this.getDishsMasterInfo(object.dishs);

        if (printtext.indexOf('#{财务类别合计}') >= 0)
            dishTypeinfo = this.getDishsTypeMasterInfo(object.dishs);

        // #region 基本数据源
        printtext = printtext.replaceAll('#{门店地址}', order.companyaddress)
            .replaceAll('#{门店电话}', order.companyphone)
            .replaceAll('#{门店名称}', order.company)
            .replaceAll('#{收银员}', order.syoperator)
            .replaceAll('#{点菜员}', order.DCoperator)
            .replaceAll('#{就餐人数}', order.rs)
            .replaceAll('#{餐别}', order.CBname)
            .replaceAll('#{订单号}', order.ordercode)
            .replaceAll('#{下单时间}', order.xdtime)
            .replaceAll('#{结算时间}', order.jstime)
            .replaceAll('#{桌台号}', order.zhuotai)
            .replaceAll('#{实收金额}', this.m2string(order.shijimoney))
            .replaceAll('#{找零金额}', this.m2string(order.zhaolingmoney))
            .replaceAll('#{订单金额}', this.m2string(order.ret.total))
            .replaceAll('#{结账单}', order.printName)
            .replaceAll('#{备注}', order.remark)
            .replaceAll('#{数量统计}', '共 ' + dishMasterInfo.dishCount + ' 道  ' + dishMasterInfo.dishNum + ' 份')
            .replaceAll('#{应收金额}', this.m2string(order.yingshou))
            .replaceAll('#{财务类别合计}', dishTypeinfo);
        // #endregion
        

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && order.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(' ', '').replaceAll('#{做法}\n', '\n#{做法}');
                var relcptext = '';
                var tuicais = [];
                var zengsongcaipins = [];


                if (templateHasHYJ && !orderHasHYJ) {
                    printtext = Utils.editPrintLineByK(printtext, '#{会员价}', [-1, -2, -3], function (str) {
                        return str.replaceAll('数量', '  数量').replaceAll('单价', ' 单价').replaceAll('  会员价', '  ').replaceAll(' 会员价', '  ').replaceAll('会员价', '  ');
                    });
                    relcptextmode = relcptextmode.replaceAll('#{会员价}', '');
                }

                var dishs = this.sortDishs(order.dishs);
                for (var i in dishs) {
                    var cp = Utils.clone(dishs[i]);

                    if (cp.num < 0)
                        continue;


                    if (cp.tuiNum != 0)
                        tuicais = tuicais.concat(cp.getTuiCai());

                    if (cp.zengNum != 0)
                        zengsongcaipins.push(cp);

                    var cpnum = cp.num - cp.tuiNum;
                    if (cpnum <= 0)
                        continue;

                    var cpname = (cp.danPinZheKou) ? ('↓' + cp.name) : cp.name;
                    var numberStr = this.m2string(cpnum) + cp.unitName;
                    var priceStr = this.m2string(cp.price);
                    var amountStr = this.m2string(cp.m4Print());
                    var hyjPriceStr = this.m2string(cp.hyPrice ? cp.hyPrice : cp.price);

                    var cpmodel = { source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen };
                    var cpunitmodel = { source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen };
                    var cppricemodel = { source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen };
                    var cpHYpricemodel = { source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen };
                    var cpmoneymodel = { source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen };

                    var tp_cp_replace_mode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpHYpricemodel, cpmoneymodel);
                    //var tp_cp_replace_mode = relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";

                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        debugger;
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            if ((scp.num) < 0) {
                                tuicais.push(scp);
                                continue;
                            }

                            if (scp.tuiNum != 0)
                                tuicais = tuicais.concat(scp.getTuiCai());

                            if (scp.zengNum != 0)
                                zengsongcaipins.push(scp);

                            var scpnum = scp.num - scp.tuiNum;
                            if (scpnum <= 0)
                                continue;

                            var scpname = '* ' + scp.name;
                            var snumstr = this.m2string(scpnum) + scp.unitName;
                            var hyjPriceStr = this.m2string(cp.hyPrice ? cp.hyPrice : cp.price);

                            var cpmodel = { source: '#{菜品名称}', text: scpname, align: "L", length: dishnamelen };
                            var cpunitmodel = { source: '#{菜品数量}', text: snumstr, align: "R", length: dishnumlen };
                            var cppricemodel = { source: '#{菜品单价}', text: '', align: "R", length: dishpricelen };
                            var cpHYpricemodel = { source: '#{会员价}', text: '', align: "R", length: hyjlen };
                            var cpmoneymodel = { source: '#{菜品金额}', text: '', align: "R", length: dishmoneylen };

                            var tp_repmode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpHYpricemodel, cpmoneymodel);

                            //var tp_repmode = relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen)).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen)) + "\n";
                            var tc_zf_txt = '\n';
                            if (scp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    zf.parentCaiPin = scp;
                                    var zfname = ' -做法:' + zf.name;
                                    var zfprice = '';
                                    var zfnum = '';
                                    var zfonep = '';
                                    tc_zf_txt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                                    //tc_zf_txt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + "\n";
                                }
                            }
                            tp_repmode = tp_repmode.replaceAll('#{做法}\n', tc_zf_txt).replaceAll('#{做法}', tc_zf_txt);
                            tp_cp_replace_mode += tp_repmode;
                        }
                    }

                    var zftxt = '\n';
                    if (cp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = ' -做法:' + zf.name;
                            var zfprice = this.m2string(zf.m4Print());
                            var zfnum = '';
                            var zfonep = '';
                            zftxt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                        }
                    }
                    tp_cp_replace_mode = tp_cp_replace_mode.replaceAll('#{做法}\n', zftxt).replaceAll('#{做法}', zftxt);

                    relcptext += tp_cp_replace_mode;
                }

                // #region 没有退菜菜品的话，就不显示
                if (tuicais.length == 0) {
                    printtext = Utils.removePrintLineByK(printtext, '#{退菜}', [1, -1, -2], function (linetext, index) {
                        return linetext.indexOf('退菜') >= 0 || ((index == -1 || index == 1) && linetext.indexOf('------') >= 0)
                    });
                }
                // #endregion

                var tuicaitxt = '';
                if (tuicais.length > 0) {
                    for (var i in tuicais) {
                        var cp = tuicais[i];

                        var cpname = cp.name;
                        var numberStr = this.m2string(cp.num * -1) + cp.unitName;
                        var priceStr = '';//cp.price.ToString("C");
                        var amountStr = cp.tuicaiReasonName ? cp.tuicaiReasonName : "";
                        var hyjPriceStr = '';

                        var argearr = [relcptextmode];
                        argearr.push({ source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen });
                        argearr.push({ source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen });
                        argearr.push({ source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen });
                        argearr.push({ source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen });
                        argearr.push({ source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen });
                        tuicaitxt += this.formatTemplateLine(argearr);
                        //tuicaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        var tc_zftxt = '\n';
                        if (cp.zuofas.length > 0) {
                            for (var z in cp.zuofas) {
                                var zf = cp.zuofas[z];
                                if (!zf.parentCaiPin)
                                    zf.parentCaiPin = cp;
                                var zfname = ' -做法:' + zf.name;
                                var zfprice = '';//(Utils.m(zf.mRaw())*-1).ToString('C');
                                var zfnum = '';
                                var zfonep = '';
                                tc_zftxt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                                //tc_zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                            }
                        }
                        tuicaitxt = tuicaitxt.replaceAll('#{做法}\n', tc_zftxt).replaceAll('#{做法}', tc_zftxt);
                    }
                }
                printtext = printtext.replaceAll('#{退菜}\n', tuicaitxt).replaceAll('#{退菜}', tuicaitxt);


                // #region 没有赠菜菜品的话，就不显示
                if (zengsongcaipins.length == 0) {
                    printtext = Utils.removePrintLineByK(printtext, '#{赠菜}', [1, -1, -2], function (linetext, index) {
                        return linetext.indexOf('赠菜') >= 0 || ((index == -1 || index == 1) && linetext.indexOf('------') >= 0)
                    });
                }
                // #endregion

                var zengcaitxt = '';
                if (zengsongcaipins.length > 0) {
                    for (var i in zengsongcaipins) {
                        var cp = zengsongcaipins[i];

                        var cpname = cp.name;
                        var numberStr = this.m2string(cp.zengNum) + cp.unitName;
                        var priceStr = this.m2string(cp.price);
                        var amountStr = cp.zengReasonName;
                        var hyjPriceStr = '';

                        var argearr = [relcptextmode];
                        argearr.push({ source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen });
                        argearr.push({ source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen });
                        argearr.push({ source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen });
                        argearr.push({ source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen });
                        argearr.push({ source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen });
                        zengcaitxt += this.formatTemplateLine(argearr);

                        //zengcaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        zengcaitxt = zengcaitxt.replaceAll('#{做法}\n', '\n').replaceAll('#{做法}', '\n');
                    }
                }
                printtext = printtext.replaceAll('#{赠菜}\n', zengcaitxt).replaceAll('#{赠菜}', zengcaitxt);

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //循环youzhemo方式
        var indexpayitem = printtext.indexOf('#yzm_item');
        fetchLength = 10;
        if (indexpayitem > 0 && order.pay_items) {
            var lastpayindexitem = printtext.lastIndexOf('#yzm_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#yzm_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#yzm_item', '');
                printtext.replaceAll('#yzm_item\n', '');
            }
            else {
                var paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
                var relpaytextmode = paytextmode.replaceAll('#yzm_item', '').replaceAll("\r", "").replaceAll(" ", "").replaceAll("\n", "");
                var relpaytext = '';


                if (order.ret.ofZheKouMoney) {
                    var yhname = order.ret.ofZheKouName;//+ '（' + order.ret.ofZheKouAmount + '%）';
                    var yhmoney = this.m2string(order.ret.ofZheKouMoney);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.danPinSum) {
                    var yhname = '单品折扣';
                    var yhmoney = this.m2string(order.ret.danPinSum);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.moLingSum) {
                    var yhname = '抹零';
                    var yhmoney = this.m2string(order.ret.moLingSum);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.youMian) {
                    var yhname = '定额优惠';
                    var yhmoney = this.m2string(order.ret.youMian);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (Utils.m(order.ret.free)) {
                    var yhname = '赠送';
                    var yhmoney = this.m2string(order.ret.free);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.hyJiaYouHui > 0) {
                    var yhname = '会员价优惠';
                    var yhmoney = this.m2string(order.ret.hyJiaYouHui);


                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }
                printtext = printtext.replaceAll(paytextmode, relpaytext);
            }
        }

        //循环付款方式
        var indexpayitem = printtext.indexOf('#pay_item');
        fetchLength = 10;
        if (indexpayitem > 0 && order.pay_items) {
            var lastpayindexitem = printtext.lastIndexOf('#pay_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#pay_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#pay_item', '');
                printtext.replaceAll('#pay_item\n', '');
            }
            else {
                var paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
                var relpaytextmode = paytextmode.replaceAll('#pay_item', '').replaceAll("\r", "").replaceAll(" ", "").replaceAll("\n", "");
                var relpaytext = '';

                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                //relpaytext += '(应收:)                 (#{应收金额})\n' ;
                //relpaytext= relpaytext.replaceAll('#{应收金额}', order.yingshou.ToString("C"));
                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';


                for (var i in order.ret.payment) {
                    var cp = order.ret.payment[i];
                    var name = cp.name;
                    if (cp.fklx == 'thirdCoupon')
                        name += '（' + cp.thirdCouponNum + '）';
                    var paymentNumStr = this.m2string(cp.pmMoney());
                    relpaytext += relpaytextmode.replaceAll('#{付款方式}', name + Utils.printBlank(paymentlen - Utils.getPrinterLength(name))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(paymentNumStr)) + paymentNumStr) + "\n";;
                }
                printtext = printtext.replaceAll(paytextmode, relpaytext);
            }
        }
        return printtext;
    };
}

function NewDuiZhangDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var linelen = 40;
    var spacelen = 0;
    var dishnamelen = 20;
    var dishnumlen = 6;
    var dishpricelen = 7;
    var dishmoneylen = 9;
    var paymentlen = 8;
    var hyjlen = 0;
    // #region 内置模板

    var _template =
				'<[#{门店名称}]>\n' +
				'<[对账单]>\n' +
				'----------------------------------------\n' +
				'<(#{桌台号})>\n' +
                '服务员: #{点菜员}  人数：#{就餐人数}\n' +
                '下单时间：#{下单时间}  餐别:#{餐别}\n' +
                '开单号：#{订单号}\n' +
                '备注: #{备注}\n' +
                '----------------------------------------\n' +
                '品名            数量      单价       金额\n' +
                '----------------------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '----------------------------------------\n' +
                '退菜\n' +
                '----------------------------------------\n' +
                '#{退菜}\n' +
                '----------------------------------------\n' +
                '赠菜\n' +
                '----------------------------------------\n' +
                '#{赠菜}\n' +
                '----------------------------------------\n' +
                '#{财务类别合计}\n' +
                '----------------------------------------\n' +
				'(消费合计)                       (#{订单金额})\n' +
                '----------------------------------------\n' +
                '#yzm_item\n' +
                '#{优惠方式}                #{优惠金额}\n' +
                '#yzm_item\n' +
                '----------------------------------------\n' +
				'#pay_item\n' +
				'#{付款方式}                #{付款金额}\n' +
				'#pay_item\n' +
				'----------------------------------------\n' +
               '(应     付)                       (#{应付金额})\n' +
				'\n' +
				'收银员： #{收银员}\n' +
				'\n' +
				'欢迎光临#{门店名称}\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    var _template58 =
				'<[#{门店名称}]>\n' +
				'<[对账单]>\n' +
				'-----------------------------\n' +
				'<(#{桌台号})>\n' +
                '服务员: #{点菜员}  人数：#{就餐人数}\n' +
                '下单时间：#{下单时间}  \n餐别:#{餐别}\n' +
                '开单号：#{订单号}\n' +
                '结算时间: #{结算时间}\n' +
                '备注: #{备注}\n' +
                '-----------------------------\n' +
                '品名         数量   单价   金额\n' +
                '-----------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '-----------------------------\n' +
                '退菜\n' +
                '-----------------------------\n' +
                '#{退菜}\n' +
                '-----------------------------\n' +
                '赠菜\n' +
                '-----------------------------\n' +
                '#{赠菜}\n' +
                '-----------------------------\n' +
                '#{财务类别合计}\n' +
                '-----------------------------\n' +
				'(消费合计)              (#{订单金额})\n' +
                '-----------------------------\n' +
                '#yzm_item\n' +
                '#{优惠方式}                #{优惠金额}\n' +
                '#yzm_item\n' +
                '-----------------------------\n' +
				'#pay_item\n' +
				'#{付款方式}                #{付款金额}\n' +
				'#pay_item\n' +
				'-----------------------------\n' +
               '(应     付)              (#{应付金额})\n' +
				'\n' +
				'收银员： #{收银员}\n' +
				'\n' +
				'欢迎光临#{门店名称}\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    // #endregion

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 16;
            dishnumlen = 8;
            dishpricelen = 8;
            dishmoneylen = 10;
            paymentlen = 27;
        }
        else {
            linelen = 32;
            dishnamelen = 12;
            dishpricelen = 6;
            dishnumlen = 5;
            dishmoneylen = 6;
            paymentlen = 18;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var order = object;
        var dishTypeinfo = '';

        var templateHasHYJ = printtext.indexOf('#{会员价}') >= 0;
        var orderHasHYJ = !!object.hyJiaYouHui;

        if (templateHasHYJ && orderHasHYJ) {
            this.m2string = function (m) { return Utils.m(m) + ''; }
            //linelen = 32;
            dishnamelen = dishnamelen - 2;
            dishpricelen = dishpricelen - 1;
            dishnumlen = dishnumlen - 1;
            dishmoneylen = dishmoneylen - 2;
            hyjlen = 6;
        }

        order.remark = (order.remark || order.remark == 'null') ? order.remark : ' ';

        if (printtext.indexOf('#{财务类别合计}') >= 0)
            dishTypeinfo = this.getDishsTypeMasterInfo(object.dishs);

        var dishMasterInfo = { dishCount: 0, dishNum: 0 };
        if (printtext.indexOf('#{数量统计}') >= 0)
            dishMasterInfo = this.getDishsMasterInfo(object.dishs);

        // #region 基本数据源
        printtext = printtext.replaceAll('#{门店地址}', order.companyaddress)
            .replaceAll('#{门店电话}', order.companyphone)
            .replaceAll('#{门店名称}', order.company)
            .replaceAll('#{收银员}', order.syoperator)
            .replaceAll('#{点菜员}', order.DCoperator)
            .replaceAll('#{就餐人数}', order.rs)
            .replaceAll('#{餐别}', order.CBname)
            .replaceAll('#{订单号}', order.ordercode)
            .replaceAll('#{下单时间}', order.xdtime)
            .replaceAll('#{结算时间}', order.jstime)
            .replaceAll('#{桌台号}', order.zhuotai)
            .replaceAll('#{实收金额}', this.m2string(order.shijimoney))
            .replaceAll('#{找零金额}', this.m2string(order.zhaolingmoney))
            .replaceAll('#{订单金额}', this.m2string(order.ret.total))
            .replaceAll('#{备注}', order.remark)
            .replaceAll('#{结账单}', '对账单')
            .replaceAll('#{对账单}', '对账单')
            .replaceAll('#{数量统计}', '共 ' + dishMasterInfo.dishCount + ' 道  ' + dishMasterInfo.dishNum + ' 份')
            .replaceAll('#{应付金额}', this.m2string(Utils.m(order.zhaolingmoney) >= 0 ? (order.shijimoney>0?order.shijimoney:0) : (Utils.m(order.zhaolingmoney) * -1)))
            .replaceAll('#{应收金额}', this.m2string(order.yingshou))
            .replaceAll('#{财务类别合计}', dishTypeinfo);

        // #endregion 



        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && order.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(' ', '').replaceAll('#{做法}\n', '\n#{做法}');
                var relcptext = '';
                var tuicais = [];
                var zengsongcaipins = [];

                
                if (templateHasHYJ && !orderHasHYJ)
                {
                    printtext = Utils.editPrintLineByK(printtext, '#{会员价}', [-1, -2, -3], function (str) {
                        return str.replaceAll('数量', '  数量').replaceAll('单价', ' 单价').replaceAll('  会员价', '  ').replaceAll(' 会员价', '  ').replaceAll('会员价', '  ');
                    });
                    relcptextmode = relcptextmode.replaceAll('#{会员价}', '');
                }
                var dishs = this.sortDishs(order.dishs);
                for (var i in dishs) {
                    var cp = Utils.clone(dishs[i]);

                    if (cp.num < 0)
                        continue;


                    if (cp.tuiNum != 0)
                        tuicais = tuicais.concat(cp.getTuiCai());

                    if (cp.zengNum != 0)
                        zengsongcaipins.push(cp);

                    var cpnum = cp.num - cp.tuiNum;
                    if (cpnum <= 0)
                        continue;

                    var cpname = (cp.danPinZheKou) ? ('↓' + cp.name) : cp.name;
                    var numberStr = this.m2string(cpnum) + cp.unitName;
                    var priceStr = this.m2string(cp.price);
                    var amountStr = this.m2string(cp.m4Print());
                    var hyjPriceStr = this.m2string(cp.hyPrice ? cp.hyPrice : cp.price);

                    var cpmodel = { source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen };
                    var cpunitmodel = { source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen };
                    var cppricemodel = { source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen };
                    var cpHYpricemodel = { source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen };
                    var cpmoneymodel = { source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen };

                    var tp_cp_replace_mode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpHYpricemodel, cpmoneymodel);
                    //var tp_cp_replace_mode = relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";

                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        debugger;
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            if ((scp.num) < 0) {
                                tuicais.push(scp);
                                continue;
                            }

                            if (scp.tuiNum != 0)
                                tuicais = tuicais.concat(scp.getTuiCai());

                            if (scp.zengNum != 0)
                                zengsongcaipins.push(scp);

                            var scpnum = scp.num - scp.tuiNum;
                            if (scpnum <= 0)
                                continue;

                            var scpname = '* ' + scp.name;
                            var snumstr = this.m2string(scpnum)+ scp.unitName;
                            var hyjPriceStr = this.m2string(cp.hyPrice ? cp.hyPrice : cp.price);

                            var cpmodel = { source: '#{菜品名称}', text: scpname, align: "L", length: dishnamelen };
                            var cpunitmodel = { source: '#{菜品数量}', text: snumstr, align: "R", length: dishnumlen };
                            var cppricemodel = { source: '#{菜品单价}', text: '', align: "R", length: dishpricelen };
                            var cpHYpricemodel = { source: '#{会员价}', text: '', align: "R", length: hyjlen };
                            var cpmoneymodel = { source: '#{菜品金额}', text: '', align: "R", length: dishmoneylen };

                            var tp_repmode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpHYpricemodel, cpmoneymodel);

                            //var tp_repmode = relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen)).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen)) + "\n";
                            var tc_zf_txt = '\n';
                            if (scp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    zf.parentCaiPin = scp;
                                    var zfname = ' -做法:' + zf.name;
                                    var zfprice = '';
                                    var zfnum = '';
                                    var zfonep = '';
                                    tc_zf_txt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                                    //tc_zf_txt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + "\n";
                                }
                            }
                            tp_repmode = tp_repmode.replaceAll('#{做法}\n', tc_zf_txt).replaceAll('#{做法}', tc_zf_txt);
                            tp_cp_replace_mode += tp_repmode;
                        }
                    }

                    var zftxt = '\n';
                    if (cp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = ' -做法:' + zf.name;
                            var zfprice = this.m2string(zf.m4Print());
                            var zfnum = '';
                            var zfonep = '';
                            zftxt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                        }
                    }
                    tp_cp_replace_mode = tp_cp_replace_mode.replaceAll('#{做法}\n', zftxt).replaceAll('#{做法}', zftxt);

                    relcptext += tp_cp_replace_mode;
                }

                // #region 没有退菜菜品的话，就不显示
                if (tuicais.length == 0) {
                    printtext = Utils.removePrintLineByK(printtext, '#{退菜}', [1,-1, -2], function (linetext,index) {
                        return linetext.indexOf('退菜') >= 0 || ((index == -1 || index == 1) && linetext.indexOf('------') >= 0)
                    });
                }
                // #endregion

                var tuicaitxt = '';
                if (tuicais.length > 0) {
                    for (var i in tuicais) {
                        var cp = tuicais[i];

                        var cpname = cp.name;
                        var numberStr = this.m2string(cp.num * -1) + cp.unitName;
                        var priceStr = '';//cp.price.ToString("C");
                        var amountStr = cp.tuicaiReasonName;
                        var hyjPriceStr = '';

                        var argearr = [relcptextmode];
                        argearr.push({ source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen });
                        argearr.push({ source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen });
                        argearr.push({ source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen });
                        argearr.push({ source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen });
                        argearr.push({ source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen });
                        tuicaitxt += this.formatTemplateLine(argearr);
                        //tuicaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        var tc_zftxt = '\n';
                        if (cp.zuofas.length > 0) {
                            for (var z in cp.zuofas) {
                                var zf = cp.zuofas[z];
                                if (!zf.parentCaiPin)
                                    zf.parentCaiPin = cp;
                                var zfname = ' -做法:' + zf.name;
                                var zfprice = '';//(Utils.m(zf.mRaw())*-1).ToString('C');
                                var zfnum = '';
                                var zfonep = '';
                                tc_zftxt += zfname + Utils.printBlank(dishnamelen + dishnumlen - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishmoneylen + hyjlen + dishpricelen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                                //tc_zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                            }
                        }
                        tuicaitxt = tuicaitxt.replaceAll('#{做法}\n', tc_zftxt).replaceAll('#{做法}', tc_zftxt);
                    }
                }
                printtext = printtext.replaceAll('#{退菜}\n', tuicaitxt).replaceAll('#{退菜}', tuicaitxt);


                // #region 没有赠菜菜品的话，就不显示
                if (zengsongcaipins.length == 0) {
                    printtext = Utils.removePrintLineByK(printtext, '#{赠菜}', [1,-1, -2], function (linetext, index) {
                        return linetext.indexOf('赠菜') >= 0 || ((index == -1 || index == 1) && linetext.indexOf('------') >= 0)
                    });
                }
                // #endregion

                var zengcaitxt = '';
                if (zengsongcaipins.length > 0) {
                    for (var i in zengsongcaipins) {
                        var cp = zengsongcaipins[i];

                        var cpname = cp.name;
                        var numberStr = this.m2string(cp.zengNum) + cp.unitName;
                        var priceStr = this.m2string(cp.price);
                        var amountStr = cp.zengReasonName;
                        var hyjPriceStr = '';

                        var argearr = [relcptextmode];
                        argearr.push({ source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen });
                        argearr.push({ source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen });
                        argearr.push({ source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen });
                        argearr.push({ source: '#{会员价}', text: hyjPriceStr, align: "R", length: hyjlen });
                        argearr.push({ source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen });
                        zengcaitxt += this.formatTemplateLine(argearr);

                        //zengcaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        zengcaitxt = zengcaitxt.replaceAll('#{做法}\n', '\n').replaceAll('#{做法}', '\n');
                    }
                }
                printtext = printtext.replaceAll('#{赠菜}\n', zengcaitxt).replaceAll('#{赠菜}', zengcaitxt);

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //循环youzhemo方式
        var indexpayitem = printtext.indexOf('#yzm_item');
        fetchLength = 10;
        if (indexpayitem > 0 && order.pay_items) {
            var lastpayindexitem = printtext.lastIndexOf('#yzm_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#yzm_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#yzm_item', '');
                printtext.replaceAll('#yzm_item\n', '');
            }
            else {
                var paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
                var relpaytextmode = paytextmode.replaceAll('#yzm_item', '').replaceAll("\r", "").replaceAll(" ", "").replaceAll("\n", "");
                var relpaytext = '';


                if (order.ret.ofZheKouMoney) {
                    var yhname = order.ret.ofZheKouName;//+ '（' + order.ret.ofZheKouAmount + '%）';
                    var yhmoney = this.m2string(order.ret.ofZheKouMoney);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.danPinSum) {
                    var yhname = '单品折扣';
                    var yhmoney = this.m2string(order.ret.danPinSum);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.moLingSum) {
                    var yhname = '抹零';
                    var yhmoney = this.m2string(order.ret.moLingSum);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.youMian) {
                    var yhname = '定额优惠';
                    var yhmoney = this.m2string(order.ret.youMian);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (Utils.m(order.ret.free)) {
                    var yhname = '赠送';
                    var yhmoney = this.m2string(order.ret.free);

                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }

                if (order.ret.hyJiaYouHui > 0) {
                    var yhname = '会员价优惠';
                    var yhmoney = this.m2string(order.ret.hyJiaYouHui);


                    relpaytext += relpaytextmode.replaceAll('#{优惠方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{优惠金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
                }
                printtext = printtext.replaceAll(paytextmode, relpaytext);
            }
        }

        //循环付款方式
        var indexpayitem = printtext.indexOf('#pay_item');
        fetchLength = 10;
        if (indexpayitem > 0 && order.pay_items) {
            var lastpayindexitem = printtext.lastIndexOf('#pay_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#pay_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#pay_item', '');
                printtext.replaceAll('#pay_item\n', '');
            }
            else {
                var paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
                var relpaytextmode = paytextmode.replaceAll('#pay_item', '').replaceAll("\r", "").replaceAll(" ", "").replaceAll("\n", "");
                var relpaytext = '';

                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                //relpaytext += '(应收:)                 (#{应收金额})\n' ;
                //relpaytext= relpaytext.replaceAll('#{应收金额}', order.yingshou.ToString("C"));
                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';


                for (var i in order.ret.payment) {
                    var cp = order.ret.payment[i];
                    var name = cp.name;
                    if (cp.fklx == 'thirdCoupon')
                        name += '（' + cp.thirdCouponNum + '）';
                    var paymentNumStr = this.m2string(cp.pmMoney());
                    relpaytext += relpaytextmode.replaceAll('#{付款方式}', name + Utils.printBlank(paymentlen - Utils.getPrinterLength(name))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(paymentNumStr)) + paymentNumStr) + "\n";;
                }
                printtext = printtext.replaceAll(paytextmode, relpaytext);
            }
        }
        return printtext;
    };
}

function WMPeiSongTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var linelen = 40;
    var spacelen = 0;
    var dishnamelen = 20;
    var dishnumlen = 6;
    var dishpricelen = 7;
    var dishmoneylen = 9;
    var paymentlen = 8;

    // #region 内置模板

    var _template ='--------- $#{订单号}$-------\n'+
				'<#{门店名称}>\n' +
				'<[#{结账单}]>\n\n' +
                 '<--------$【#{付款方式}】$-------->\n\n' +
				'----------------------------------------\n' +
                '下单时间：#{下单时间}\n' +
                '发票：#{发票}\n' +
                '备注: #{备注}\n' +
                '(送达时间: #{送出时间})\n' +
                '----------------------------------------\n' +
                '(品名            数量      单价       金额)\n' +
                '----------------------------------------\n' +
				'#item\n' +
				'(#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额})\n' +
                '#{做法}\n' +
                '#item\n' +
                 '----------------------------------------\n' +
                '(#{财务类别合计})\n' +
                '----------------------------------------\n' +
                '(配送费:)                      (#{配送费})\n' +
                '(红  包:)                      (#{红包})\n' +
				'(总  计:)                      (#{订单金额})\n' +
                '----------------------------------------\n' +
				'$#{客户地址}$\n' +
                '$#{客户姓名}$\n' +
				'$#{客户电话}$\n' +
                '------- $#{订单号}$ 完------';

    var _template58 =
				'----- $#{订单号}$----\n' +
				'<#{门店名称}>\n' +
				'<[#{结账单}]>\n\n' +
                 '<----$【#{付款方式}】$---->\n\n' +
				'-----------------------------\n' +
                '下单时间：#{下单时间}\n' +
                '发票：#{发票}\n' +
                '备注: #{备注}\n' +
                '(送出时间: #{送出时间})\n' +
                '-----------------------------\n' +
                '(品名        数量        金额)\n' +
                '-----------------------------\n' +
				'#item\n' +
				'#({菜品名称}#{菜品数量}    #{菜品金额})\n' +
                '#{做法}\n' +
                '#item\n' +
                '-----------------------------\n' +
                '(#{财务类别合计})\n' +
                '-----------------------------\n' +
                '(配送费:)                  (#{配送费})\n' +
                '(红  包:)                  (#{红包})\n' +
				'(总  计:)                  (#{订单金额})\n' +
                '-----------------------------\n' +
				'$#{客户地址}$\n' +
                '$#{客户姓名}$\n' +
				'$#{客户电话}$\n' +
                '--- $#{订单号}$ 完---';

    // #endregion

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 16;
            dishnumlen = 8;
            dishpricelen = 8;
            dishmoneylen = 10;
            paymentlen = 27;
        }
        else {
            linelen = 32;
            dishnamelen = 12;
            dishpricelen = 6;
            dishnumlen = 5;
            dishmoneylen = 10;
            paymentlen = 18;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var order = object;
        var waimaiObj = order.waimaiObj.orderDeliveryInfo;
        var waimaiorder = order.waimaiObj;
        order.remark = waimaiorder.remark;

        if (Math.abs(Utils.m(waimaiObj.elemeHongbao))==0)
            printtext = Utils.removePrintLineByK(printtext, '#{红包}');

        order.remark = (order.remark && order.remark != 'null') ? order.remark : ' ';

        if (!waimaiorder.orderType || waimaiorder.orderType != 'WaimaiBook')
            printtext = Utils.removePrintLineByK(printtext, '#{送出时间}');
        else
            printtext = printtext.replaceAll('#{送出时间}', this.dateFormat(waimaiObj.bookDeliverTime));

        // #region 替换基本数据源
        printtext = printtext.replaceAll('#{门店地址}', order.companyaddress)
            .replaceAll('#{门店电话}', order.companyphone)
            .replaceAll('#{门店名称}', order.company)
            .replaceAll('#{收银员}', order.syoperator)
            .replaceAll('#{点菜员}', order.DCoperator)
            .replaceAll('#{就餐人数}', order.rs)
            .replaceAll('#{餐别}', order.CBname)
            .replaceAll('#{订单号}', order.zhuotai)
            .replaceAll('#{下单时间}', order.xdtime)
            .replaceAll('#{结算时间}', order.jstime)
            .replaceAll('#{桌台号}', order.zhuotai)
            .replaceAll('#{实收金额}', Utils.m2string(order.shijimoney))
            .replaceAll('#{找零金额}', Utils.m2string(order.zhaolingmoney))
            .replaceAll('#{订单金额}', Utils.m2string(waimaiorder.totalPrice))
            .replaceAll('#{结账单}', order.printName)
            .replaceAll('#{备注}', order.remark)
            .replaceAll('#{应收金额}', Utils.m2string(order.yingshou))
            .replaceAll('#{送出人员}', waimaiObj.deliverymanName)
            .replaceAll('#{水单编号}', waimaiObj.orderNo)
            .replaceAll('#{客户姓名}', waimaiObj.receiverName)
            .replaceAll('#{客户电话}', waimaiObj.receiverPhone)
            .replaceAll('#{客户地址}', waimaiObj.address.replaceAll('\\(', '（').replaceAll('\\)', '）'))
            .replaceAll('#{其他}', Utils.m2string(Utils.m(waimaiorder.totalPrice) - order.ret.total))
            .replaceAll('#{发票}', waimaiorder.invoiceType ? waimaiorder.invoiceTitle : "无")
            .replaceAll('#{红包}', Utils.m2string(waimaiorder.elemeHongbao))
            .replaceAll('#{配送费}', Utils.m2string(waimaiObj.deliverFee))
            .replaceAll('#{付款方式}', (waimaiorder.orderTradeInfoList.length && waimaiorder.orderTradeInfoList[0].payType == 1) ? "货到付款" : "在线支付")
            .replaceAll('#{付款类型}', (waimaiorder.orderTradeInfoList.length && waimaiorder.orderTradeInfoList[0].payType == 1) ? "货到付款" : "在线支付")
            .replaceAll('#{客户备注}', order.remark);
        // #endregion

        // #region 计算财务类别合计

        if (printtext.indexOf('#{财务类别合计}') >= 0) {
            var cwlbhj = [];
            for (var i in order.dishs) {
                var tcp = order.dishs[i];
                if (tcp.num < 0)
                    continue;

                tcp.num = tcp.num - tcp.tuiNum - tcp.zengNum;
                if (tcp.num <= 0)
                    continue;
                var cw = null;
                for (var j in cwlbhj) {
                    if (cwlbhj[j].kid == tcp.caiwuTypeId)
                        cw = cwlbhj[j];
                }
                if (cw == null && tcp.caiwuTypeId)
                    cwlbhj.push({ kid: tcp.caiwuTypeId, kname: tcp.caiwuTypeName, kmoney: tcp.m4Print() });
                else if (cw)
                    cw.kmoney += tcp.m4Print();
            }

            var cwlbhjstr = '';
            for (var h in cwlbhj) {
                var itemstr = cwlbhj[h].kname + ":" + Utils.m2string(cwlbhj[h].kmoney);
                if ((Utils.getPrinterLength(itemstr) + Utils.getPrinterLength(cwlbhjstr)) > linelen)
                    cwlbhjstr += '\n';
                cwlbhjstr += itemstr + ' ';
            }
            printtext = printtext.replaceAll('#{财务类别合计}', cwlbhjstr);

        }
        // #endregion

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && order.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(' ', '').replaceAll('#{做法}\n', '\n#{做法}');
                var relcptext = '';
                var tuicais = [];
                var zengsongcaipins = [];

                for (var i in order.dishs) {
                    var cp = order.dishs[i];

                    if (cp.num < 0)
                        continue;


                    if (cp.tuiNum != 0)
                        tuicais = tuicais.concat(cp.getTuiCai());

                    if (cp.zengNum != 0)
                        zengsongcaipins.push(cp);

                    cp.num = cp.num - cp.tuiNum;
                    if (cp.num <= 0)
                        continue;

                    var cpname = (cp.danPinZheKou) ? ('↓' + cp.name) : cp.name;
                    var numberStr = (cp.num).ToString("C") + cp.unitName;
                    var priceStr = Utils.m2string(cp.price);
                    var amountStr = Utils.m(cp.m4Print()).ToString("C");

                    var cpmodel = { source: '#{菜品名称}', text: cpname, align: "L", length: dishnamelen };
                    var cpunitmodel = { source: '#{菜品数量}', text: numberStr, align: "R", length: dishnumlen };
                    var cppricemodel = { source: '#{菜品单价}', text: priceStr, align: "R", length: dishpricelen };
                    var cpmoneymodel = { source: '#{菜品金额}', text: amountStr, align: "R", length: dishmoneylen };

                    var tp_cp_replace_mode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpmoneymodel);

                    //var tp_cp_replace_mode = relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";

                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        debugger;
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            if ((scp.num) < 0) {
                                tuicais.push(scp);
                                continue;
                            }

                            if (scp.tuiNum != 0)
                                tuicais = tuicais.concat(scp.getTuiCai());

                            if (scp.zengNum != 0)
                                zengsongcaipins.push(scp);

                            scp.num = scp.num - scp.tuiNum;
                            if (scp.num <= 0)
                                continue;

                            var scpname = '* ' + scp.name;
                            var snumstr = (scp.num).ToString("C") + scp.unitName;

                            var cpmodel = { source: '#{菜品名称}', text: scpname, align: "L", length: dishnamelen };
                            var cpunitmodel = { source: '#{菜品数量}', text: snumstr, align: "R", length: dishnumlen };
                            var cppricemodel = { source: '#{菜品单价}', text: '', align: "R", length: dishpricelen };
                            var cpmoneymodel = { source: '#{菜品金额}', text: '', align: "R", length: dishmoneylen };

                            var tp_repmode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel, cppricemodel, cpmoneymodel);

                            //var tp_repmode = relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen)).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen)) + "\n";
                            var tc_zf_txt = '\n';
                            if (scp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    zf.parentCaiPin = scp;
                                    var zfname = ' -做法:' + zf.name;
                                    var zfprice = '';
                                    var zfnum = '';
                                    var zfonep = '';
                                    tc_zf_txt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + "\n";
                                }
                            }
                            tp_repmode = tp_repmode.replaceAll('#{做法}\n', tc_zf_txt).replaceAll('#{做法}', tc_zf_txt);
                            tp_cp_replace_mode += tp_repmode;
                        }
                    }

                    var zftxt = '\n';
                    if (cp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = ' -做法:' + zf.name;
                            var zfprice = Utils.m(zf.m4Print()).ToString('C');
                            var zfnum = '';
                            var zfonep = '';
                            zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                        }
                    }
                    tp_cp_replace_mode = tp_cp_replace_mode.replaceAll('#{做法}\n', zftxt).replaceAll('#{做法}', zftxt);

                    relcptext += tp_cp_replace_mode;
                }

                // #region 没有退菜菜品的话，就不显示
                if (tuicais.length == 0) {
                    var spprinttextarr = printtext.split('\n');
                    var spindex = -1;
                    for (var s in spprinttextarr) {
                        var stext = spprinttextarr[s];
                        if (stext.indexOf('#{退菜}') >= 0)
                            spindex = s;
                    }
                    if (spindex >= 0) {
                        spprinttextarr.splice(spindex, 1);
                        if (spprinttextarr[spindex - 1].indexOf('退菜') >= 0)
                            spprinttextarr.splice(spindex - 1, 1);
                        if (spprinttextarr[spindex - 2].indexOf('退菜') >= 0) {
                            spprinttextarr.splice(spindex - 1, 1);
                            spprinttextarr.splice(spindex - 2, 1);
                        }
                    }
                    printtext = spprinttextarr.join('\n');
                }
                // #endregion

                var tuicaitxt = '';
                if (tuicais.length > 0) {
                    for (var i in tuicais) {
                        var cp = tuicais[i];

                        var cpname = cp.name;
                        var numberStr = (cp.num * -1).ToString("C") + cp.unitName;
                        var priceStr = '';//cp.price.ToString("C");
                        var amountStr = '退菜';

                        tuicaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        var tc_zftxt = '\n';
                        if (cp.zuofas.length > 0) {
                            for (var z in cp.zuofas) {
                                var zf = cp.zuofas[z];
                                if (!zf.parentCaiPin)
                                    zf.parentCaiPin = cp;
                                var zfname = ' -做法:' + zf.name;
                                var zfprice = '';//(Utils.m(zf.mRaw())*-1).ToString('C');
                                var zfnum = '';
                                var zfonep = '';
                                tc_zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                            }
                        }
                        tuicaitxt = tuicaitxt.replaceAll('#{做法}\n', tc_zftxt).replaceAll('#{做法}', tc_zftxt);
                    }
                }
                printtext = printtext.replaceAll('#{退菜}\n', tuicaitxt).replaceAll('#{退菜}', tuicaitxt);


                // #region 没有赠菜菜品的话，就不显示
                if (zengsongcaipins.length == 0) {
                    var spprinttextarr = printtext.split('\n');
                    var spindex = -1;
                    for (var s in spprinttextarr) {
                        var stext = spprinttextarr[s];
                        if (stext.indexOf('#{赠菜}') >= 0)
                            spindex = s;
                    }
                    if (spindex >= 0) {
                        spprinttextarr.splice(spindex, 1);
                        if (spprinttextarr[spindex - 1].indexOf('赠菜') >= 0)
                            spprinttextarr.splice(spindex - 1, 1);
                        if (spprinttextarr[spindex - 2].indexOf('赠菜') >= 0) {
                            spprinttextarr.splice(spindex - 1, 1);
                            spprinttextarr.splice(spindex - 2, 1);
                        }
                    }
                    printtext = spprinttextarr.join('\n');
                }
                // #endregion

                var zengcaitxt = '';
                if (zengsongcaipins.length > 0) {
                    for (var i in zengsongcaipins) {
                        var cp = zengsongcaipins[i];

                        var cpname = cp.name;
                        var numberStr = (cp.zengNum).ToString("C") + cp.unitName;
                        var priceStr = cp.price.ToString("C");
                        var amountStr = '赠菜';

                        zengcaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        zengcaitxt = zengcaitxt.replaceAll('#{做法}\n', '\n').replaceAll('#{做法}', '\n');
                    }
                }
                printtext = printtext.replaceAll('#{赠菜}\n', zengcaitxt).replaceAll('#{赠菜}', zengcaitxt);

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //循环付款方式
        var indexpayitem = printtext.indexOf('#pay_item');
        fetchLength = 10;
        if (indexpayitem > 0 && order.pay_items) {
            var lastpayindexitem = printtext.lastIndexOf('#pay_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#pay_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#pay_item', '');
                printtext.replaceAll('#pay_item\n', '');
            }
            else {
                var paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
                var relpaytextmode = paytextmode.replaceAll('#pay_item', '').replaceAll("\r", "").replaceAll(" ", "").replaceAll("\n", "");
                var relpaytext = '';

                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                //relpaytext += '(应收:)                 (#{应收金额})\n' ;
                //relpaytext= relpaytext.replaceAll('#{应收金额}', order.yingshou.ToString("C"));
                //relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';


                for (var i in order.ret.payment) {
                    var cp = order.ret.payment[i];
                    var name = cp.name;
                    var paymentNumStr = cp.pmMoney().ToString("C");
                    relpaytext += relpaytextmode.replaceAll('#{付款方式}', name + Utils.printBlank(paymentlen - Utils.getPrinterLength(name))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(paymentNumStr)) + paymentNumStr) + "\n";;
                }
                printtext = printtext.replaceAll(paytextmode, relpaytext);
            }
        }
        return printtext;
    };
}


function HuanTaiObject() {
    this.oldDeskNo = null;
    this.newDeskNo = null;
    this.diancaiyuan = null;
}

function HuanTaiDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
				'<$#{打印机名称}换台单$>\n' +
				'-------------------------------------\n' +
				'#{打印时间} 操作人:#{操作人}\n' +
				'<L#3$#{原桌台} 换到 $L>\n' +
                '<R#3$#{新桌台}$R>\n\n' +
				'流水号：#{单据号}\n\n';

    var _template58 =
               '<$#{打印机名称}换台单$>\n' +
               '-------------------------------------\n' +
               '#{打印时间} 操作人:#{操作人}\n' +
               '<L#3$#{原桌台} 换到 $L>\n' +
               '<R#3$#{新桌台}$R>\n\n' +
               '流水号：#{单据号}\n\n';

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{原桌台}', object.oldDeskNo)
            .replaceAll('#{新桌台}', object.newDeskNo)
           .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
            .replaceAll('#{餐别}', object.canbie)
            .replaceAll('#{备注}', object.remark)
            .replaceAll('#{订单号}', object.orderno)
            .replaceAll('#{点菜员}', object.diancaiyuan)
            .replaceAll('#{操作人}', object.operator);
        return printtext;
    };
}

function ZhiZuoDanObject() {
    this.deskNo = null;
    this.rs = null;
    this.dish = { name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 };
    this.diancaiyuan = null;
    this.notifyText = null;
}

function ZhiZuoDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
				'<[#{打印机名称}切配制作单]>\n' +
				'--------------------------------\n' +
				'#{打印时间} 点菜员:#{点菜员}\n' +
				'$#{出品要求}$    $#{桌台号}$\n' +
				'--------------------------------\n' +
				'$#{菜品名称}$\n' +
				'[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
                '[#{做法}]\n--------------------------------\n[#{口味}]\n' +
				'流水号：#{单据号}';

    var _template58 =
				'<[#{打印机名称}切配制作单]>\n' +
				'--------------------------------\n' +
				'#{打印时间} 点菜员:#{点菜员}\n' +
				'$#{出品要求}$    $#{桌台号}$\n' +
				'--------------------------------\n' +
				'$#{菜品名称}$\n' +
				'[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
                '[#{做法}]\n------------------------\n[#{口味}]\n' +
				'流水号：#{单据号}';

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        debugger;
        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
            .replaceAll('#{菜品名称}', object.dish.name)
            .replaceAll('#{菜品数量}', object.dish.num + object.dish.unitName)
            .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
            .replaceAll('#{点菜员}', object.diancaiyuan)
            .replaceAll('#{单号}', object.ordercode)
            .replaceAll('#{金额}', '￥'+Utils.m(object.dish.dishze))
            .replaceAll('#{短单号}', object.ordercode.substring(object.ordercode.length-3, object.ordercode.length))
            .replaceAll('#{出品要求}', object.notifyText);
        if (invoice.islable=='true')
            printtext = printtext.replaceAll('#{打印时间}', (new Date()).format("hh:mm")).replaceAll('#{日期}', (new Date()).format("MM/dd")).replaceAll('#{点单时间}', (new Date()).format("hh:mm"));
        else
            printtext = printtext.replaceAll('#{日期}', (new Date()).format("yyyy-MM-dd")).replaceAll('#{点单时间}', (new Date()).format("hh:mm:ss"));
        // console.info(object);
        var zfs = '';
        if (object.dish.zuofas) {
            debugger;
            for (var z in object.dish.zuofas) {
                zfs += object.dish.zuofas[z].name + '\t';
            }
        }
        var kws = '';
        if (object.dish.kouweis) {

            for (var k in object.dish.kouweis) {
                kws += (object.dish.kouweis[k].name ? object.dish.kouweis[k].name : object.dish.kouweis[k].kwName) + '\t';
            }
        }
        printtext = printtext.replaceAll('#{做法}', zfs).replaceAll('#{口味}', kws);
        // console.info(printtext);
        return printtext;
    };
}

function KeYongDanObject() {
    this.deskNo = null;
    this.rs = null;
    this.canbie = null;
    this.company = '袁州食府';
    this.companyphone = '0795-3563999';
    this.companyaddress = '宜春市环城西路363号';
    this.dishs = [{ name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 }, { name: '清炒空心菜', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }, { name: '剑南春', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }];
    this.diancaiyuan = null;
};

function KeYongDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    // #region 默认模板
    var _template =
				'<[客用单]>\n' +
				'<$#{桌台号}$>\n' +
	            '服务员:#{服务员}  人数:#{就餐人数}\n' +
				'打印时间:#{打印时间}  \n' +
                '餐别:#{餐别}\n' +
				'------------------------------------------\n' +
				'菜品名称                              数量\n' +
				'#item\n' +
				'#{菜品名称}   #{菜品数量}\n' +
				'#item\n' +
				'------------------------------------------\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    var _template58 =
				'<[客用单]>\n' +
				'<$#{桌台号}$>\n' +
	            '服务员:#{服务员}  人数:#{就餐人数}\n' +
				'打印时间:#{打印时间}  \n' +
                '餐别:#{餐别}\n' +
				'-------------------------------\n' +
				'菜品名称                数量\n' +
				'#item\n' +
				'#{菜品名称}   #{菜品数量}\n' +
				'#item\n' +
				'-------------------------------\n' +
				'#{门店电话}\n' +
				'#{门店地址}';

    // #endregion

    var linelen = 40;
    var dishnamelen = 25;
    var dishnumlen = 6;

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        this.size = size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 30;
            dishnumlen = 9;
        }
        else {
            linelen = 32;
            dishnamelen = 20;
            dishnumlen = 5;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var dishMasterInfo = { dishCount: 0, dishNum: 0 };
        if (printtext.indexOf('#{数量统计}') >= 0)
            dishMasterInfo = this.getDishsMasterInfo(object.dishs);

        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
            .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
            .replaceAll('#{餐别}', object.canbie)
            .replaceAll('#{订单号}', object.ordercode)
            .replaceAll('#{备注}', object.remark)
            .replaceAll('#{点菜员}', object.diancaiyuan).replaceAll('#{服务员}', object.diancaiyuan)
            .replaceAll('#{数量统计}', '共 ' + dishMasterInfo.dishCount + ' 道  ' + dishMasterInfo.dishNum + ' 份')
            .replaceAll('#{操作员}', object.operator)
            .replaceAll('#{开台时间}', object.kaiTaiTime);

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && object.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "");
                var relcptext = '';
                var tuicais = [];
                var zengsongcaipins = [];

                for (var i in object.dishs) {
                    var cp = object.dishs[i];

                    if (cp.num < 0)
                        continue;

                    if (cp.tuiNum != 0)
                        tuicais.push(cp);

                    if (cp.zengNum != 0)
                        zengsongcaipins.push(cp);

                    var cpnum = cp.num - cp.tuiNum;
                    if (cpnum <= 0)
                        continue;

                    var cpname = cp.danPinZheKou ? ('↓' + cp.name) : cp.name;
                    cpname = cp.chupin + ' ' + cpname;
                    var numberStr = (cp.needweigh=='1'?'约 ':'') + (cpnum).ToString("C") + cp.unitName;

                    relcptext += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                    if (cp.zuofas.length > 0) {
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = ' -做法:' + zf.name;
                            var zfprice = Utils.m(zf.m4Print()).ToString('C');
                            var zfnum = '';
                            var zfonep = '';
                            relcptext += relcptextmode.replaceAll('#{菜品名称}', zfname + Utils.printBlank(dishnamelen  - Utils.getPrinterLength(zfname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen  - Utils.getPrinterLength(zfnum)) + zfnum) + "\n";
                        }
                    }

                    if (cp.kouweis.length > 0) {
                        for (var z in cp.kouweis) {
                            var kw = cp.kouweis[z];
                            if (kw.kwName)
                                kw.name = kw.kwName;
                            var kwname = ' -口味:' + kw.name;
                            var zfnum = '';
                            var zfonep = '';
                            relcptext += relcptextmode.replaceAll('#{菜品名称}', kwname + Utils.printBlank(dishnamelen  - Utils.getPrinterLength(kwname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen  - Utils.getPrinterLength(zfnum)) + zfnum) + "\n";
                        }
                    }

                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            var scpname = '* ' + scp.name;

                            var snumstr = (scp.num).ToString("C") + scp.unitName;

                            if (scp.num < 0)
                                continue;

                            if (scp.tuiNum != 0)
                                tuicais.push(scp);

                            if (scp.zengNum != 0)
                                zengsongcaipins.push(scp);

                            scp.num = scp.num - scp.tuiNum;
                            if (scp.num <= 0)
                                continue;

                            relcptext += relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr) + "\n";
                            if (scp.zuofas.length > 0) {
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    var zfname = ' -做法:' + zf.name;
                                    var zfprice = 0;
                                    var zfnum = '';
                                    var zfonep = '';
                                    relcptext += relcptextmode.replaceAll('#{菜品名称}', zfname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(zfname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen  - Utils.getPrinterLength(zfnum)) + zfnum) + "\n";
                                }
                            }
                        }
                    }


                }

                if (tuicais.length > 0) {
                    relcptext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                    relcptext += '退菜\n';
                    relcptext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                    for (var i in tuicais) {
                        var scp = tuicais[i];
                        var scpname = scp.name;
                        scpname = scp.chupin + ' ' + scpname;
                        var snumstr = (scp.tuiNum).ToString("C") + scp.unitName;

                        relcptext += relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr) + "\n";
                    }
                }

                if (zengsongcaipins.length > 0) {
                    relcptext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                    relcptext += '赠菜\n';
                    relcptext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';
                    for (var i in zengsongcaipins) {
                        var scp = zengsongcaipins[i];
                        var scpname = scp.name;
                        scpname = scp.chupin + ' ' + scpname;
                        var snumstr = (scp.zengNum).ToString("C") + scp.unitName;

                        relcptext += relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr) + "\n";
                    }
                }

                printtext = printtext.replaceAll(cptextmode, relcptext);




            }
        }

        return printtext;
    };
}

function DuiZhangDanObject() {
    this.deskNo = null;
    this.rs = null;
    this.canbie = null;
    this.ordertime = null;
    this.orderno = null;
    this.ordermoney = null;
    this.diancaiyuan = null;
    this.yingshou = null;
    this.zhuotai = null;
    this.company = '袁州食府';
    this.companyphone = '0795-3563999';
    this.companyaddress = '宜春市环城西路363号';
    this.remark = '';
    this.ret = {
        total: 0, //消费合计
        ofZheKouName: '', //折扣率的名字
        ofZheKouMoney: 0, //折扣掉的金额
        youMian: 0,//定额
        free: 0, //赠送
        payment: [],
        danPinSum: 0,
        moLingSum: 0
    };
    this.dishs = [{ name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 }, { name: '清炒空心菜', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }, { name: '剑南春', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }];
};

function DuiZhangDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    // #region 内置模板

    var _template =
				'<[#{门店名称}]>\n' +
				'<[对账单]>\n' +
				'-----------------------------------------\n' +
				'<(#{桌台号})>\n' +
				'服务员: #{点菜员}  人数：#{就餐人数}\n' +
				'下单时间：#{下单时间}  餐别:#{餐别}\n' +
				'开单号：#{订单号}\n' +
                '备注：#{备注}\n' +
				'-----------------------------------------\n' +
				'品名              数量      单价     金额\n' +
				'-----------------------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '----------------------------------------\n' +
                '退菜\n' +
                '----------------------------------------\n' +
                '#{退菜}\n' +
                '----------------------------------------\n' +
                '赠菜\n' +
                '----------------------------------------\n' +
                '#{赠菜}\n' +
                '----------------------------------------\n' +
                '#{财务类别合计}\n' +
				'-----------------------------------------\n' +
				//'(消费合计:)                        (#{订单金额})\n' +
				//'-----------------------------------------\n' +
                '#pay_item\n' +
				'#{付款方式}              #{付款金额}\n' +
				'#pay_item\n' +
				'----------------------------------------\n' +
				'(应收:)                            (#{应收金额})\n' +
				'欢迎光临#{门店名称}';

    var _template58 =
				'<[#{门店名称}]>\n' +
				'<[对账单]>\n' +
				'-----------------------------\n' +
				'<(#{桌台号})>\n' +
				'服务员: #{点菜员}  人数：#{就餐人数}\n' +
				'下单时间：#{下单时间}  \n餐别:#{餐别}\n' +
				'开单号：#{订单号}\n' +
                '备注：#{备注}\n' +
				'-----------------------------\n' +
				'品名       数量    单价   金额\n' +
				'-----------------------------\n' +
				'#item\n' +
				'#{菜品名称}#{菜品数量}  #{菜品单价}  #{菜品金额}\n' +
                '#{做法}\n' +
                '#item\n' +
                '-----------------------------\n' +
                '退菜\n' +
                '-----------------------------\n' +
                '#{退菜}\n' +
                '-----------------------------\n' +
                '赠菜\n' +
                '-----------------------------\n' +
                '#{赠菜}\n' +
                '-----------------------------\n' +
                '#{财务类别合计}\n' +
				'-----------------------------\n' +
				//'(消费合计:)            (#{订单金额})\n' +
				//'-----------------------------\n' +
                '#pay_item\n' +
				'#{付款方式}              #{付款金额}\n' +
				'#pay_item\n' +
				'-----------------------------\n' +
				'(应收:)                (#{应收金额})\n' +
				'欢迎光临#{门店名称}';

    // #endregion 

    this.getTemplate = function () {
        if (this.size === 58)
            return _template58;
        return _template;
    };

    var linelen = 40;
    var spacelen = 0;
    var dishnamelen = 20;
    var dishnumlen = 6;
    var dishpricelen = 7;
    var dishmoneylen = 9;
    var paymentlen = 8;

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 16;
            dishnumlen = 8;
            dishpricelen = 8;
            dishmoneylen = 10;
            paymentlen = 27;
        }
        else {
            linelen = 32;
            dishnamelen = 12;
            dishpricelen = 6;
            dishnumlen = 5;
            dishmoneylen = 6;
            paymentlen = 18;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var order = object;
        order.remark = (order.remark || order.remark == 'null') ? order.remark : ' ';
        var ordermoney = order.ret ? order.ret.total.ToString("C") : order.ordermoney.ToString("C");
        printtext = printtext.replaceAll('#{门店名称}', order.company)
            .replaceAll('#{点菜员}', order.diancaiyuan)
            .replaceAll('#{就餐人数}', order.rs)
            .replaceAll('#{餐别}', order.canbie)
            .replaceAll('#{订单号}', order.orderno)
            .replaceAll('#{下单时间}', order.ordertime)
            .replaceAll('#{桌台号}', order.zhuotai)
            .replaceAll('#{备注}', order.remark)
            .replaceAll('#{订单金额}', ordermoney);


        // #region 计算财务类别合计

        if (printtext.indexOf('#{财务类别合计}') >= 0) {
            var cwlbhj = [];
            for (var i in order.dishs) {
                var tcp = order.dishs[i];
                var cw = null;
                for (var j in cwlbhj) {
                    if (cwlbhj[j].kid == tcp.caiwuTypeId)
                        cw = cwlbhj[j];
                }
                if (cw == null && tcp.caiwuTypeId)
                    cwlbhj.push({ kid: tcp.caiwuTypeId, kname: tcp.caiwuTypeName, kmoney: tcp.m4Print() });
                else if (cw)
                    cw.kmoney += tcp.m4Print();
            }

            var cwlbhjstr = '';
            for (var h in cwlbhj) {
                var itemstr = cwlbhj[h].kname + ":" + Utils.m2string(cwlbhj[h].kmoney);
                if ((Utils.getPrinterLength(itemstr) + Utils.getPrinterLength(cwlbhjstr)) > linelen)
                    cwlbhjstr += '\n';
                cwlbhjstr += itemstr + ' ';
            }
            printtext = printtext.replaceAll('#{财务类别合计}', cwlbhjstr);

        }
        // #endregion
        
        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && order.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(' ', '').replaceAll('#{做法}\n', '\n#{做法}');
                var relcptext = '';
                var tuicais = [];
                var zengsongcaipins = [];

                for (var i in order.dishs) {
                    var cp = order.dishs[i];

                    if (cp.num < 0)
                        continue;


                    if (cp.tuiNum != 0)
                        tuicais = tuicais.concat(cp.getTuiCai());

                    if (cp.zengNum != 0)
                        zengsongcaipins.push(cp);

                    cp.num = cp.num - cp.tuiNum;
                    if (cp.num <= 0)
                        continue;

                    var cpname = (cp.danPinZheKou) ? ('↓' + cp.name) : cp.name;
                    var numberStr = (cp.num).ToString("C") + cp.unitName;
                    var priceStr = cp.price.ToString("C");
                    var amountStr = Utils.m(cp.m4Print()).ToString("C");
                    var tp_cp_replace_mode = relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";

                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        debugger;
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            if ((scp.num) < 0) {
                                tuicais.push(scp);
                                continue;
                            }

                            if (scp.tuiNum != 0)
                                tuicais = tuicais.concat(scp.getTuiCai());

                            if (scp.zengNum != 0)
                                zengsongcaipins.push(scp);

                            scp.num = scp.num - scp.tuiNum;
                            if (scp.num <= 0)
                                continue;

                            var scpname = '* ' + scp.name;
                            var snumstr = (scp.num).ToString("C") + scp.unitName;
                            var tp_repmode = relcptextmode.replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen)).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen)) + "\n";
                            var tc_zf_txt = '\n';
                            if (scp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    zf.parentCaiPin = scp;
                                    var zfname = ' -做法:' + zf.name;
                                    var zfprice = '';
                                    var zfnum = '';
                                    var zfonep = '';
                                    tc_zf_txt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + "\n";
                                }
                            }
                            tp_repmode = tp_repmode.replaceAll('#{做法}\n', tc_zf_txt).replaceAll('#{做法}', tc_zf_txt);
                            tp_cp_replace_mode += tp_repmode;
                        }
                    }

                    var zftxt = '\n';
                    if (cp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = ' -做法:' + zf.name;
                            var zfprice = Utils.m(zf.m4Print()).ToString('C');
                            var zfnum = '';
                            var zfonep = '';
                            zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                        }
                    }
                    tp_cp_replace_mode = tp_cp_replace_mode.replaceAll('#{做法}\n', zftxt).replaceAll('#{做法}', zftxt);

                    relcptext += tp_cp_replace_mode;
                }

                // #region 没有退菜菜品的话，就不显示
                if (tuicais.length == 0) {
                    var spprinttextarr = printtext.split('\n');
                    var spindex = -1;
                    for (var s in spprinttextarr) {
                        var stext = spprinttextarr[s];
                        if (stext.indexOf('#{退菜}') >= 0)
                            spindex = s;
                    }
                    if (spindex >= 0) {
                        spprinttextarr.splice(spindex, 1);
                        if (spprinttextarr[spindex - 1].indexOf('退菜') >= 0)
                            spprinttextarr.splice(spindex - 1, 1);
                        if (spprinttextarr[spindex - 2].indexOf('退菜') >= 0) {
                            spprinttextarr.splice(spindex - 1, 1);
                            spprinttextarr.splice(spindex - 2, 1);
                        }
                    }
                    printtext = spprinttextarr.join('\n');
                }
                // #endregion

                var tuicaitxt = '';
                if (tuicais.length > 0) {
                    for (var i in tuicais) {
                        var cp = tuicais[i];

                        var cpname = cp.name;
                        var numberStr = (cp.num * -1).ToString("C") + cp.unitName;
                        var priceStr = '';//cp.price.ToString("C");
                        var amountStr = '退菜';

                        tuicaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        var tc_zftxt = '\n';
                        if (cp.zuofas.length > 0) {
                            for (var z in cp.zuofas) {
                                var zf = cp.zuofas[z];
                                if (!zf.parentCaiPin)
                                    zf.parentCaiPin = cp;
                                var zfname = ' -做法:' + zf.name;
                                var zfprice = '';//(Utils.m(zf.mRaw())*-1).ToString('C');
                                var zfnum = '';
                                var zfonep = '';
                                tc_zftxt += zfname + Utils.printBlank(dishnamelen + 6 - Utils.getPrinterLength(zfname)) + Utils.printBlank(dishnumlen - 5 - Utils.getPrinterLength(zfnum)) + zfnum + Utils.printBlank(dishpricelen - 1 - Utils.getPrinterLength(zfonep)) + zfonep + Utils.printBlank(dishmoneylen - Utils.getPrinterLength(zfprice)) + zfprice + '\n';
                            }
                        }
                        tuicaitxt = tuicaitxt.replaceAll('#{做法}\n', tc_zftxt).replaceAll('#{做法}', tc_zftxt);
                    }
                }
                printtext = printtext.replaceAll('#{退菜}\n', tuicaitxt).replaceAll('#{退菜}', tuicaitxt);

                
                // #region 没有赠菜菜品的话，就不显示
                if (zengsongcaipins.length == 0) {
                    var spprinttextarr = printtext.split('\n');
                    var spindex = -1;
                    for (var s in spprinttextarr) {
                        var stext = spprinttextarr[s];
                        if (stext.indexOf('#{赠菜}') >= 0)
                            spindex = s;
                    }
                    if (spindex >= 0) {
                        spprinttextarr.splice(spindex, 1);
                        if (spprinttextarr[spindex - 1].indexOf('赠菜') >= 0)
                            spprinttextarr.splice(spindex - 1, 1);
                        if (spprinttextarr[spindex - 2].indexOf('赠菜') >= 0) {
                            spprinttextarr.splice(spindex - 1, 1);
                            spprinttextarr.splice(spindex - 2, 1);
                        }
                    }
                    printtext = spprinttextarr.join('\n');
                }
                // #endregion

                var zengcaitxt = '';
                if (zengsongcaipins.length > 0) {
                    for (var i in zengsongcaipins) {
                        var cp = zengsongcaipins[i];

                        var cpname = cp.name;
                        var numberStr = (cp.zengNum).ToString("C") + cp.unitName;
                        var priceStr = cp.price.ToString("C");
                        var amountStr = '赠菜';

                        zengcaitxt += relcptextmode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr).replaceAll('#{菜品单价}', Utils.printBlank(dishpricelen - Utils.getPrinterLength(priceStr)) + priceStr).replaceAll('#{菜品金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(amountStr)) + amountStr) + "\n";
                        zengcaitxt = zengcaitxt.replaceAll('#{做法}\n', '\n').replaceAll('#{做法}', '\n');
                    }
                }
                printtext = printtext.replaceAll('#{赠菜}\n', zengcaitxt).replaceAll('#{赠菜}', zengcaitxt);

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        if (order.ret && order.ret.payment.length > 0) {
            printtext = printtext.replaceAll('#{应收金额}', order.yingshou.ToString("C"))
        } else {
            printtext = Utils.removePrintLineByK(printtext, '#{应收金额}');// printtext.replaceAll('#{应收金额}', '').replaceAll('应收:', '').replaceAll('应收', '');
        }

        var paytextmode = '';
        var relpaytext = '';

        //循环付款方式
        var indexpayitem = printtext.indexOf('#pay_item');
        fetchLength = 10;
        if (indexpayitem > 0) {
            var lastpayindexitem = printtext.lastIndexOf('#pay_item\n');
            if (lastpayindexitem == -1) {
                lastpayindexitem = printtext.lastIndexOf('#pay_item');
                fetchLength = 9;
            }
            if (indexpayitem == lastpayindexitem) {
                printtext.replaceAll('#pay_item', '');
                printtext.replaceAll('#pay_item\n', '');
            }
            else {
                paytextmode = printtext.substring(indexpayitem, lastpayindexitem + fetchLength);
            }
        }

        var relpaytextmode = paytextmode.replaceAll('#pay_item', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");



        if (order.ret) {//&& order.ret.payment.length > 0) {
            if (order.ret.ofZheKouMoney) {
                var yhname = order.ret.ofZheKouName;
                var yhmoney = order.ret.ofZheKouMoney.ToString('C');

                relpaytext += relpaytextmode.replaceAll('#{付款方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
            }

            if (order.ret.danPinSum) {
                var yhname = '单品折扣';
                var yhmoney = order.ret.danPinSum.ToString('C');

                relpaytext += relpaytextmode.replaceAll('#{付款方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
            }

            if (order.ret.moLingSum) {
                var yhname = '抹零';
                var yhmoney = order.ret.moLingSum.ToString('C');

                relpaytext += relpaytextmode.replaceAll('#{付款方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
            }

            if (order.ret.youMian) {
                var yhname = '定额优惠';
                var yhmoney = order.ret.youMian.ToString('C');

                relpaytext += relpaytextmode.replaceAll('#{付款方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
            }

            if (order.ret.free) {
                var yhname = '赠送';
                var yhmoney = order.ret.free;

                relpaytext += relpaytextmode.replaceAll('#{付款方式}', yhname + Utils.printBlank(paymentlen - Utils.getPrinterLength(yhname))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(yhmoney)) + yhmoney) + "\n";;
            }

            relpaytext += this.size === 58 ? '-----------------------------\n' : '------------------------------------------\n';

            for (var i in order.ret.payment) {
                var cp = order.ret.payment[i];
                var name = cp.name;
                var paymentNumStr = cp.pmMoney().ToString("C");
                relpaytext += relpaytextmode.replaceAll('#{付款方式}', name + Utils.printBlank(paymentlen - Utils.getPrinterLength(name))).replaceAll('#{付款金额}', Utils.printBlank(dishmoneylen - Utils.getPrinterLength(paymentNumStr)) + paymentNumStr) + "\n";;
            }
        }


        printtext = printtext.replaceAll(paytextmode, relpaytext);


        return printtext;
    };
}

function JieBanDanObject() {
    this.orders = [
		{
		    orderNo: "",
		    rateMoney: "",
		    cwkm: [
				{
				    id: "",
				    name: "",
				    money: ""
				}
		    ]
		}
    ];

    this.taxMoney = null;//发票金额
    this.shouyinyuan = null;
    this.banciNo = null;
    this.startTime = null;
    this.endTime = null;

    this.totalrs = 0;
    this.totalzhuotai = 0;

    this.zengSongMoney = 0;

    this.cplx = [
		{
		    id: "",
		    name: "",
		    money: ""
		}
    ];

    this.cwkm = [
		{
		    id: "",
		    name: "",
		    money: ""
		}
    ];

    this.zhekous = [
        {
            id: "",
            name: "",
            money: ""
        }
    ];

    this.chongzhis = [
		{
		    id: "",
		    name: "",
		    money: ""
		}
    ];


    this.getTotalCwkm = function () {

    };

    this.getTotalCplx = function () {

    };

    this.getTotalZK = function () {

    };

}

function JieBanDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    // #region 自带模板

    var _template = '<[#{门店名称}]>\n\n<[结班单]>\n' +
	'---------------------------------------\n' +
	'本班次共有#{账单条数}条账单 开发票:#{发票金额}\n' +
	'收银员：#{收银员} 班次号：#{班次号}\n' +
	'打印时间：#{打印时间}\n' +
	'开班时间：#{开班时间}\n' +
	'结班时间：#{结班时间}\n' +
    '总人数：#{总人数}         桌台数：#{桌台数} \n' +
	'---------------------------------------\n' +
	'销售类别统计\n' +
	'---------------------------------------\n' +
	'#cplx\n' +
	'#{菜品类型}#{菜品类型金额}\n' +
	'#cplx\n' +
	'---------------------------------------\n' +
	'付款项目\n' +
	'---------------------------------------\n' +
	'#cwkm\n' +
	'#{财务科目}#{财务科目金额}\n' +
	'#cwkm\n' +
    '---------------------------------------\n' +
    '优免项目\n' +
	'---------------------------------------\n' +
	'#cwym\n' +
	'#{优免科目}#{优免科目金额}\n' +
	'#cwym\n' +
    '---------------------------------------\n' +
	'会员充值统计\n' +
	'---------------------------------------\n' +
	'#membercz\n' +
	'#{财务科目}#{财务科目金额}\n' +
	'#membercz\n'+
    '---------------------------------------\n' +
    '退卡统计\n' +
    '---------------------------------------\n' +
    '#membertui\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#membertui\n'+
    '---------------------------------------\n' +
    '卡收入\n' +
    '---------------------------------------\n' +
    '#memberhj\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#memberhj\n';


    var _template58 = '<[#{门店名称}]>\n\n<[结班单]>\n' +
   '-----------------------------\n' +
   '本班次共有#{账单条数}条账单 开发票:#{发票金额}\n' +
   '收银员：#{收银员}\n' +
   '班次号：#{班次号}\n' +
   '打印时间：#{打印时间}\n' +
   '开班时间：#{开班时间}\n' +
   '结班时间：#{结班时间}\n' +
   '总人数：#{总人数}    桌台数：#{桌台数} \n' +
   '-----------------------------\n' +
   '销售类别统计\n' +
   '-----------------------------\n' +
   '#cplx\n' +
   '#{菜品类型}#{菜品类型金额}\n' +
   '#cplx\n' +
   '-----------------------------\n' +
   '付款项目\n' +
   '-----------------------------\n' +
   '#cwkm\n' +
   '#{财务科目}#{财务科目金额}\n' +
   '#cwkm\n' +
   '-----------------------------\n' +
   '优免项目\n' +
   '-----------------------------\n' +
   '#cwym\n' +
   '#{优免科目}#{优免科目金额}\n' +
   '#cwym\n' +
   '-----------------------------\n' +
   '会员充值统计\n' +
   '-----------------------------\n' +
   '#membercz\n' +
   '#{财务科目}#{财务科目金额}\n' +
   '#membercz\n'+
    '-----------------------------\n' +
    '退卡统计\n' +
    '-----------------------------\n' +
    '#membertui\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#membertui\n'+
    '-----------------------------\n' +
    '卡收入\n' +
    '-----------------------------\n' +
    '#memberhj\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#memberhj\n';

    // #endregion

    var linelen = 40;
    var ordernolen = 20;
    var ordercwkmlen = 12;
    var youhuimoney = 10;
    var namelen = 20;
    var moneylen = 12;

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            ordernolen = 20;
            ordercwkmlen = 12;
            youhuimoney = 10;
            namelen = 30;
            moneylen = 12;
        }
        else {
            linelen = 32;
            ordernolen = 15;
            ordercwkmlen = 9;
            youhuimoney = 8;
            namelen = 20;
            moneylen = 8;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var cplxhj = object.getTotalCplx();
        var cwkmhj = object.getTotalCwkm();
        var cwzkhj = object.getTotalZK();

        var renjun = object.totalrs ? Utils.m2string(Utils.m(cwkmhj) / Utils.m(object.totalrs)) : '0.00';
        var zhuojun = object.totalzhuotai ? Utils.m2string(Utils.m(cwkmhj) / Utils.m(object.totalzhuotai)) : '0.00';
        var zsMoney = object.zengSongMoney;
        var yingyemoneyNoZS = Utils.m2string(cplxhj - zsMoney);

        printtext = printtext.replaceAll('#{账单条数}', object.orders.length)
            .replaceAll('#{发票金额}', object.taxMoney)
            .replaceAll('#{班次号}', object.banciNo)
            .replaceAll('#{开班时间}', object.startTime)
            .replaceAll('#{结班时间}', object.endTime)
            .replaceAll('#{收银员}', object.shouyinyuan)
            .replaceAll('#{门店名称}', BIZCONSTANT.POSUSER.HotelName)
            .replaceAll('#{总人数}', object.totalrs)
            .replaceAll('#{桌台数}', object.totalzhuotai)
            .replaceAll('#{菜品类型合计}', cplxhj)
            .replaceAll('#{人均}', renjun)
            .replaceAll('#{桌均}', zhuojun)
            .replaceAll('#{不含赠送营业额}', yingyemoneyNoZS)
            .replaceAll('#{财务科目合计}', cwkmhj);

        var orderIndexIndex = printtext.indexOf('#orders#');
        if (orderIndexIndex != -1) {
            var tempText = "";
            tempText += "账单编号" + Utils.printBlank(ordernolen - Utils.getPrinterLength("账单编号")) + Utils.printBlank(ordercwkmlen - Utils.getPrinterLength("付款方式")) + "付款方式" + Utils.printBlank(youhuimoney - Utils.getPrinterLength("优惠金额")) + "优惠金额" + "\n";
            for (var i in object.orders) {
                var cp = object.orders[i];
                var cwkms = cp.cwkm;
                for (var idx in cwkms) {
                    var cwkm = cwkms[idx];
                    var cwkmStr = cwkm.name + ":" + cwkm.money;
                    if (idx == "0") {
                        tempText += cp.orderNo + Utils.printBlank(ordernolen - Utils.getPrinterLength(cp.orderNo));
                    }
                    else {
                        tempText += Utils.printBlank(ordernolen);
                    }
                    tempText += Utils.printBlank(ordercwkmlen - Utils.getPrinterLength(cwkmStr)) + cwkmStr;
                    if (idx == "0") {
                        var rateMoneyStr = cp.rateMoney.ToString("C");
                        tempText += Utils.printBlank(youhuimoney - Utils.getPrinterLength(rateMoneyStr)) + rateMoneyStr + "\n";
                    }
                    else {
                        tempText += Utils.printBlank(youhuimoney) + "\n";
                    }
                }
            }
            printtext = printtext.replaceAll("#orders#", tempText);
        }

        var indexitem = printtext.indexOf('#cplx');
        var fetchLength = 6;
        if (indexitem > 0 && object.cplx) {
            var lastindexitem = printtext.lastIndexOf('#cplx\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#cplx');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cplx', '');
                printtext.replaceAll('#cplx\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cplx', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.cplx) {
                    var cp = object.cplx[i];

                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{菜品类型}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{菜品类型金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = '('+Utils.m(cplxhj).ToString('C')+')';
                relcptext += relcptextmode.replaceAll('#{菜品类型}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{菜品类型金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)+2) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        indexitem = printtext.indexOf('#cwkm');
        fetchLength = 6;
        if (indexitem > 0 && object.cwkm) {
            var lastindexitem = printtext.lastIndexOf('#cwkm\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#cwkm');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cwkm', '');
                printtext.replaceAll('#cwkm\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cwkm', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.cwkm) {
                    var cp = object.cwkm[i];

                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = '('+Utils.m(cwkmhj).ToString('C')+')';
                relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)+2) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------

        indexitem = printtext.indexOf('#cwym');
        fetchLength = 6;
        if (indexitem > 0 && object.zhekous) {
            var lastindexitem = printtext.lastIndexOf('#cwym\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#cwym');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cwym', '');
                printtext.replaceAll('#cwym\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cwym', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.zhekous) {
                    var cp = object.zhekous[i];

                    var numberStr = Utils.m2string(cp.money);

                    relcptext += relcptextmode.replaceAll('#{优免科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{优免科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = '('+Utils.m(cwzkhj).ToString('C')+")";
                relcptext += relcptextmode.replaceAll('#{优免科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{优免科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)+2) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#membercz');
        fetchLength = 10;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#membercz\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#membercz');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#membercz', '');
                printtext.replaceAll('#membercz\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#membercz\n', '').replaceAll('#membercz', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                for (var i in object.chongzhis) {
                    var cp = object.chongzhis[i];
                    if (cp.type != 'RD021' && cp.type != 'RD024')
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '') {
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计", -1);
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计", 1);
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计");
                }
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#membertui');
        fetchLength = 11;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#membertui\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#membertui');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#membertui', '');
                printtext.replaceAll('#membertui\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#membertui\n', '').replaceAll('#membertui', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                for (var i in object.chongzhis) {
                    var cp = object.chongzhis[i];
                    if (!cp.type || (cp.type != 'RD131' && cp.type != 'RD134'))
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '')
                {
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计", -1);
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计", 1);
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计");
                }  
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#memberhj');
        fetchLength = 10;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#memberhj\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#memberhj');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#memberhj', '');
                printtext.replaceAll('#memberhj\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#memberhj\n', '').replaceAll('#memberhj', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                var srhjarr = [{ name: '现金', money: 0 }];
                for (var i1 in object.chongzhis)
                {
                    var itemcz = object.chongzhis[i1];
                    itemcz.name = itemcz.name.replaceAll('（退押金）', '').replaceAll('（退余额）', '').replaceAll('（押金）', '');
                    var oldcz=Utils.arrayFind(srhjarr,itemcz.name,'name');
                    if (oldcz)
                        oldcz.money += Utils.m(itemcz.money);
                    else
                        srhjarr.push(itemcz);
                }

                for (var i in srhjarr) {
                    var cp = srhjarr[i];
                    if (!cp.money)
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '') {
                    printtext = Utils.removePrintLineByK(printtext, "卡收入", -1);
                    printtext = Utils.removePrintLineByK(printtext, "卡收入", 1);
                    printtext = Utils.removePrintLineByK(printtext, "卡收入");
                }
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }


        return printtext;
    };
}

function ShouYinReportTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template = '<[#{门店名称}]>\n\n<[收银报表单]>\n' +
	'---------------------------------------\n' +
	'共有#{账单条数}条账单 \n' +
	'收银员：#{收银员} \n' +
	'打印时间：#{打印时间}\n' +
	'开始日期：#{开始日期}\n' +
	'结束日期：#{结束日期}\n' +
    '总人数：#{总人数}    桌台数：#{桌台数} \n' +
	'---------------------------------------\n' +
	'销售类别统计\n' +
	'---------------------------------------\n' +
	'#cplx\n' +
	'#{菜品类型}#{菜品类型金额}\n' +
	'#cplx\n' +
	'---------------------------------------\n' +
	'付款项目\n' +
	'---------------------------------------\n' +
	'#cwkm\n' +
	'#{财务科目}#{财务科目金额}\n' +
	'#cwkm\n' +
    '---------------------------------------\n' +
    '优免项目\n' +
	'---------------------------------------\n' +
	'#cwym\n' +
	'#{优免科目}#{优免科目金额}\n' +
	'#cwym\n' +
    '---------------------------------------\n' +

	'会员充值统计\n' +
	'---------------------------------------\n' +
	'#membercz\n' +
	'#{财务科目}#{财务科目金额}\n' +
	'#membercz\n' +
    '---------------------------------------\n' +
    '退卡统计\n' +
    '---------------------------------------\n' +
    '#membertui\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#membertui\n' +
    '---------------------------------------\n' +
    '卡收入\n' +
    '---------------------------------------\n' +
    '#memberhj\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#memberhj\n';

    var _template58 = '<[#{门店名称}]>\n\n<[收银报表单]>\n' +
   '-----------------------------\n' +
   '共有#{账单条数}条账单 \n' +
   '收银员：#{收银员}\n' +
   '打印时间：#{打印时间}\n' +
   '开始日期：#{开始日期}\n' +
   '结束日期：#{结束日期}\n' +
   '总人数：#{总人数}    桌台数：#{桌台数} \n' +
   '-----------------------------\n' +
   '销售类别统计\n' +
   '-----------------------------\n' +
   '#cplx\n' +
   '#{菜品类型}#{菜品类型金额}\n' +
   '#cplx\n' +
   '-----------------------------\n' +
   '付款项目\n' +
   '-----------------------------\n' +
   '#cwkm\n' +
   '#{财务科目}#{财务科目金额}\n' +
   '#cwkm\n' +
   '-----------------------------\n' +
   '优免项目\n' +
   '-----------------------------\n' +
   '#cwym\n' +
   '#{优免科目}#{优免科目金额}\n' +
   '#cwym\n' +
   '-----------------------------\n' +
   '会员充值统计\n' +
   '-----------------------------\n' +
   '#membercz\n' +
   '#{财务科目}#{财务科目金额}\n' +
   '#membercz\n' +
    '-----------------------------\n' +
    '退卡统计\n' +
    '-----------------------------\n' +
    '#membertui\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#membertui\n' +
    '-----------------------------\n' +
    '卡收入\n' +
    '-----------------------------\n' +
    '#memberhj\n' +
    '#{财务科目}#{财务科目金额}\n' +
    '#memberhj\n';


    var linelen = 40;
    var ordernolen = 20;
    var ordercwkmlen = 12;
    var youhuimoney = 10;
    var namelen = 20;
    var moneylen = 12;

    this.getTemplate = function () {
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            ordernolen = 20;
            ordercwkmlen = 12;
            youhuimoney = 10;
            namelen = 30;
            moneylen = 12;
        }
        else {
            linelen = 32;
            ordernolen = 15;
            ordercwkmlen = 9;
            youhuimoney = 8;
            namelen = 20;
            moneylen = 8;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{账单条数}', object.jiaoyiCount).replaceAll('#{发票金额}', object.taxMoney).replaceAll('#{班次号}', object.banciNo).replaceAll('#{开始日期}', object.startTime).replaceAll('#{结束日期}', object.endTime).replaceAll('#{收银员}', object.shouyinyuan).replaceAll('#{门店名称}', BIZCONSTANT.POSUSER.HotelName);
        printtext = printtext.replaceAll('#{总人数}', object.totalrs).replaceAll('#{桌台数}', object.totalzhuotai);
        var cplxhj = object.getTotalCplx();
        var cwkmhj = object.getTotalCwkm();
        var cwzkhj = object.getTotalZK();
        printtext = printtext.replaceAll('#{菜品类型合计}', cplxhj).replaceAll('#{财务科目合计}', cwkmhj);

        var orderIndexIndex = printtext.indexOf('#orders#');
        if (orderIndexIndex != -1) {
            var tempText = "";
            tempText += "账单编号" + Utils.printBlank(ordernolen - Utils.getPrinterLength("账单编号")) + Utils.printBlank(ordercwkmlen - Utils.getPrinterLength("付款方式")) + "付款方式" + Utils.printBlank(youhuimoney - Utils.getPrinterLength("优惠金额")) + "优惠金额" + "\n";
            for (var i in object.orders) {
                var cp = object.orders[i];
                var cwkms = cp.cwkm;
                for (var idx in cwkms) {
                    var cwkm = cwkms[idx];
                    var cwkmStr = cwkm.name + ":" + cwkm.money;
                    if (idx == "0") {
                        tempText += cp.orderNo + Utils.printBlank(ordernolen - Utils.getPrinterLength(cp.orderNo));
                    }
                    else {
                        tempText += Utils.printBlank(ordernolen);
                    }
                    tempText += Utils.printBlank(ordercwkmlen - Utils.getPrinterLength(cwkmStr)) + cwkmStr;
                    if (idx == "0") {
                        var rateMoneyStr = cp.rateMoney.ToString("C");
                        tempText += Utils.printBlank(youhuimoney - Utils.getPrinterLength(rateMoneyStr)) + rateMoneyStr + "\n";
                    }
                    else {
                        tempText += Utils.printBlank(youhuimoney) + "\n";
                    }
                }
            }
            printtext = printtext.replaceAll("#orders#", tempText);
        }

        var indexitem = printtext.indexOf('#cplx');
        var fetchLength = 6;
        if (indexitem > 0 && object.cplx) {
            var lastindexitem = printtext.lastIndexOf('#cplx\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#cplx');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cplx', '');
                printtext.replaceAll('#cplx\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cplx', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.cplx) {
                    var cp = object.cplx[i];

                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{菜品类型}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{菜品类型金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = Utils.m(cplxhj).ToString('C');
                relcptext += relcptextmode.replaceAll('#{菜品类型}', '合计' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{菜品类型金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        indexitem = printtext.indexOf('#cwkm');
        fetchLength = 6;
        if (indexitem > 0 && object.cwkm) {
            var lastindexitem = printtext.lastIndexOf('#cwkm\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#cwkm');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cwkm', '');
                printtext.replaceAll('#cwkm\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cwkm', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.cwkm) {
                    var cp = object.cwkm[i];

                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = Utils.m(cwkmhj).ToString('C');
                relcptext += relcptextmode.replaceAll('#{财务科目}', '合计' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------

        indexitem = printtext.indexOf('#cwym');
        fetchLength = 6;
        if (indexitem > 0 && object.zhekous) {
            var lastindexitem = printtext.lastIndexOf('#cwym\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#cwym');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#cwym', '');
                printtext.replaceAll('#cwym\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#cwym', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                for (var i in object.zhekous) {
                    var cp = object.zhekous[i];

                    var numberStr = Utils.m2string(cp.money);

                    relcptext += relcptextmode.replaceAll('#{优免科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{优免科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                var hjstr = Utils.m(cwzkhj).ToString('C');
                relcptext += relcptextmode.replaceAll('#{优免科目}', '合计' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{优免科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr)) + hjstr) + "\n";

                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#membercz');
        fetchLength = 10;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#membercz\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#membercz');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#membercz', '');
                printtext.replaceAll('#membercz\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#membercz\n', '').replaceAll('#membercz', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                for (var i in object.chongzhis) {
                    var cp = object.chongzhis[i];
                    if (cp.type != 'RD021' && cp.type != 'RD024')
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '') {
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计", -1);
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计", 1);
                    printtext = Utils.removePrintLineByK(printtext, "会员充值统计");
                }
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#membertui');
        fetchLength = 11;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#membertui\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#membertui');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#membertui', '');
                printtext.replaceAll('#membertui\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#membertui\n', '').replaceAll('#membertui', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                for (var i in object.chongzhis) {
                    var cp = object.chongzhis[i];
                    if (!cp.type || (cp.type != 'RD131' && cp.type != 'RD134'))
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '') {
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计", -1);
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计", 1);
                    printtext = Utils.removePrintLineByK(printtext, "退卡统计");
                }
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        //--------------------------------------------------------------------------
        indexitem = printtext.indexOf('#memberhj');
        fetchLength = 10;
        if (indexitem > 0 && object.chongzhis) {
            debugger;
            var lastindexitem = printtext.lastIndexOf('#memberhj\n');
            if (lastindexitem == -1 || indexitem == lastindexitem) {
                lastindexitem = printtext.lastIndexOf('#memberhj');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#memberhj', '');
                printtext.replaceAll('#memberhj\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#memberhj\n', '').replaceAll('#memberhj', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                var relcptext = '';
                var hj = 0;
                var srhjarr = [{ name: '现金', money: 0 }];
                for (var i1 in object.chongzhis) {
                    var itemcz = object.chongzhis[i1];
                    itemcz.name = itemcz.name.replaceAll('（退押金）', '').replaceAll('（退余额）', '').replaceAll('（押金）', '');
                    var oldcz = Utils.arrayFind(srhjarr, itemcz.name, 'name');
                    if (oldcz)
                        oldcz.money += Utils.m(itemcz.money);
                    else
                        srhjarr.push(itemcz);
                }

                for (var i in srhjarr) {
                    var cp = srhjarr[i];
                    if (!cp.money)
                        continue;
                    hj += cp.money;
                    var numberStr = cp.money.ToString("C");

                    relcptext += relcptextmode.replaceAll('#{财务科目}', cp.name + Utils.printBlank(namelen - Utils.getPrinterLength(cp.name))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(numberStr)) + numberStr) + "\n";
                }
                if (relcptext == '') {
                    printtext = Utils.removePrintLineByK(printtext, "卡收入", -1);
                    printtext = Utils.removePrintLineByK(printtext, "卡收入", 1);
                    printtext = Utils.removePrintLineByK(printtext, "卡收入");
                }
                else {
                    //var hjstr = '(' + hj.ToString('C') + ')';
                    //relcptext += relcptextmode.replaceAll('#{财务科目}', '(合计)' + Utils.printBlank(namelen - Utils.getPrinterLength('合计'))).replaceAll('#{财务科目金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(hjstr) + 2) + hjstr) + "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);
            }
        }

        return printtext;
    };
}


function XiaoShouTypeTongJiObject()
{
    this.startTime = '';

    this.endTime = '';

    this.operatorName = '';

    this.zheQianMoney = '';

    this.shiShouMoney = '';

    this.youMianMoney = '';

    this.tuiCaiMoney = '';

    this.num = '';

    this.res = [
        {
            typeName: '',
            total:'',
            cps: [
                {
                    name: '',
                    unitName: '',
                    num: 0,
                    money: 0
                }
            ]
        }
    ];
}

function XiaoShouTypeTongJiTemplate()
{
    this.base = PrinterTemplate;
    this.base();

    var _template = '<[#{门店名称}]>\n\n<[品项销售统计表]>\n' +
	'---------------------------------------\n' +
	'开始时间：#{开始时间}\n' +
	'结束时间：#{结束时间}\n' +
	'点菜员：#{收银员}\n' +
	'销售统计：#{销售统计}\n' +
	'营业收入：#{营业收入}\n' +
    '营业优免：#{营业优免}\n' +
    '退菜金额：#{退菜金额}\n' +
    '菜品数量：#{菜品数量}\n' +
    '打印时间：#{打印时间}\n' +
    '---------------------------------------\n' +
    '名称              数量        金额 \n' +
    '#typeName' +
	'--------------------------------------- \n' +
	'#{类别名称}\n' +
	'--------------------------------------- \n' +
	'#cplx\n' +
	'#{菜品名称}#{数量}#{金额}\n' +
	'#cplx\n' +
    '#typeName';

    var _template58 = '<[#{门店名称}]>\n\n<[品项销售统计表]>\n' +
	'-----------------------------\n' +
    '开始时间：#{开始时间}\n' +
    '结束时间：#{结束时间} ' +
    '点菜员：#{收银员}\n' +
    '销售统计：#{销售统计}\n' +
    '营业收入：#{营业收入}\n' +
    '营业优免：#{营业优免}\n' +
    '退菜金额：#{退菜金额}\n' +
    '菜品数量：#{菜品数量}\n' +
    '打印时间：#{打印时间}\n' +
    '#typeName' +
	'-----------------------------\n' +
	'#{类别名称}\n' +
    '名称            数量   金额\n' +
	'-----------------------------\n' +
	'#cplx\n' +
	'#{菜品名称}#{数量}#{金额}\n' +
	'#cplx\n' +
    '#typeName';

    var linelen = 40;
    var namelen = 20;
    var unitlen = 3;
    var numlen = 4;
    var moneylen = 15;


    this.getTemplate = function () {
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            namelen = 15;
            unitlen = 5;
            numlen = 8;
            moneylen = 12;
        }
        else {
            linelen = 32;
            namelen = 15;
            unitlen = 3;
            numlen = 4;
            moneylen = 7;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{开始时间}', object.startTime).replaceAll('#{结束时间}', object.endTime).replaceAll('#{收银员}', object.operatorName).replaceAll('#{销售统计}', object.zheQianMoney).replaceAll('#{营业收入}', object.shiShouMoney).replaceAll('#{营业优免}', object.youMianMoney).replaceAll('#{退菜金额}', object.tuiCaiMoney).replaceAll('#{菜品数量}', object.num).replaceAll('#{打印时间}', Utils.now()).replaceAll('#{门店名称}', BIZCONSTANT.POSUSER.HotelName);



        var indexitem = printtext.indexOf('#typeName');
        var fetchLength = 10;
        if (indexitem > 0) {
            var lastindexitem = printtext.lastIndexOf('#typeName\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#typeName');
                fetchLength = 9;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#typeName', '');
                printtext.replaceAll('#typeName\n', '');
            }
            else {

                var bigcptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var bigrelcptextmode = bigcptextmode.replaceAll('#typeName', '').replaceAll("\r", "");
                var bigrelcptext = '';

                var inindex = bigcptextmode.indexOf('#cplx');
                var infetchLength = 6;
                var inlastindexitem = bigcptextmode.lastIndexOf('#cplx\n');
                if (inlastindexitem == -1) {
                    inlastindexitem = bigcptextmode.lastIndexOf('#cplx');
                    infetchLength = 5;
                }
                if (inindex == inlastindexitem) {
                    bigcptextmode.replaceAll('#cplx', '');
                    bigcptextmode.replaceAll('#cplx\n', '');
                }

                var incptextmode = bigcptextmode.substring(inindex, inlastindexitem + infetchLength);
                var inreplacemode = incptextmode.replaceAll('#cplx', '').replaceAll("\r", "").replaceAll("\n", "").replaceAll(" ", "");
                for (var i in object.res) {
                    var lp = object.res[i];
                    var tp_inrelace = '';

                    var hjname = '合计';
                    var hjnum = 0;
                    var hjunit = '';
                    var hjmoney = 0;


                    for (var j in lp.cps)
                    {
                        var cpname = lp.cps[j].name;
                        var unitName = lp.cps[j].unitName;
                        var num = Utils.m2string(lp.cps[j].num);
                        var money = Utils.m2string(lp.cps[j].zhenQianTotal);

                        hjnum += lp.cps[j].num;
                        hjmoney += lp.cps[j].zhenQianTotal;

                        tp_inrelace += inreplacemode.replaceAll('#{菜品名称}', cpname + Utils.printBlank(namelen - Utils.getPrinterLength(cpname))).replaceAll('#{菜品单位}',   unitName + Utils.printBlank(unitlen - Utils.getPrinterLength(unitName))  ).replaceAll('#{数量}',  Utils.printBlank(numlen - Utils.getPrinterLength(num)) + num ).replaceAll('#{金额}',  Utils.printBlank(moneylen - Utils.getPrinterLength(money)) + money ) + "\n";
                    }

                    tp_inrelace += inreplacemode.replaceAll('#{菜品名称}', '('+hjname+')' + Utils.printBlank(namelen - Utils.getPrinterLength(hjname))).replaceAll('#{菜品单位}', hjunit + Utils.printBlank(unitlen - Utils.getPrinterLength(hjunit))).replaceAll('#{数量}', Utils.printBlank(numlen - Utils.getPrinterLength(Utils.m2string(hjnum))) + '('+Utils.m2string(hjnum)+')').replaceAll('#{金额}', Utils.printBlank(moneylen - Utils.getPrinterLength(Utils.m2string(hjmoney))) +'('+ Utils.m2string(hjmoney)+')') + "\n";

                    bigrelcptext += bigrelcptextmode.replaceAll('#{类别名称}', lp.typeName + Utils.printBlank(namelen - Utils.getPrinterLength(lp.typeName))).replaceAll(incptextmode, tp_inrelace);
                }

                printtext = printtext.replaceAll(bigcptextmode, bigrelcptext);
            }
        }

        


        return printtext;
    };

}

function TongZhiDanObject() {
    this.diancaiyuan = null;
    this.deskNo = null;
    this.notifyText = null;
    this.rs = null;
    this.isZhengZhuo = false;
    this.dish = { name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 };
}

function TongZhiDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
    '<[#{打印机名称}通知单]>\n' +
    '---------------------------------------\n' +
    '#{打印时间} 点菜员:#{点菜员}\n' +
    '<(#{桌台号})>\n' +
    '#3$#{出品要求}$  $#{菜品名称}$\n' +
    '[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
    '\n' +
    '流水号：#{单据号}';

    var _template58 =
   '<[#{打印机名称}通知单]>\n' +
   '---------------------------\n' +
   '#{打印时间} 点菜员:#{点菜员}\n' +
   '<(#{桌台号})>\n' +
   '#3$#{出品要求}$  $#{菜品名称}$\n' +
   '[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
   '\n' +
   '流水号：#{单据号}';

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
            .replaceAll('#{点菜员}', object.diancaiyuan)
            .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
            .replaceAll('#{餐别}', object.canbie)
            .replaceAll('#{备注}', object.remark)
            .replaceAll('#{订单号}', object.orderno)
            .replaceAll('#{操作人}', object.operator);

        if (object.isZhengZhuo) {
            printtext = printtext.replaceAll('#{出品要求}', "整桌" + object.notifyText)
                .replaceAll('#{做法}', '')
                .replaceAll('#{口味}', '')
                .replaceAll('#{菜品名称}', '')
                .replaceAll('#{菜品数量}', '')
                .replaceAll('数量：', '')
                .replaceAll('数量', '');
        }
        else {
            var zfs = '';
            if (object.dish.zuofas) {
                debugger;
                for (var z in object.dish.zuofas) {
                    zfs += object.dish.zuofas[z].name + '\t';
                }
            }
            var kws = '';
            if (object.dish.kouweis) {

                for (var k in object.dish.kouweis) {
                    kws += object.dish.kouweis[k].name + '\t';
                }
            }
            printtext = printtext.replaceAll('#{做法}', zfs)
                .replaceAll('#{口味}', kws)
                .replaceAll('#{菜品名称}', object.dish.name)
                .replaceAll('#{菜品数量}', object.dish.num + object.dish.unitName)
                .replaceAll('#{出品要求}', object.notifyText);
        }

        return printtext;
    };
}

function HuaDanObject() {
    this.deskNo = null;
    this.rs = null;
    this.canbie = null;
    this.company = '袁州食府';
    this.companyphone = '0795-3563999';
    this.companyaddress = '宜春市环城西路363号';
    this.ordertime = null;
    this.orderno = null;
    this.dishs = [{ name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 }, { name: '清炒空心菜', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }, { name: '剑南春', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }];
    this.diancaiyuan = null;
    this.remark = '';
}

function HuaDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    // #region 默认模板
    var _template =
    '<[#{打印机名称}划单]>\n' +
    '<(#{桌台号})>\n' +
    '------------------------------------------\n' +
    '点菜员: #{点菜员}  人数：#{就餐人数}\n' +
    '下单时间：#{下单时间}  餐别:#{餐别}\n' +
    '开单号：#{订单号}\n' +
    '------------------------------------------\n' +
    '(菜品名称                            数量)\n' +
    '#item\n' +
    '(#{出品要求} #{菜品名称}#{菜品数量})\n' +
    '#{做法}\n' +
    '#{口味}\n' +
    '#item\n' +
    '------------------------------------------\n' +
    '流水号：#{单据号}';

    var _template58 =
    '<[#{打印机名称}划单]>\n' +
    '<(#{桌台号})>\n' +
    '-----------------------------\n' +
    '点菜员: #{点菜员}  人数：#{就餐人数}\n' +
    '下单时间：#{下单时间}  餐别:#{餐别}\n' +
    '开单号：#{订单号}\n' +
    '-----------------------------\n' +
    '(菜品名称            数量)\n' +
    '#item\n' +
    '(#{出品要求} #{菜品名称}#{菜品数量})\n' +
    '#{做法}\n' +
    '#{口味}\n' +
    '#item\n' +
    '-----------------------------\n' +
    '流水号：#{单据号}';

    // #endregion

    var linelen = 40;
    var dishnamelen = 20;
    var dishnumlen = 6;

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 28;
            dishnumlen = 9;
        }
        else {
            linelen = 32;
            dishnamelen = 26;
            dishnumlen = 6;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        var dishMasterInfo = { dishCount: 0, dishNum:0};
        if (printtext.indexOf('#{数量统计}')>=0)
            dishMasterInfo = this.getDishsMasterInfo(object.dishs);

        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
                            .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
                            .replaceAll('#{餐别}', object.canbie)
                            .replaceAll('#{点菜员}', object.diancaiyuan)
                            .replaceAll('#{操作人}', object.diancaiyuan)
                            .replaceAll('#{餐别}', object.canbie)
                            .replaceAll('#{订单号}', object.orderno)
                            .replaceAll('#{数量统计}', '共 ' + dishMasterInfo.dishCount + ' 道  ' + dishMasterInfo.dishNum+' 份')
                            .replaceAll('#{下单时间}', object.ordertime)
                            .replaceAll('#{开台时间}', object.kaiTaiTime);

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && object.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n\n", "\n");
                if (relcptextmode.indexOf('\n') == 0)
                    relcptextmode = relcptextmode.substring(1, relcptextmode.length);
                var relcptext = '';
                for (var i in object.dishs) {
                    var cp = object.dishs[i];

                    var numberStr = Utils.m2string(cp.num) + cp.unitName;
                    var priceStr = Utils.m2string(cp.price);
                    var amountStr = Utils.m2string(cp.price * cp.num);

                    relcptext += relcptextmode.replaceAll('#{出品要求}', cp.chupin).replaceAll('#{菜品名称}', cp.name + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cp.name))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(numberStr)) + numberStr);//+ "\n";

                    var zftxt = '';
                    var zfmode = Utils.getPrintLineByK(relcptextmode, '#{做法}', 0);
                    if (cp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                        zftxt = '';
                        
                        for (var z in cp.zuofas) {
                            var zf = cp.zuofas[z];
                            var zfname = zfmode.replaceAll('#{做法}', zf.name);
                            //var zfprice = Utils.m(zf.m4Print()).ToString('C');
                            var zfnum = '';
                            var zfonep = '';
                            zftxt += zfname + '\n';
                        }
                        //if (cp.kouweis.length == 0 || relcptextmode.indexOf('#{口味}') == -1)
                        //zftxt = zftxt.substring(0, zftxt.length - 1);
                    }
                    if (zfmode && zfmode.length>0)
                        relcptext = relcptext.replaceAll(zfmode.replaceAll('\\[', '\\[')+'\n', zftxt);

                    var kwtxt = '';
                    var kwmode = Utils.getPrintLineByK(relcptextmode, '#{口味}', 0);
                    if (cp.kouweis.length > 0 && relcptextmode.indexOf('#{口味}') > -1) {
                        //kwtxt = '';
                        
                        for (var k in cp.kouweis) {
                            var kwname = (cp.kouweis[k].name ? cp.kouweis[k].name : cp.kouweis[k].kwName) ;
                           
                            kwtxt += kwmode.replaceAll('#{口味}', kwname) + '\n';
                        }
                        //kwtxt = kwtxt.substring(0, kwtxt.length - 1);
                    }
                    if (kwmode && kwmode.length > 0)
                        relcptext = relcptext.replaceAll(kwmode.replaceAll('\\[', '\\[') + '\n', kwtxt);


                    if (cp.isScomb == 'true' || cp.isScomb == '1') {
                        for (var j in cp.scombCaipins) {
                            var scp = cp.scombCaipins[j];
                            var scpname = '--' + scp.name;

                            var snumstr = Utils.m2string(scp.num) + scp.unitName;
                            var priceStr = Utils.m2string(scp.price);
                            var amountStr = Utils.m2string(scp.price * scp.num);

                            relcptext += relcptextmode.replaceAll('#{出品要求}', scp.chupin).replaceAll('#{菜品名称}', scpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(scpname))).replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(snumstr)) + snumstr);// + "\n";

                            var zftxt = '';
                            var zfmode = Utils.getPrintLineByK(relcptextmode, '#{做法}', 0);
                            if (scp.zuofas.length > 0 && relcptextmode.indexOf('#{做法}') > -1) {
                                zftxt = '';
                                for (var z in scp.zuofas) {
                                    var zf = scp.zuofas[z];
                                    var zfname = zfmode.replaceAll('#{做法}', zf.name);
                                    var zfnum = '';
                                    var zfonep = '';
                                    zftxt += zfname + '\n';
                                }
                            }
                            if (zfmode && zfmode.length > 0)
                                relcptext = relcptext.replaceAll(zfmode.replaceAll('\\[', '\\[') + '\n', zftxt);

                            var kwtxt = '';
                            var kwmode = Utils.getPrintLineByK(relcptextmode, '#{口味}', 0);
                            if (scp.kouweis.length > 0 && relcptextmode.indexOf('#{口味}') > -1) {
                                for (var k in scp.kouweis) {
                                    var kwname = (scp.kouweis[k].name ? scp.kouweis[k].name : scp.kouweis[k].kwName);
                                    kwtxt += kwmode.replaceAll('#{口味}', kwname) + '\n';
                                }
                            }
                            if (kwmode && kwmode.length > 0)
                                relcptext = relcptext.replaceAll(kwmode.replaceAll('\\[', '\\[') + '\n', kwtxt);


                        }
                    }

                }
                printtext = printtext.replaceAll2(cptextmode, relcptext);
            }
        }

        return printtext;
    };
};

function TuiCaiDanObject() {
    this.diancaiyuan = null;
    this.deskNo = null;
    this.dish = { name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 };
    this.rs = null;
    this.tuicainum = 0;
    this.tuicaiReason = null;
}

function TuiCaiDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
    '<[#{打印机名称}退单]>\n' +
    '--------------------------------------\n' +
    '#{打印时间} 操作员:#{点菜员}\n' +
    '<(#{桌台号})>\n' +
    '#3$退$ $#{菜品名称} #{退菜原因}$\n' +
    '[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
    '\n' +
    '流水号：#{单据号}';

    var _template58 =
    '<[#{打印机名称}退单]>\n' +
    '-----------------------\n' +
    '#{打印时间} 操作员:#{点菜员}\n' +
    '<(#{桌台号})>\n' +
    '#3$退$ $#{菜品名称} #{退菜原因}$\n' +
    '[数量：#{菜品数量}  人数：#{就餐人数}]\n' +
    '\n' +
    '流水号：#{单据号}';

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
            .replaceAll('#{菜品名称}', object.dish.name)
            .replaceAll('#{菜品数量}', object.tuicainum + object.dish.unitName)
            .replaceAll('#{就餐人数}', object.rs).replaceAll('#{人数}', object.rs)
            .replaceAll('#{退菜原因}', object.tuicaiReason)
            .replaceAll('#{点菜员}', object.diancaiyuan)
            .replaceAll('#{餐别}', object.canbie)
            .replaceAll('#{备注}', object.remark)
            .replaceAll('#{订单号}', object.orderno)
            .replaceAll('#{操作人}', object.operator);
        return printtext;
    };
};

function ChuDaCeShiObject() {
    this.printerName = null;
}

function ChuDaCeshiDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '[厨打测试成功]\n' +
                '\n' +
                '厨打名称: #{打印机名称}\n' +
                '测试时间: #{打印时间}\n' +
                '流水号：  #{单据号}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{打印机名称}', object.printerName);
        return printtext;
    };
}

function CeshiDanTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[测试成功]>\n\n' +
                '机器号：#{机器号}\n' +
                '测试时间: #{打印时间}\n';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{机器号}', BIZCONSTANT.POSUSER.device);
        return printtext;
    };
}


function FDDanTestObject() {
    this.deskNo = null;
    this.rs = null;
    this.canbie = null;
    this.company = '袁州食府';
    this.companyphone = '0795-3563999';
    this.companyaddress = '宜春市环城西路363号';
    this.ordertime = null;
    this.orderno = null;
    this.dishs = [{ name: '蒜蓉粉丝虾', price: 10.00, num: 2, unitName: '个', dishze: 20.00 }, { name: '清炒空心菜', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }, { name: '剑南春', price: 100.00, num: 1, unitName: '分', dishze: 100.00 }];
    this.diancaiyuan = null;
}

function FDDanTestTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
    '<[分单测试]>\n' +

    '------------------------------------------\n' +
    '(菜品名称)\n' +
    '#item\n' +
    '( #{菜品名称})\n' +
    '#item\n' +
    '------------------------------------------\n' +
    '流水号：#{单据号}';

    var linelen = 40;
    var dishnamelen = 20;
    var dishnumlen = 6;

    this.getTemplate = function () {
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 30;
            dishnumlen = 9;
        }
        else {
            linelen = 32;
            dishnamelen = 26;
            dishnumlen = 6;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        //printtext = printtext.replaceAll('#{桌台号}', object.deskNo).replaceAll('#{就餐人数}', object.rs).replaceAll('#{餐别}', object.canbie).replaceAll('#{点菜员}', object.diancaiyuan).replaceAll('#{餐别}', object.canbie).replaceAll('#{订单号}', object.orderno).replaceAll('#{下单时间}', object.ordertime);

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && object.dishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n", "");
                var relcptext = '';
                for (var i in object.dishs) {
                    var cp = object.dishs[i];
                    relcptext += relcptextmode.replaceAll('#{菜品名称}', cp.name + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cp.name))) + "\n";
                }
                printtext = printtext.replaceAll2(cptextmode, relcptext);
            }
        }

        return printtext;
    };
};



function ChongZhiObject() {
    this.cardNo = null;
    this.hyName = null;
    this.money = 0;
    this.zengsong = 0;
    this.yue = 0;
    this.paytype = null;
    this.operatorName = null;
    this.HotelName = null;
}

function ChongZhiTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[卡充值通知单]>\n' +
                '\n' +
                '卡    号:  #{卡号}\n' +
                '会    员:  #{会员}\n' +
                '充值金额： #{充值金额}\n' +
                '赠送金额： #{赠送金额}\n' +
                '账户余额： #{账户余额}\n' +
                '付款方式： #{付款方式}\n' +
                '充值门店： #{门店名称}\n' +
                '操 作 员： #{操作员}\n' +
                '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{会员}', object.hyName).replaceAll('#{充值金额}', Utils.m(object.money).ToString('C')).replaceAll('#{赠送金额}', Utils.m(object.zengsong).ToString('C')).replaceAll('#{账户余额}', Utils.m(object.yue).ToString('C')).replaceAll('#{付款方式}', object.paytype).replaceAll('#{操作员}', object.operatorName).replaceAll('#{门店名称}', object.HotelName);;
        return printtext;
    };
}

function BJMKChongZhiObject() {
    this.cardNo = null;
    this.kaFei = 0;
    this.money = 0;
    this.zengsong = 0;
    this.yue = 0;
    this.paytype = null;
    this.operatorName = null;
    this.HotelName = null;
}

function BJMKChongZhiTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
        '<[卡充值通知单]>\n' +
        '------------------------------------------\n' +
        '卡    号:  #{卡号}\n' +
        '会员类型： 不记名卡\n' +
        '押    金:  #{押金}\n' +
        '充值金额： #{充值金额}\n' +
        '赠送金额： #{赠送金额}\n' +
        '账户余额： #{账户余额}\n' +
        '付款方式： #{付款方式}\n' +
        '\n' +
        '------------------------------------------\n' +
        '操 作 员： #{操作员}\n' +
        '交易门店： #{门店名称}\n' +
        '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{押金}', Utils.m(object.kaFei).ToString('C')).replaceAll('#{充值金额}', Utils.m(object.money).ToString('C')).replaceAll('#{赠送金额}', Utils.m(object.zengsong).ToString('C')).replaceAll('#{账户余额}', Utils.m(object.yue).ToString('C')).replaceAll('#{付款方式}', object.paytype).replaceAll('#{操作员}', object.operatorName).replaceAll('#{门店名称}', object.HotelName);
        return printtext;
    };
}

function BJMKTuiKaObject() {
    this.cardNo = null;
    this.kaFei = 0;
    this.money = 0;
    this.shiTui = 0;
    this.operatorName = null;
    this.HotelName = null;
}

function BJMKTuiKaTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
        '<[退卡通知单]>\n' +
        '------------------------------------------\n' +
        '卡    号:  #{卡号}\n' +
        '会员类型： 不记名卡\n' +
        '押    金:  #{押金}\n' +
        '退卡金额： #{退卡金额}\n' +
        '付款方式： 现金\n' +
        '实退金额： #{实退金额}\n' +
        '\n' +
        '------------------------------------------\n' +
        '操 作 员： #{操作员}\n' +
        '交易门店： #{门店名称}\n' +
        '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{押金}', Utils.m(object.kaFei).ToString('C')).replaceAll('#{退卡金额}', Utils.m(object.money).ToString('C')).replaceAll('#{实退金额}', Utils.m(object.shiTui).ToString('C')).replaceAll('#{操作员}', object.operatorName).replaceAll('#{门店名称}', object.HotelName);
        return printtext;
    };
}


function KaXiaoFeiObject() {
    this.cardNo = null;
    this.hyName = null;
    this.money = 0;
    this.zengsong = 0;
    this.yue = 0;
    this.PJH = null;
    this.jfxf = 0;
    this.syjf = 0;
    this.operatorName = null;
    this.HotelName = null;
}

function KaXiaoFeiTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[会员消费通知单]>\n' +
                '\n' +
                '凭 据 号： #{凭据号}\n' +
                '会员卡号:  #{卡号}\n' +
                '会员名称:  #{会员}\n' +
                '储值消费： #{消费金额}\n' +
                '账户余额： #{账户余额}\n' +
                '积分消费： #{积分消费}\n' +
                '剩余积分： #{剩余积分}\n' +
                '消费门店： #{门店名称}\n' +
                '操 作 员： #{操作员}\n' +
                '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo)
            .replaceAll('#{会员}', object.hyName)
            .replaceAll('#{消费金额}', Utils.m(object.money).ToString('C'))
            .replaceAll('#{凭据号}', object.PJH)
            .replaceAll('#{账户余额}', Utils.m(object.yue).ToString('C'))
            .replaceAll('#{积分消费}', Utils.m(object.jfxf).ToString('C'))
            .replaceAll('#{剩余积分}', Utils.m(object.syjf).ToString('C'))
            .replaceAll('#{付款方式}', object.paytype)
            .replaceAll('#{操作员}', object.operatorName)
            .replaceAll('#{门店名称}', object.HotelName);
        return printtext;
    };
}


function FaKaObject() {
    this.cardNo = null;
    this.hyName = null;
    this.money = 0;
    this.zengsong = 0;
    this.yue = 0;
    this.kf = 0;
    this.paytype = null;
    this.operatorName = null;
    this.HotelName = null;
}

function FaKaTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[发卡通知单]>\n' +
                '\n' +
                '卡    号:  #{卡号} \n' +
                '会    员:  #{会员} \n' +
                '发卡门店： #{门店名称} \n' +
                '押金金额： #{押金金额}\n' +
                '充值金额： #{充值金额}\n' +
                '赠送金额： #{赠送金额}\n' +
                '账户余额： #{账户余额}\n' +
                '付款方式： #{付款方式}\n' +
                '操 作 员： #{操作员} \n' +
                '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {

        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{会员}', object.hyName).replaceAll('#{操作员}', object.operatorName).replaceAll('#{门店名称}', object.HotelName);

        //if (object.money != 0 || object.zengsong != 0)
        printtext = printtext.replaceAll('#{充值金额}', Utils.m2string(object.money)).replaceAll('#{赠送金额}', Utils.m2string(object.zengsong)).replaceAll('#{账户余额}', Utils.m2string(object.yue)).replaceAll('#{付款方式}', object.paytype);
        //else
        //{
        //    printtext = printtext.replaceAll('#{充值金额}\n', '').replaceAll('#{赠送金额}\n', '').replaceAll('#{账户余额}\n', '').replaceAll('#{付款方式}\n', '').replaceAll('\n充值金额：', '').replaceAll('\n赠送金额：', '').replaceAll('\n账户余额：', '').replaceAll('\n付款方式：', '');
        //    printtext = printtext.replaceAll('#{充值金额}', '').replaceAll('#{赠送金额}', '').replaceAll('#{账户余额}', '').replaceAll('#{付款方式}', '').replaceAll('充值金额：', '').replaceAll('赠送金额：', '').replaceAll('账户余额：', '').replaceAll('付款方式：', '');
        //}
            

        //if (!object.kf)
        //    printtext = printtext.replaceAll('#{卡费金额}\n', '').replaceAll('#{卡费金额}', '').replaceAll('\n卡费金额：', '').replaceAll('卡费金额：', '');
        //else
        printtext = printtext.replaceAll('#{押金金额}', Utils.m2string(object.kf));

        return printtext;
    };
}

function CheXiaoObject() {
    this.cardNo = null;
    this.hyName = null;
    this.money = 0;
    this.cheQMoney = 0;
    this.cheHMoney = 0;
    this.operatorName = null;
    this.HotelName = null;
}

function CheXiaoTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[卡充值撤销通知单]>\n' +
                '\n' +
                '卡    号:  #{卡号}\n' +
                '会    员:  #{会员}\n' +
                '撤销金额： #{撤销金额}\n' +
                '撤前金额： #{撤前金额}\n' +
                '撤后余额： #{撤后余额}\n' +
                '撤销门店： #{撤销门店}\n' +
                '操 作 员： #{操作员}\n' +
                '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{会员}', object.hyName).replaceAll('#{撤销金额}', Utils.m(object.money).ToString('C')).replaceAll('#{撤前金额}', Utils.m(object.cheQMoney).ToString('C')).replaceAll('#{撤后余额}', Utils.m(object.cheHMoney).ToString('C')).replaceAll('#{操作员}', object.operatorName).replaceAll('#{撤销门店}', object.HotelName);;
        return printtext;
    };
}

//积分撤销单打印
function JifenchexiaoObj() {
    this.cardNo = null;
    this.hyStyle = null;
    this.hyName = null;
    this.cheJifen = 0;
    this.jifen = 0;
    this.pingJu = null;
    this.operatorName = null;
}

function JifenchexiaoTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[积分消费撤销单]>\n' +
                '\n' +
                '卡    号:  #{卡号}\n' +
                '会员类型： #{会员类型}\n' +
                '会    员:  #{会员}\n' +
                '撤销积分： #{撤销积分}\n' +
                '积分余额： #{积分余额}\n' +
                '凭 据 号： #{凭据号}\n' +
                '操 作 员： #{操作员}\n' +
                '打印时间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo).replaceAll('#{会员类型}', object.hyStyle).replaceAll('#{会员}', object.hyName).replaceAll('#{撤销积分}', Utils.m(object.cheJifen).ToString('C')).replaceAll('#{积分余额}', Utils.m(object.jifen).ToString('C')).replaceAll('#{凭据号}', object.pingJu).replaceAll('#{操作员}', object.operatorName);
        return printtext;
    };
}

//储值撤掉打印
function ChuzhichexiaoObj() {
    this.cardNo = null;
    this.hyName = null;
    this.money = 0;
    this.cheMoney = 0;
    this.jifen = 0;
    this.syjf = 0;
    this.PJH = '';
    this.operatorName = null;
    this.HotelName = null;
}

function ChuzhichexiaoTemplate() {
    this.base = PrinterTemplate;
    this.base();

    var _template =
                '<[会员消费撤销通知单]>\n' +
                '\n' +
                '凭   据   号： #{凭据号}\n' +
                '会 员  卡 号:  #{卡号}\n' +
                '会 员  名 称:  #{会员}\n' +
                '储值消费撤销： #{撤销金额}\n' +
                '账 户  余 额： #{账户余额}\n' +
                '积分消费撤销： #{撤销积分}\n' +
                '剩 余  积 分： #{剩余积分}\n' +
                '消 费  门 店： #{撤销门店}\n' +
                '操   作   员： #{操作员}\n' +
                '打 印  时 间： #{打印时间}';

    this.getTemplate = function () {
        return _template;
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{卡号}', object.cardNo)
            .replaceAll('#{会员}', object.hyName)
            .replaceAll('#{撤销金额}', Utils.m(object.cheMoney).ToString('C'))
            .replaceAll('#{账户余额}', Utils.m(object.money).ToString('C'))
            .replaceAll('#{撤销积分}', Utils.m(object.jifen).ToString('C'))
            .replaceAll('#{剩余积分}', Utils.m(object.syjf).ToString('C'))
            .replaceAll('#{操作员}', object.operatorName)
            .replaceAll('#{凭据号}', object.PJH)
            .replaceAll('#{撤销门店}', object.HotelName);
        return printtext;
    };
}

function TuiCaiHuiZongDanObject() {
    this.tuiDishs = [];
    this.totalNum = 0;
    this.totalMoney = 0.00;
    this.caozuoyuan = '';
    this.startTime = '';
    this.endTime = '';
    this.cpType = '';
};

function TuiCaiHuiZongTemplate() {
    this.base = PrinterTemplate;
    this.base();

    // #region 默认模板
    var _template =
        '<[退菜汇总单]>\n' +
        '菜品类型:#{菜品类型}\n' +
        '开始时间:#{开始时间}\n' +
        '结束时间:#{结束时间}\n' +
        '------------------------------------------\n' +
        '品名                         数量        金额\n' +
        '#item\n' +
        '#{品名及理由}   #{菜品数量}  #{菜品金额}\n' +
        '#item\n' +
        '------------------------------------------\n' +
        '操作员:#{操作员}\n' +
        '打印时间:#{打印时间}\n';

    var _template58 =
        '<[退菜汇总单]>\n' +
        '菜品类型:#{菜品类型}\n' +
        '开始时间:#{开始时间}\n' +
        '结束时间:#{结束时间}\n' +
        '------------------------------------\n' +
        '品名                   数量      金额\n' +
        '#item\n' +
        '#{品名及理由}   #{菜品数量}  #{菜品金额}\n' +
        '#item\n' +
        '------------------------------------\n' +
        '操作员:#{操作员}\n' +
        '打印时间:#{打印时间}\n';

    // #endregion

    var linelen = 40;
    var dishnamelen = 20;
    var dishnumlen = 10;
    var dishpricelen = 10;

    this.getTemplate = function () {
        if (this.invoice && this.invoice.printTemplate) {
            this.size = this.invoice.printTemplate.size;
            this.setPrinterArg(this.size);
            return (this.invoice.printTemplate.newContent && this.invoice.printTemplate.newContent.length > 1) ? this.invoice.printTemplate.newContent : this.size == 80 ? this.invoice.printTemplate.sourceContent : this.invoice.printTemplate.sourceContent58;
        }
        if (this.size === 58)
            return _template58;
        return _template;
    };

    this.setPrinterArg = function (size) {
        size = size == null ? 80 : size;
        this.size = size;
        if (size == 80) {
            linelen = 40;
            dishnamelen = 25;
            dishnumlen = 5;
            dishpricelen = 10
        }
        else {
            linelen = 32;
            dishnamelen = 20;
            dishnumlen = 4;
            dishpricelen = 8;
        }
    };

    this._parseObject = function (object, invoice, printtext) {
        printtext = printtext.replaceAll('#{桌台号}', object.deskNo)
            .replaceAll('#{菜品类型}', object.cpType)
            .replaceAll('#{开始时间}', object.startTime)
            .replaceAll('#{结束时间}', object.endTime)
            //.replaceAll('#{菜品总数量}', object.totalNum)
            //.replaceAll('#{菜品总金额}', object.totalMoney)
            .replaceAll('#{操作员}', object.caozuoyuan);

        //循环菜品
        var indexitem = printtext.indexOf('#item');
        var fetchLength = 6;
        if (indexitem > 0 && object.tuiDishs) {
            var lastindexitem = printtext.lastIndexOf('#item\n');
            if (lastindexitem == -1) {
                lastindexitem = printtext.lastIndexOf('#item');
                fetchLength = 5;
            }
            if (indexitem == lastindexitem) {
                printtext.replaceAll('#item', '');
                printtext.replaceAll('#item\n', '');
            }
            else {
                var cptextmode = printtext.substring(indexitem, lastindexitem + fetchLength);
                var relcptextmode = cptextmode.replaceAll('#item', '').replaceAll("\r", "").replaceAll("\n","");
                var relcptext = '';
                for (var i in object.tuiDishs) {
                    var cp = object.tuiDishs[i],tuicaiReasonName,cpname,cpnum,cpmoney;

                    if(cp.isHeji){
                        cpname = cp.name;
                        cpnum = this.m2string(cp.num);
                        cpmoney = this.m2string(cp.zheQianMoney);
                    } else{
                        tuicaiReasonName = cp.tuicaiReasonName ? cp.tuicaiReasonName : "";
                        cpname = cp.name+"【"+tuicaiReasonName+"】";
                        cpnum = this.m2string(cp.num);
                        cpmoney = this.m2string(cp.zheQianMoney);
                    }
                    var cpmodel = { source: '#{品名及理由}', text: cpname, align: "L", length: dishnamelen };
                    var cpunitmodel = { source: '#{菜品数量}', text: cpnum, align: "R", length: dishnumlen };
                    var cppricemodel = { source: '#{菜品金额}', text: cpmoney, align: "R", length: dishpricelen };

                    var tp_cp_replace_mode = this.formatTemplateLine(relcptextmode, cpmodel, cpunitmodel,cppricemodel);
                    if(cp.isHeji){
                        if(linelen == 32){
                            relcptext += '------------------------------------\n' + tp_cp_replace_mode+"\n";

                        }else{
                            relcptext += '------------------------------------------\n' + tp_cp_replace_mode+"\n";
                        }


                    }else{
                        relcptext += tp_cp_replace_mode+"\n";
                    }


                    //relcptext += relcptextmode.replaceAll('#{品名及理由}', cpname + Utils.printBlank(dishnamelen - Utils.getPrinterLength(cpname)))
                    //        .replaceAll('#{菜品数量}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(cpnum)) + cpnum)
                    //        .replaceAll('#{菜品金额}', Utils.printBlank(dishnumlen - Utils.getPrinterLength(cpmoney)) + cpmoney)+ "\n";
                }
                printtext = printtext.replaceAll(cptextmode, relcptext);

            }
        }
        return printtext;
    };
}